/*--------------------------------------------------------------------------------------------------
Cleaning raw data

Clean raw data as given by the Punjab secretary of education. We also follow their steps for building the 
flagging measures

	Outline:

	1. calculation of main outcomes
	2. keep main variables and assign labels
	3. students scores data
	4. fix markaz assigment
	5. balance dataset
	6. fill missings as required
	7. assign flagging status
	8. additional variables
	9. additional data considerations
	10. head teacher data
--------------------------------------------------------------------------------------------------*/

/* cleaning data notes:

In this code we clean administrative dataset collected by the PMIU of the education secretariat of Punjab
in Pakistan. To clean the data and create the treatments we are following their suggestions based on how
the data was collected 

* Relevant notes:

1. because the monthly sampling was done randomly on 80% of the schools, we complete the panel dataset by
school year by filling the missing schools for each markaz and assigning them the closest outcome reported.
If an school was not observed during an school-year, we assume it was not present, so we do not include it 
in the complete panel. Note that from random sampling, this does not affects the distribution of the treatment
or the outcomes in general

2. new markaz were created or renamed at different points in time, which makes harder to follow schools consistently. 
We define specific rules to identify the probability that a newly named markaz correspond to an older one, based on
whether or not an school was present and for how long. Such standarization allow us to track of schools for 
longer periods of time when exposed to the same AEO. While such standarization follows an assumption, on average the 
schools would have been exposed to the same intensity of the treatment regardless. The results are robust to
keeping the original assignment as reported by the admin data
*/

*---------------------------------------------------------------------------------------------------
**# 1. calculation of main outcomes #

/* The data to be used in this paper consist in monthly school data reported between september 2011
and december 2018. The data was collected in different stages, between which there might exist 
differences in treatment coding. Hence, we clean the data in various stages to account for the 
differences in data collection */

* read master data
use "$data/cc_mea_master.dta", clear 

* drop unnecesary data
drop if year < 2011

*define if datapack 1, 2, 3, 4
gen datapack = 1 if (year >= 2011 & year <= 2014) | (year == 2015 & month < 9)
replace datapack = 2 if (year == 2015 & month >= 9) | (year == 2016)
replace datapack = 3 if (year == 2017 & month >= 1 & month <= 5)
replace datapack = 4 if (year == 2017 & month >= 9) | (year == 2018 & month <= 4)
replace datapack = 3 if datapack == 4 // two datapacks calculate outcomes equally

/* The datapacks have some differences in calculating the outcomes. Nevertheless for all exscept 
for student attendance, the outcomes are calculated with the same procedure */
	
* define schools that were closed at the moment of visit
gen closed = (closedreason == 1)

* editing variable names
rename district_e district
rename tehsil_e tehsil
rename wing_e wing
rename markaz_e markaz
rename level_e level

*local for iterate in creating variables
local vars teacher functional admin
foreach v of local vars{
	 
	if("`v'" == "teacher"){ // teacher presence
		
		* creating variables for color-coding thresholds
		gen green_tpres = 90
		gen red_tpres = 86

		* adjust teacherpresence: note we would like to observe only non-justified absence
		drop  unauthorizedabsent //recalculate unauthorized absences in case of errors
		egen totalpresent = rowtotal(present sanctionedleave examsduty trainingduty others) 
		gen unauthorizedabsent = totalteachers - totalpresent //new adjusted absence
		drop totalpresent // do not need this variable

		* calculation of teacher presence	
		gen tpres = 100*(present/totalteachers)
		replace tpres = 100 if tpres > 100 & tpres != .

		* markaz-wing level  teacher presence
		bysort month year district tehsil wing markaz: egen mar_tpres_n = sum(present) 
		bysort month year district tehsil wing markaz: egen mar_tpres_d = sum(totalteachers) 
		gen mar_tpres = 100*(mar_tpres_n/mar_tpres_d)
		drop mar_tpres_n mar_tpres_d //do not need
		
		* tehsil-wing level  teacher presence
		bysort month year district tehsil wing: egen tehsil_tpres_n = sum(present) 
		bysort month year district tehsil wing: egen tehsil_tpres_d = sum(totalteachers) 
		gen tehsil_tpres = 100*(tehsil_tpres_n/tehsil_tpres_d)
		drop tehsil_tpres_n tehsil_tpres_d //do not need

		*district level teacher presence
		bysort month year district: egen district_tpres_n = sum(present) 
		bysort month year district: egen district_tpres_d = sum(totalteachers) 
		gen district_tpres = 100*(district_tpres_n/district_tpres_d)
		drop district_tpres_n district_tpres_d //do not need
	
	}
	else if("`v'" == "functional"){ // functional facilities
		
		* creating variables for threshold
		gen green_fac = 95
		gen red_fac = 90

		* calculation school level functional facilities (non-mosque open schools): mosque level == 6	
		egen fac_n = rowtotal(elec_f dw_f toilet_f bw_f) if sstatus == 1 & level != 6
		gen fac_d = 4 if sstatus == 1 & level != 6
		gen fac = 100*(fac_n/fac_d)
			
		* markaz-wing level functional facilities
		bysort month year district tehsil wing markaz: egen mar_fac_n = sum(fac_n) 
		bysort month year district tehsil wing markaz: egen mar_fac_d = sum(fac_d) 
		gen mar_fac = mar_fac_n*100/mar_fac_d
		drop mar_fac_n mar_fac_d
		
		* tehsil-wing level functional facilities
		bysort month year district tehsil wing: egen tehsil_fac_n = sum(fac_n) 
		bysort month year district tehsil wing: egen tehsil_fac_d = sum(fac_d) 
		gen tehsil_fac = tehsil_fac_n*100/tehsil_fac_d
		drop tehsil_fac_n tehsil_fac_d

		* district level functional facilities
		bysort month year district: egen district_fac_n = sum(fac_n)
		bysort month year district: egen district_fac_d = sum(fac_d)
		gen district_fac = district_fac_n*100/district_fac_d
		drop district_fac_n district_fac_d

	}
	else if("`v'" == "admin"){ // administrative visits
		
		* threshold for datapack 1
		gen green_advis = 90
		gen red_advis = 80

		* threshold for datapack 2
		replace red_advis = 86 if datapack == 2

		* threshold for datapack 3 or 4
		replace red_advis = 70 if datapack == 3 | datapack == 4
		
		* calculation
		replace admin_visit = 0 if sstatus == 0 // nonsensical qualifier imposed by PMIU
		gen advis = 1 if admin_visit > 0 & admin_visit != . 
		replace advis = 0 if admin_visit == 0
		
	}
		
}

/* the student attendance variable have different conditions under different datapacks, then we 
create for each datapack and then append all */

forvalues i = 1(1)3{ // datapack 1, 2, 3

	if(`i' == 1){ // datapack 1
		preserve

		keep if datapack == 1
					
		* school level student attendance
		
			* creating variables for color-coding thresholds: A = 1, B = 2, C = 3
		gen red_satt = 89 if (district_cat == 1 & (month > 11 | month < 4))
		replace red_satt = 87 if (district_cat == 1 & (month>=4 & month <= 11))
		replace red_satt = 87 if (district_cat == 2 & (month > 11 | month < 4))
		replace red_satt = 85 if (district_cat == 2 & (month >= 4 & month <= 11))
		replace red_satt = 84 if (district_cat == 3 & (month > 11 | month < 4))
		replace red_satt = 82 if (district_cat == 3 & (month >= 4 & month <= 11))
		
			* other threshold
		gen green_satt = 92 if (district_cat == 1 & (month > 11 | month < 4))
		replace green_satt = 90 if (district_cat == 1 & (month >= 4 & month <= 11))
		replace green_satt = 90 if (district_cat == 2 & (month > 11 | month < 4))
		replace green_satt = 88 if (district_cat == 2 & (month >= 4 & month <= 11))
		replace green_satt = 87 if (district_cat == 3 & (month > 11 | month < 4))
		replace green_satt = 85 if (district_cat == 3 & (month >= 4 & month <= 11))
				
			* present students
		egen satt_n = rowtotal(cls1present cls2present cls3present cls4present cls5present cls6present ///
			cls7present cls8present cls9present cls10present cls11present cls12present) 
					
			* enrolled students
		egen satt_d = rowtotal(cls1enrol cls2enrol cls3enrol cls4enrol cls5enrol cls6enrol cls7enrol ///
			cls8enrol cls9enrol cls10enrol cls11enrol cls12enrol)
					
			* because of error in reporting
		replace satt_d = satt_n if satt_n > satt_d
				
			* student attendance rate
		gen satt = 100*(satt_n/satt_d)
				
			* drop non required variables
		drop cls1present cls2present cls3present cls4present cls5present cls6present cls7present cls8present ///
			cls9present cls10present cls11present cls12present cls1enrol cls2enrol cls3enrol cls4enrol ///
			cls5enrol cls6enrol cls7enrol cls8enrol cls9enrol cls10enrol cls11enrol cls12enrol

		* markaz-wing level student attendance
		bysort month year district tehsil wing markaz: egen mar_satt_n = sum(satt_n) 
		bysort month year district tehsil wing markaz: egen mar_satt_d = sum(satt_d) 
		gen mar_satt = 100*(mar_satt_n/mar_satt_d)
		drop mar_satt_n mar_satt_d
		
		* tehsil-wing level student attendance
		bysort month year district tehsil wing: egen tehsil_satt_n = sum(satt_n) 
		bysort month year district tehsil wing: egen tehsil_satt_d = sum(satt_d) 
		gen tehsil_satt = 100*(tehsil_satt_n/tehsil_satt_d)
		drop tehsil_satt_n tehsil_satt_d

		* district level student attendance
		bysort month year district: egen district_satt_n = sum(satt_n) 
		bysort month year district: egen district_satt_d = sum(satt_d) 
		gen district_satt = 100*(district_satt_n/district_satt_d)
		drop district_satt_n district_satt_d
				
		* save
		tempfile dp1
		save `dp1'		
				
		restore

	}
	else if(`i' == 2){ // datapack 2
		
		preserve

		keep if datapack == 2	
					
		* school level student attendance

			* creating variables for color-coding thresholds: A = 1, B = 2, C = 3
		gen green_satt = 92
		gen red_satt = 88

			* for category A districts 
				* normal months
		replace green_satt = 92 if (district_cat == 1 & (month > 11 | month < 4))
		replace red_satt = 88 if (district_cat == 1 & (month > 11 | month < 4))
				* low attendance months
		replace green_satt = 90 if (district_cat == 1 & (month >= 4 & month <= 11))
		replace red_satt = 86 if (district_cat == 1 & (month >= 4 & month <= 11))
				* year coding for dec 16 onwards (erronneous targets carried once system was automated)
		replace green_satt = 90 if (district_cat == 1 & ((year == 2016 & month == 12) | year > 2016))
		replace red_satt = 86 if (district_cat == 1 & ((year == 2016 & month == 12) | year > 2016))
				
			* for category B districts
				* normal months
		replace green_satt = 90 if (district_cat == 2 & (month > 11 | month < 4))
		replace red_satt = 86 if (district_cat == 2 & (month > 11 | month < 4))
				* low attendance months
		replace green_satt = 88 if (district_cat == 2 & (month >= 4 & month <= 11))
		replace red_satt = 84 if (district_cat == 2 & (month >= 4 & month <= 11))
				* year coding for dec 16 onwards (erronneous targets carried once system was automated)
		replace green_satt = 88 if (district_cat == 2 & ((year == 2016 & month == 12) | year > 2016))
		replace red_satt = 84 if (district_cat == 2 & ((year == 2016 & month == 12) | year > 2016))
			
			* for category C districts
				* normal months
		replace green_satt = 87 if (district_cat == 3 & (month > 11 | month < 4))
		replace red_satt = 83 if (district_cat == 3 & (month > 11 | month < 4))
				* low attendance months
		replace green_satt = 85 if (district_cat == 3 & (month >= 4 & month <= 11))
		replace red_satt = 81 if (district_cat == 3 & (month >= 4 & month <= 11))
				* year coding for dec 16 onwards (erronneous targets carried once system was automated)
		replace green_satt = 85 if (district_cat == 3 & ((year == 2016 & month == 12) | year > 2016))
		replace red_satt = 81 if (district_cat == 3 & ((year == 2016 & month == 12) | year > 2016))
			
			* fixing threshold for specific districts to erroneous values to replicate data-pack
				* create string of district
		decode district, gen(district_e)
				* replace thresholds
		replace green_satt = 92 if (district_e == "GUJRANWALA" | district_e == "NANKANA SAHIB" | ///
			district_e == "PAKPATTAN") & (month > 11 | month < 4)
		replace red_satt = 88 if (district_e == "GUJRANWALA" | district_e == "NANKANA SAHIB" | ///
			district_e =="PAKPATTAN") & (month > 11 | month < 4)
		replace green_satt = 90 if (district_e == "GUJRANWALA" | district_e == "NANKANA SAHIB" | ///
			district_e = ="PAKPATTAN") & (month >= 4 & month <= 11)
		replace red_satt = 86 if (district_e == "GUJRANWALA" | district_e == "NANKANA SAHIB" | ///
			district_e == "PAKPATTAN") & (month >= 4 & month <= 11)
		replace green_satt = 90 if district_e == "BHAKKAR" & (month > 11 | month < 4)
		replace red_satt = 86 if district_e == "BHAKKAR" & (month > 11 | month < 4)
		replace green_satt = 88 if district_e == "BHAKKAR" & (month >= 4 & month <= 11)
		replace red_satt = 84 if district_e == "BHAKKAR" & (month >= 4 & month <= 11)		
		replace green_satt = 90 if month == 12 & year == 2016 & district_e == "ATTOCK"
		replace red_satt = 86 if month == 12 & year == 2016 & district_e == "ATTOCK"
		drop district_e // do not need this variable
				
				
			* present students
		egen satt_n = rowtotal(cls1present cls2present cls3present cls4present cls5present cls6present ///
			cls7present cls8present cls9present cls10present cls11present cls12present) 
					
			* enrolled students
		egen satt_d = rowtotal(cls1enrol cls2enrol cls3enrol cls4enrol cls5enrol cls6enrol cls7enrol ///
			cls8enrol cls9enrol cls10enrol cls11enrol cls12enrol)
					
			* because of error in reporting
		replace satt_d = satt_n if satt_n > satt_d

			* feb 2016 student attendance calculation excludes enrolment and presence of grades 5 and 8
		egen satt_n_temp = rowtotal(cls1present cls2present cls3present cls4present cls6present ///
			cls7present cls9present cls10present cls11present cls12present) 
		egen satt_d_temp = rowtotal(cls1enrol cls2enrol cls3enrol cls4enrol cls6enrol cls7enrol ///
			cls9enrol cls10enrol cls11enrol cls12enrol)  
		replace satt_n = satt_n_temp if year==2016 & month==2
		replace satt_d = satt_d_temp if year==2016 & month==2
		drop satt_n_temp satt_d_temp
			
		tempfile temp_dp2
		save `temp_dp2'
		
			* march 2016, student attendance used is average of that in Jan16 and Feb16
		keep if year==2016 & (month==1 | month==2)
		bysort emis: egen satt_n_temp = mean(satt_n)
		bysort emis: egen satt_d_temp = mean(satt_d)
		keep emis satt_n_temp satt_d_temp
		duplicates drop emis, force
		merge 1:m emis using `temp_dp2', gen(abc)
		drop if abc==1
		drop abc
		replace satt_n = satt_n_temp if year==2016 & month==3
		replace satt_d = satt_d_temp if year==2016 & month==3
		drop satt_n_temp satt_d_temp 

			* student attendance rate
		gen satt = 100*(satt_n/satt_d)
				
			* drop non required variables
		drop cls1present cls2present cls3present cls4present cls5present cls6present cls7present cls8present ///
			cls9present cls10present cls11present cls12present cls1enrol cls2enrol cls3enrol cls4enrol ///
			cls5enrol cls6enrol cls7enrol cls8enrol cls9enrol cls10enrol cls11enrol cls12enrol
			
		* markaz-wing level student attendance
		bysort month year district tehsil wing markaz: egen mar_satt_n = sum(satt_n) 
		bysort month year district tehsil wing markaz: egen mar_satt_d = sum(satt_d) 
		gen mar_satt = 100*(mar_satt_n/mar_satt_d)
		drop mar_satt_n mar_satt_d
		
		* tehsil-wing level student attendance
		bysort month year district tehsil wing: egen tehsil_satt_n = sum(satt_n) 
		bysort month year district tehsil wing: egen tehsil_satt_d = sum(satt_d) 
		gen tehsil_satt = 100*(tehsil_satt_n/tehsil_satt_d)
		drop tehsil_satt_n tehsil_satt_d

		* district level student attendance
		bysort month year district: egen district_satt_n = sum(satt_n) 
		bysort month year district: egen district_satt_d = sum(satt_d) 
		gen district_satt = 100*(district_satt_n/district_satt_d)
		drop district_satt_n district_satt_d
				
		* save
		tempfile dp2
		save `dp2'	

		restore	
		
	}
	else if(`i' == 3){ // datapacks 3 and 4
	
		*need to clean the datawhere the threshold for this datapacks come
		preserve
				
		use "$data/satt_targets_dp3.dta", clear
				
		* remove redundant spaces from district names
		cap replace  rs_district_name = upper(rs_district_name)
		cap replace rs_district_name = trim(rs_district_name)
		cap replace rs_district_name' = subinstr(rs_district_name, "  ", " ",.)
				
		* keep required data
		keep rs_district_name rs_target_green_sa_kachi rs_month rs_year
				
		* update thresholds
		rename rs_target_green_sa_kachi green_satt
		gen red_satt = green_satt - 5
				
		* rename variables
		rename rs_district_name district_e
		rename rs_month month
		rename rs_year year
				
		* save tempfile
		tempfile thresholds
		save `thresholds'
				
		restore
		
		* merge with the main dataset for datapack 3 and clean
		preserve
				
		keep if datapack >= 3
						
		* create string of districts (because the original vraible is encoded)
		decode district, gen(district_e)
		
		* merge with tempfile of threshold
		merge m:1 district_e year month using `thresholds'
		keep if _merge == 3
		drop _merge district_e

		* school level student attendance
		
				* present students
		egen satt_n = rowtotal(cls1present cls2present cls3present cls4present cls5present cls6present ///
			cls7present cls8present cls9present cls10present cls11present cls12present) 
					
				* enrolled students
		egen satt_d = rowtotal(cls1enrol cls2enrol cls3enrol cls4enrol cls5enrol cls6enrol cls7enrol ///
			cls8enrol cls9enrol cls10enrol cls11enrol cls12enrol)
					
				* because of error in reporting
		replace satt_d = satt_n if satt_n > satt_d
				
				* student attendance rate
		gen satt = 100*(satt_n/satt_d)
				
				* drop non required variables
		drop cls1present cls2present cls3present cls4present cls5present cls6present cls7present cls8present ///
			cls9present cls10present cls11present cls12present cls1enrol cls2enrol cls3enrol cls4enrol ///
			cls5enrol cls6enrol cls7enrol cls8enrol cls9enrol cls10enrol cls11enrol cls12enrol

		* markaz-wing level student attendance
		bysort month year district tehsil wing markaz: egen mar_satt_n = sum(satt_n) 
		bysort month year district tehsil wing markaz: egen mar_satt_d = sum(satt_d) 
		gen mar_satt = 100*(mar_satt_n/mar_satt_d)
		drop mar_satt_n mar_satt_d
		
		* tehsil-wing level student attendance
		bysort month year district tehsil wing: egen tehsil_satt_n = sum(satt_n) 
		bysort month year district tehsil wing: egen tehsil_satt_d = sum(satt_d) 
		gen tehsil_satt = 100*(tehsil_satt_n/tehsil_satt_d)
		drop tehsil_satt_n tehsil_satt_d

		* district level student attendance
		bysort month year district: egen district_satt_n = sum(satt_n) 
		bysort month year district: egen district_satt_d = sum(satt_d) 
		gen district_satt = 100*(district_satt_n/district_satt_d)
		drop district_satt_n district_satt_d
				
		* save
		tempfile dp3
		save `dp3'	
				
		restore
		
	}
	
}
	
* append datapacks
use `dp1', clear
append using `dp2'
append using `dp3'

*---------------------------------------------------------------------------------------------------
**# 2. keep main variables and assign labels #

if(1){
* keep main variables

*id variables
global id emis district tehsil markaz wing markaz_wing_tehsil_district

*thresholds
global thres green_tpres green_satt green_fac green_advis red_tpres red_satt red_fac red_advis

*school level variables 
global school_var tpres satt fac advis

*markaz-wing level variables
global mar_var mar_tpres mar_satt mar_fac

*tehsil-wing level variables
global tehsil_var tehsil_tpres tehsil_satt tehsil_fac

*distric level variables
global dis_var district_tpres district_satt district_fac district_cat

*time variables
global time day month year _month_num

*other variables
global other_var totalteachers present sanctionedleave examsduty trainingduty others ///
	latecommers unauthorizedabsent satt_d satt_n latitude longitude closed school_head_name  ///
	school_head_designation school_head_phone datapack 
	
*keep
keep $id $thres $school_var $mar_var $tehsil_var $dis_var $time $other_var

* additional fix
rename markaz_wing_tehsil_district mar 

* compress
compress

* save
tempfile datapack
save `datapack'
}

*---------------------------------------------------------------------------------------------------
**# 3. students scores data #

/* scores data started to be collected since datapack 3: we have scores for math, english and urdu, 
we clean it independent from the main data and then merge it all */

if(1){
* read master data
use "$data/lnd_master.dta", clear 

* remove test entries
drop if strpos(lnd_school, "PITB") | strpos(lnd_school, "TEST") | strpos(lnd_school, "PMIU")
* remove pssp schools
drop if strpos(lnd_school, "PSSP")

* keep only required variables
keep emis year month tot_eng cor_eng tot_math cor_math tot_urdu cor_urdu
* merge with master data
merge 1:1 emis year month using `datapack'
drop if _merge == 1
drop _merge

*local to iterate over scores
local vars eng math urdu

foreach v of local vars{
	
	if("`v'" == "eng"){ // english scores
		
		* creating variables for color-coding thresholds
		gen green_eng = 80
		gen red_eng = 70 

		* calculation of correct answers
		gen school_eng = 100*(cor_eng/tot_eng)
		replace school_eng = 100 if school_eng > 100 & school_eng != .

		* markaz-wing level  teacher presence
		bysort year month district wing tehsil markaz: egen mar_eng_n = sum(cor_eng) 
		bysort year month district wing tehsil markaz: egen mar_eng_d = sum(tot_eng) 
		gen mar_eng = 100*(mar_eng_n/mar_eng_d)
		drop mar_eng_n mar_eng_d
		
		* tehsil-wing level  teacher presence
		bysort year month district wing tehsil: egen tehsil_eng_n = sum(cor_eng) 
		bysort year month district wing tehsil: egen tehsil_eng_d = sum(tot_eng) 
		gen tehsil_eng = 100*(tehsil_eng_n/tehsil_eng_d)
		drop tehsil_eng_n tehsil_eng_d

		* district level teacher presence
		bysort year month district: egen district_eng_n = sum(cor_eng) 
		bysort year month district: egen district_eng_d = sum(tot_eng) 
		gen district_eng = 100*(district_eng_n/district_eng_d)
		drop district_eng_n district_eng_d
		
	}
	else if("`v'" == "math"){ // math scores
	
		* creating variables for color-coding thresholds
		gen green_math = 80
		gen red_math = 70 

		* calculation of correct answers
		gen school_math = 100*(cor_math/tot_math)
		replace school_math = 100 if school_math > 100 & school_math != .

		* markaz-wing level  teacher presence
		bysort year month district wing tehsil markaz: egen mar_math_n = sum(cor_math) 
		bysort year month district wing tehsil markaz: egen mar_math_d = sum(tot_math) 
		gen mar_math = 100*(mar_math_n/mar_math_d)
		drop mar_math_n mar_math_d
		
		* tehsil-wing level  teacher presence
		bysort year month district wing tehsil: egen tehsil_math_n = sum(cor_math) 
		bysort year month district wing tehsil: egen tehsil_math_d = sum(tot_math) 
		gen tehsil_math = 100*(tehsil_math_n/tehsil_math_d)
		drop tehsil_math_n tehsil_math_d

		*district level teacher presence
		bysort year month district: egen district_math_n = sum(cor_math) 
		bysort year month district: egen district_math_d = sum(tot_math) 
		gen district_math = 100*(district_math_n/district_math_d)
		drop district_math_n district_math_d
			
	}
	else if("`v'" == "urdu"){
		
		* creating variables for color-coding thresholds
		gen green_urdu = 80
		gen red_urdu = 70 

		* calculation of correct answers
		gen school_urdu = 100*(cor_urdu/tot_urdu)
		replace school_urdu = 100 if school_urdu > 100 & school_urdu != .

		* markaz-wing level  teacher presence
		bysort year month district wing tehsil markaz: egen mar_urdu_n = sum(cor_urdu) 
		bysort year month district wing tehsil markaz: egen mar_urdu_d = sum(tot_urdu) 
		gen mar_urdu = 100*(mar_urdu_n/mar_urdu_d)
		drop mar_urdu_n mar_urdu_d
		
		* tehsil-wing level  teacher presence
		bysort year month district wing tehsil: egen tehsil_urdu_n = sum(cor_urdu) 
		bysort year month district wing tehsil: egen tehsil_urdu_d = sum(tot_urdu) 
		gen tehsil_urdu = 100*(tehsil_urdu_n/tehsil_urdu_d)
		drop tehsil_urdu_n tehsil_urdu_d

		* district level teacher presence
		bysort year month district: egen district_urdu_n = sum(cor_urdu) 
		bysort year month district: egen district_urdu_d = sum(tot_urdu) 
		gen district_urdu = 100*(district_urdu_n/district_urdu_d)
		drop district_urdu_n district_urdu_d
		
	}
		
}

* label variables 

* general variables
label var emis "school emis"
label var  year "year"
label var month "month"

*english scores
label var green_eng "green threshold for english scores (%)"
label var red_eng "red threshold for english scores (%)"
label var school_eng "correct english scores (%)"
label var mar_eng "%age correct english questions in markaz-wing"
label var tehsil_eng "%age correct english questions in tehsil-wing"
label var district_eng "%age correct english questions in district"

* math scores
label var green_math "green threshold for math scores (%)"
label var red_math "red threshold for math scores (%)"
label var school_math "correct math scores (%)"
label var mar_math "%age correct math questions in markaz-wing"
label var tehsil_math "%age correct math questions in tehsil-wing"
label var district_math "%age correct math questions in district"

* urdu scores
label var green_urdu "green threshold for urdu scores (%)"	
label var red_urdu "red threshold for urdu scores (%)"
label var school_urdu "correct urdu scores (%)"
label var mar_urdu "%age correct urdu questions in markaz-wing"
label var tehsil_urdu "%age correct urdu questions in tehsil-wing"
label var district_urdu "%age correct urdu questions in district"

* compress
compress
save "$analysis/processed/cc_datapacks.dta", replace

}

*---------------------------------------------------------------------------------------------------
**# 4. fix markaz assigment #

/* markaz are not geographic units, but rather defined as administrative and monitoring units 
We identified that markaz are time varying and the same school might report more than 1 markaz across our 
sample. To improve stability, we identify those markaz that systematically might be assigned to others

We separate the cleaning of markaz assigment between datapack 1 and the others, the reason for this 
is that while the system remained relatively stable in dp1, in dp2 and further there started to be 
introduced new elements to the monitoring system, then while it consistent to fix markaz within dp1, 
it is a stronger assumption to fix them across, dp1 and dp2 
*/

if(1){
	
forvalues i = 1(1)2{
	
	*select datapack
	use "$analysis/processed/cc_datapacks.dta", clear
	
	if(`i' == 1){
		display("keep datapack 1")
		keep if datapack == 1
	}
	else{
		display("keep other datapacks")
		keep if datapack > 1		
	}
	
	gen original_mar = mar // to ensure we can recover outcomes
	drop if mar == .
			
	/*
	rule 1: 
		
	we assign to the same markaz those schools if there is a jump to another markaz and then 
	goes back to the original one
	*/

	* how many schools remain in the same mar?
	bys emis: egen num_mar = nvals(mar)
	tab num_mar

	* identify those schols that change of mar
	gen id = 1 if num_mar != 1
	
	/* will do the following check for all schools the next period and previous period mar
	if the prev and post are the same, but the main is not, then there was a weird jump,
	so we can assign it to the main*/

	bys emis (_month_num): gen prev_mar = mar[_n-1] if id == 1
	bys emis (_month_num): gen next_mar = mar[_n+1] if id == 1
	replace mar = prev_mar if ((prev_mar == next_mar) & (mar != prev_mar) & prev_mar != .) & id == 1
	
	*validate number of schools in the same mar
	drop num_mar id prev_mar next_mar
	bys emis: egen num_mar = nvals(mar)
	tab num_mar
	gen id = 1 if num_mar != 1
	
	/*
	rule 2: 
		
	we assign to the same markaz those schools that change markaz but at the beggining and
	end of all the period we observe them in the same mar
	*/

	*check coincidence of first and last mar
	bys emis (_month_num): gen position = _n
	bys emis (_month_num): gen position_max = _N
	
	gen temp = mar if position == 1 // first mar
	bys emis (_month_num): egen first_mar = max(temp) if id == 1
	drop temp
	
	gen temp = mar if position == position_max // last mar
	bys emis (_month_num): egen last_mar = max(temp) if id == 1
	drop temp
	
	* coincidence between first and last
	gen coincide = ((first_mar == last_mar) & id == 1) 
	*replace mar that coincide
	replace mar = first_mar if coincide == 1 & id == 1
	
	*validate number of schools in the same mar
	drop num_mar id position position_max first_mar last_mar coincide
	bys emis: egen num_mar = nvals(mar)
	tab num_mar
	gen id = 1 if num_mar != 1
	
	/*
	rule 3: 
		
	we assign to the same markaz those schools if there is a jump to another markaz and then 
	goes back to the original one after a couple of periods, but not immediatly - will use 
	two, three  
	*/
	
	/* try for two periods*/
	bys emis (_month_num): gen prev_mar1 = mar[_n-1] if id == 1
	bys emis (_month_num): gen prev_mar2 = mar[_n-2] if id == 1
	bys emis (_month_num): gen prev_mar3 = mar[_n-3] if id == 1

	bys emis (_month_num): gen next_mar1 = mar[_n+1] if id == 1
	bys emis (_month_num): gen next_mar2 = mar[_n+2] if id == 1

	replace mar = prev_mar1 if ((prev_mar1 == prev_mar2) & (prev_mar1 == prev_mar3) & (mar != prev_mar1)) & ///
							   ((mar != next_mar1) & (mar != next_mar2)) & prev_mar1 != . & id == 1 						
							   
	replace mar = prev_mar1 if ((prev_mar1 == prev_mar2) & (prev_mar1 == prev_mar3) & (mar != prev_mar1)) & ///
							   ((mar != next_mar1) | (mar != next_mar2)) & prev_mar1 != . & id == 1 						

	*validate number of schools in the same mar
	drop num_mar id prev_mar* next_mar*
	bys emis: egen num_mar = nvals(mar)
	tab num_mar
	gen id = 1 if num_mar != 1
	
	/* try for three periods*/
	bys emis (_month_num): gen prev_mar1 = mar[_n-1] if id == 1
	bys emis (_month_num): gen prev_mar2 = mar[_n-2] if id == 1
	bys emis (_month_num): gen prev_mar3 = mar[_n-3] if id == 1

	bys emis (_month_num): gen next_mar1 = mar[_n+1] if id == 1
	bys emis (_month_num): gen next_mar2 = mar[_n+2] if id == 1
	bys emis (_month_num): gen next_mar3 = mar[_n+3] if id == 1

	replace mar = prev_mar1 if ((prev_mar1 == prev_mar2) & (prev_mar1 == prev_mar3) & (mar != prev_mar1)) & ///
							   ((mar != next_mar1) & (mar != next_mar2) & (mar != next_mar3)) & prev_mar1 != . & id == 1 

	replace mar = prev_mar1 if ((prev_mar1 == prev_mar2) & (prev_mar1 == prev_mar3) & (mar != prev_mar1)) & ///
							   ((mar != next_mar1) | (mar != next_mar2) | (mar != next_mar3)) & prev_mar1 != . & id == 1 
	drop num_mar id
	
	* save 
	tempfile dp`i'_markaz
	save `dp`i'_markaz'	

}
			
* append new datapacks
use `dp1_markaz', clear
append using `dp2_markaz'

*compress
save "$analysis/processed/cc_datapacks.dta", replace

}

* now we need to reassign tehsil district and wing
if(1){
	
* district
bys original_mar: egen numdis = nvals(district)
rename district original_district
gen new_district = original_district if mar == original_mar
bys mar: egen district = max(new_district)
replace district = original_district if district == .
bys mar: egen numdis2 = nvals(district)
drop numdis new_district numdis2

*tehsil
bys original_mar: egen numtes = nvals(tehsil)
rename tehsil original_tehsil
gen new_tehsil = original_tehsil if mar == original_mar
bys mar: egen tehsil = max(new_tehsil)
replace tehsil = original_tehsil if tehsil == .
bys mar: egen numtes2 = nvals(tehsil) 
drop numtes new_tehsil numtes2

*wing
bys original_mar: egen numwing = nvals(wing)
rename wing original_wing
gen new_wing = original_wing if mar == original_mar
bys mar: egen wing = max(new_wing)
replace wing = original_wing if wing == .
bys mar: egen numwing2 = nvals(wing)
drop numwing new_wing numwing2

*markaz
bys original_mar: egen nummarkaz = nvals(markaz)
rename markaz original_markaz
gen new_markaz = original_markaz if mar == original_mar
bys mar: egen markaz = max(new_markaz)
replace markaz = original_markaz if markaz == .
bys mar: egen nummarkaz2 = nvals(markaz)
drop nummarkaz new_markaz nummarkaz2

}

/* we have already fix the geography and ids for each mar, but we also need to adjust the outcomes based on which
we will recover the flagging. This procedure (and the one above) follows the indications of the Punjab Education 
Secretary for the analysis
*/

if(1){

* adjust district level variables
local vars district_tpres district_satt district_fac district_eng district_math district_urdu
foreach v of local vars{
	rename `v' original_`v' // keep the original
	gen new_`v' = original_`v' if mar == original_mar // create a new value with the original
	/*note that new_ obtains the variable for each original mar calculate by month, 
	thus for all original mar month we should have the same value 
	*/
	bys mar _month_num: egen `v' = max(new_`v')
	replace `v' = original_`v' if `v' == .
	drop new_`v' 
}	
	
* adjust tehsil level variables
local vars tehsil_tpres tehsil_satt tehsil_fac tehsil_eng tehsil_math tehsil_urdu
foreach v of local vars{
	rename `v' original_`v' // keep the original
	gen new_`v' = original_`v' if mar == original_mar // create a new value with the original
	/*note that new_ obtains the variable for each original mar calculate by month, 
	thus for all original mar month we should have the same value 
	*/
	bys mar _month_num: egen `v' = max(new_`v')
	replace `v' = original_`v' if `v' == .
	drop new_`v' 
}	
	
* adjust mar level variables
local vars mar_tpres mar_satt mar_fac mar_eng mar_math mar_urdu
foreach v of local vars{
	rename `v' original_`v' // keep the original
	gen new_`v' = original_`v' if mar == original_mar // create a new value with the original
	/*note that new_ obtains the variable for each original mar calculate by month, 
	thus for all original mar month we should have the same value 
	*/
	bys mar _month_num: egen `v' = max(new_`v')
	replace `v' = original_`v' if `v' == .
	drop new_`v' 
}	
	
* adjust for duplicates when we replaced missings
local vars tpres satt fac eng math urdu
foreach v of local vars{
	bys mar _month_num: egen num`v' = nvals(mar_`v') // for more than 90% we recover exactly one value
	* whenever there is more than one value we recalculate as the average of the schools in it
	if("`v'" == "eng" | "`v'" == "math" | "`v'" == "urdu"){
		bys mar _month_num: egen temp = mean(school_`v') if num`v' > 1
	}
	else{
		bys mar _month_num: egen temp = mean(`v') if num`v' > 1
	}
	bys mar _month_num: replace mar_`v' = temp if num`v' > 1
	drop temp num`v'
}	
	
*drop non-functional ever schools
bys emis: egen nonfunc_ever = max(closed)
drop if nonfunc_ever == 1
drop nonfunc_ever
*drop id

*compress
save "$analysis/processed/cc_datapacks.dta", replace

}

*---------------------------------------------------------------------------------------------------
**# 5. balance dataset #

/* The school data is collected randomly in a monthly basis. Each month, the 80% of the schools are
visited to collect data on the outcomes. Hence, by construction we have a non-balanced panel dataset.
Exploiting the random visiting of schools, we impute the missing dates with the closest available
information. Note that because of the random sampling, imputation do not change the distribution of 
the variables. Still, to avoid the imputation on structual changes, we limit the filling of missings 
per academic year*/

if(1){

* dataset to be balanced
use "$analysis/processed/cc_datapacks.dta", clear

* indicator for original data
/*we need to identify the original data, to absorb any variation that might be artificially 
generated by the balancing*/

gen original = 1

* create date variable
gen date_treat = ym(year, month)
format date_treat %tm

* define panel estructure
xtset emis date_treat

* complete the panel
	/*need to complete the panel but need to do it separately by datapack, considering that there 
	are some schools that dissapear in between datapack 1 and the others*/
forvalues i = 1(1)2{
	
	if(`i' == 1){ // complete datapack 1
		
		preserve 
		
		keep if datapack == 1
		tsfill, full // note this code depends on how we define the panel in xtset

		/*drop non existing periods: there is no information between june and august in all the years 
		because of vacation time. We assume may and september are consecutive months*/
		drop if date_treat > tm(2010m5) & date_treat < tm(2010m9)
		drop if date_treat > tm(2011m5) & date_treat < tm(2011m9)
		drop if date_treat > tm(2012m5) & date_treat < tm(2012m9)
		drop if date_treat > tm(2013m5) & date_treat < tm(2013m9)
		drop if date_treat > tm(2014m5) & date_treat < tm(2014m9)

		*save balanced datapack 1
		tempfile dp1
		save `dp1'
		restore	
			
	}
	else if(`i' == 2){ // complete datapack 2
	
		preserve 
		keep if datapack > 1
		tsfill, full

		/*drop non existing periods: there is no information between june and august in all the years 
		because of vacation time. We assume may and september are consecutive months*/
		drop if date_treat > tm(2015m5) & date_treat < tm(2015m9)
		drop if date_treat > tm(2016m5) & date_treat < tm(2016m9)
		drop if date_treat > tm(2017m5) & date_treat < tm(2017m9)
		drop if date_treat > tm(2018m5) & date_treat < tm(2018m9)

			*save balanced datapack 2
		tempfile dp2
		save `dp2'
		restore
	
	}
	
}
	
* append balanced datapacks
use `dp1', clear
append using `dp2'

/*there are schools that never appear in an academic period, hence, we need to limit the balancing 
per academic year to account for the set of schools we observe at least one time per year*/
gen academic_per = 1 if date_treat >= tm(2010m9) & date_treat <= tm(2011m5)
replace academic_per = 2 if date_treat >= tm(2011m9) & date_treat <= tm(2012m5)
replace academic_per = 3 if date_treat >= tm(2012m9) & date_treat <= tm(2013m5)
replace academic_per = 4 if date_treat >= tm(2013m9) & date_treat <= tm(2014m5)
replace academic_per = 5 if date_treat >= tm(2014m9) & date_treat <= tm(2015m5)
replace academic_per = 6 if date_treat >= tm(2015m9) & date_treat <= tm(2016m5)
replace academic_per = 7 if date_treat >= tm(2016m9) & date_treat <= tm(2017m5)
replace academic_per = 8 if date_treat >= tm(2017m9) & date_treat <= tm(2018m5)

* need to drop non-existing schools: drop those schools that never appear in an academic period
gen temp = (mar == .) // when completing the panel if there are new dates the mar will be missing
bys academic_per emis: egen total_missing = sum(temp) // an academic period have 9 months
drop if total_missing == 9 // drop if always missing in academic year
drop if total_missing == 5 & academic_per == 1 //this academic period have only 5 months
drop if total_missing == 8 & academic_per == 8 //this academic period have only 8 months
drop temp total_missing

/* adjust variables to fill gaps

because we complete the panel, the variables for the new dates for each school are reported as
missing, then we impute the missings with the closest available data
*/
	
* adjust id variables
local vars original_mar original_district original_tehsil original_markaz original_wing district tehsil markaz wing mar
foreach v of local vars{
	bys emis academic_per (date_treat): egen temp = max(`v')
	replace `v' = temp if `v' == .
	drop temp
}


* for one observations there is a duplicate
/*
bys emis academic_per: egen nummars = nvals(mar)
bys emis academic_per: egen maxmar = max(mar) if nummars > 1
replace mar = maxmar if nummars > 1
drop nummars maxmar
*/

* adjust time variables
replace month = month(date_treat) if month == .
replace year = year(date_treat) if year == .

* adjust datapack
replace datapack = 1 if datapack == . & date_treat <= tm(2015m5)
replace datapack = 2 if datapack == . & date_treat > tm(2015m5) & date_treat <= tm(2016m12)
replace datapack = 3 if datapack == . & date_treat > tm(2016m12)

* adjust thresholds: all thresholds except from student attendance are constant
local thres green_tpres red_tpres green_fac red_fac green_advis red_advis green_eng red_eng green_math red_math green_urdu red_urdu
foreach i of local thres{
	egen temp = max(`i')
	replace `i' = temp if `i' == .
	drop temp
}

* all thresholds except from student attendance are constant
bys district datapack: egen temp = max(district_cat)
replace district_cat = temp if district_cat == .
drop temp

	*fix student attendance for each datapack
forvalues i = 1(1)3{
	
	if(`i' == 1){ // datapack 1
				
		*red threshold
		replace red_satt = 89 if (district_cat == 1 & (month > 11 | month < 4) & datapack == 1 & red_satt == .)
		replace red_satt = 87 if (district_cat == 1 & (month>=4 & month <= 11) & datapack == 1 & red_satt == .)
		replace red_satt = 87 if (district_cat == 2 & (month > 11 | month < 4) & datapack == 1 & red_satt == .)
		replace red_satt = 85 if (district_cat == 2 & (month >= 4 & month <= 11) & datapack == 1 & red_satt == .)
		replace red_satt = 84 if (district_cat == 3 & (month > 11 | month < 4) & datapack == 1 & red_satt == .)
		replace red_satt = 82 if (district_cat == 3 & (month >= 4 & month <= 11) & datapack == 1 & red_satt == .)
		
		*green threshold
		replace green_satt = 92 if (district_cat == 1 & (month > 11 | month < 4) & datapack == 1 & green_satt == .)
		replace green_satt = 90 if (district_cat == 1 & (month >= 4 & month <= 11) & datapack == 1 & green_satt == .)
		replace green_satt = 90 if (district_cat == 2 & (month > 11 | month < 4) & datapack == 1 & green_satt == .)
		replace green_satt = 88 if (district_cat == 2 & (month >= 4 & month <= 11) & datapack == 1 & green_satt == .)
		replace green_satt = 87 if (district_cat == 3 & (month > 11 | month < 4) & datapack == 1 & green_satt == .)
		replace green_satt = 85 if (district_cat == 3 & (month >= 4 & month <= 11) & datapack == 1 & green_satt == .)
		
		}	
	else if(`i' == 2){ // datapack 2
		
		*red thresholds
		replace red_satt = 88 if (district_cat == 1 & (month > 11 | month < 4)  & datapack == 2 & red_satt == .)
		replace red_satt = 86 if (district_cat == 1 & (month >= 4 & month <= 11) & datapack == 2 & red_satt == .)
		replace red_satt = 86 if (district_cat == 1 & ((year == 2016 & month == 12) | year > 2016) & datapack == 2 & red_satt == .)
		replace red_satt = 86 if (district_cat == 2 & (month > 11 | month < 4) & datapack == 2 & red_satt == .)
		replace red_satt = 84 if (district_cat == 2 & (month >= 4 & month <= 11) & datapack == 2 & red_satt == .)
		replace red_satt = 84 if (district_cat == 2 & ((year == 2016 & month == 12) | year > 2016) & datapack == 2 & red_satt == .)
		replace red_satt = 83 if (district_cat == 3 & (month > 11 | month < 4) & datapack == 2 & red_satt == .)
		replace red_satt = 81 if (district_cat == 3 & (month >= 4 & month <= 11) & datapack == 2 & red_satt == .)
		replace red_satt = 81 if (district_cat == 3 & ((year == 2016 & month == 12) | year > 2016) & datapack == 2 & red_satt == .)
		replace green_satt = 92 if datapack == 2 & green_satt == .
		replace red_satt = 88 if datapack == 2 & red_satt == .

		*green thresholds
		replace green_satt = 92 if (district_cat == 1 & (month > 11 | month < 4) & datapack == 2 & green_satt == .)
		replace green_satt = 90 if (district_cat == 1 & (month >= 4 & month <= 11) & datapack == 2 & green_satt == .)
		replace green_satt = 90 if (district_cat == 1 & ((year == 2016 & month == 12) | year > 2016) & datapack == 2 & green_satt == .)
		replace green_satt = 90 if (district_cat == 2 & (month > 11 | month < 4) & datapack == 2 & green_satt == .)
		replace green_satt = 88 if (district_cat == 2 & (month >= 4 & month <= 11) & datapack == 2 & green_satt == .)
		replace green_satt = 88 if (district_cat == 2 & ((year == 2016 & month == 12) | year > 2016) & datapack == 2 & green_satt == .)
		replace green_satt = 87 if (district_cat == 3 & (month > 11 | month < 4) & datapack == 2 & green_satt == .)
		replace green_satt = 85 if (district_cat == 3 & (month >= 4 & month <= 11) & datapack == 2 & green_satt == .)
		replace green_satt = 85 if (district_cat == 3 & ((year == 2016 & month == 12) | year > 2016) & datapack == 2 & green_satt == .)

		}
	else if(`i' == 3){ // datapack 3
		
		*green satt
		bys district datapack (date_treat): replace green_satt = green_satt[_n-1] if missing(green_satt)

		*red satt
		bys district datapack (date_treat): replace red_satt = red_satt[_n-1] if missing(red_satt)
	
	}
	
}

* order variables
order district tehsil markaz wing mar emis year month date_treat datapack green_tpres red_tpres ///
	green_satt red_satt green_fac red_fac green_advis red_advis green_eng red_eng green_math ///
	red_math green_urdu red_urdu

/*we still have to adjust all time varying continuous variables. For this we follow the same 
procedure as the mar id*/

rename satt_d students
rename satt_n presentstudents

* school level variables
global school_vars tot_eng cor_eng tot_math cor_math tot_urdu cor_urdu latitude longitude ///
	totalteachers present sanctionedleave examsduty trainingduty others latecommers ///
	school_head_name school_head_designation closed tpres fac advis satt school_eng ///
	school_math school_urdu students present students presentstudents
		
	* backward
global vars $school_vars
foreach v of global vars{
	
	bys academic_per emis (date_treat): replace `v' = `v'[_n-1] if missing(`v')
	
}
	
	*forward
foreach v of global vars{
	gen id = 1 // id for counting 
	forvalues i = 1(1)10{ //replace the maximum amount until no missings
		display id
		bys academic_per emis (date_treat): replace `v' = `v'[_n+1] if missing(`v')
		replace id = id + 1
	}
	drop id
}
	
* district level variables
global dis_vars district_tpres district_satt district_fac district_eng district_math district_urdu
foreach v of global dis_vars{
	
	bys academic_per district date_treat: egen temp = max(`v')
	replace `v' = temp if `v' == .
	drop temp
}

* district level variables - original assignment
global dis_vars original_district_tpres original_district_fac original_district_satt original_district_eng original_district_math original_district_urdu
foreach v of global dis_vars{
	
	bys academic_per original_district date_treat: egen temp = max(`v')
	replace `v' = temp if `v' == .
	drop temp
}

* tehsil level variables
global tehsil_vars tehsil_tpres tehsil_fac tehsil_satt tehsil_eng tehsil_math tehsil_urdu
foreach v of global tehsil_vars{
	
	bys academic_per tehsil date_treat: egen temp = max(`v')
	replace `v' = temp if `v' == .
	drop temp
}

* tehsil level variables - original assignment
global tehsil_vars original_tehsil_tpres original_tehsil_fac original_tehsil_satt original_tehsil_eng original_tehsil_math original_tehsil_urdu
foreach v of global tehsil_vars{
	
	bys academic_per original_tehsil date_treat: egen temp = max(`v')
	replace `v' = temp if `v' == .
	drop temp
}

* mar level variables
global mar_vars mar_tpres mar_satt mar_fac mar_eng mar_math mar_urdu
foreach v of global mar_vars{
	
	bys academic_per mar date_treat: egen temp = max(`v')
	replace `v' = temp if `v' == .
	drop temp
}

* mar level variables - original assignment
global mar_vars original_mar_tpres original_mar_fac original_mar_satt original_mar_eng original_mar_math original_mar_urdu
foreach v of global mar_vars{
	
	bys academic_per original_mar date_treat: egen temp = max(`v')
	replace `v' = temp if `v' == .
	drop temp
}

* drop unrequired variables 
drop _month_num month year //acad_year 

* create additional
replace original = 0 if original == .

*save
compress
save "$analysis/processed/cc_datapacks.dta", replace

}

*---------------------------------------------------------------------------------------------------
**# 6. fill missings as required #

if(1){
	
use "$analysis/processed/cc_datapacks.dta", clear

* ids -- ready
* original ids -- ready
local original district tehsil wing markaz mar
foreach v of local original{
	replace original_`v' = `v' if original_`v' == .
}

* flagging thresholds
replace green_satt = 85 if green_satt == .
replace red_satt = 81 if red_satt == .

* outcomes
global vars district_tpres district_satt district_fac district_eng district_math district_urdu ///
	original_district_tpres original_district_fac original_district_satt original_district_eng ///
	original_district_math original_district_urdu ///
	tehsil_tpres tehsil_fac tehsil_satt tehsil_eng tehsil_math tehsil_urdu ///
	original_tehsil_tpres original_tehsil_fac original_tehsil_satt original_tehsil_eng ///
	original_tehsil_math original_tehsil_urdu ///
	mar_tpres mar_satt mar_fac mar_eng mar_math mar_urdu ///
	original_mar_tpres original_mar_fac original_mar_satt original_mar_eng original_mar_math original_mar_urdu
	
	* backward
foreach v of global vars{
	bys academic_per emis (date_treat): replace `v' = `v'[_n-1] if missing(`v')	
}

* district level are ready, keep fixing tehsil and mar
global vars tehsil_tpres tehsil_fac tehsil_satt tehsil_eng tehsil_math tehsil_urdu ///
	original_tehsil_tpres original_tehsil_fac original_tehsil_satt original_tehsil_eng ///
	original_tehsil_math original_tehsil_urdu ///
	mar_tpres mar_satt mar_fac mar_eng mar_math mar_urdu ///
	original_mar_tpres original_mar_fac original_mar_satt original_mar_eng original_mar_math original_mar_urdu

	*forward
foreach v of global vars{
	gen id = 1 // id for counting 
	forvalues i = 1(1)10{ //replace the maximum amount until no missings
		display id
		bys academic_per emis (date_treat): replace `v' = `v'[_n+1] if missing(`v')		
		replace id = id + 1
	}
	drop id
}

*fix school level variables
global vars tot_eng tot_math tot_urdu cor_eng cor_math cor_urdu latitude longitude ///
	totalteachers present presentstudents sanctionedleave examsduty trainingduty ///
	others latecommers unauthorizedabsent fac advis students satt school_eng school_math school_urdu
	
	* backward: not limit to academic year - does not matter as we are observing schools
foreach v of global vars{
	bys emis (date_treat): replace `v' = `v'[_n-1] if missing(`v')	
}

	*forward: as much as possible
foreach v of global vars{
	gen id = 1 // id for counting 
	forvalues i = 1(1)10{ //replace the maximum amount until no missings
		display id
		bys emis (date_treat): replace `v' = `v'[_n+1] if missing(`v')		
		replace id = id + 1
	}
	drop id
}

* limit scores variables to the correct observations
local scores tot_eng tot_math tot_urdu cor_eng cor_math cor_urdu school_eng school_math school_urdu
foreach v of local scores{
	
	replace `v' = . if district_eng == .
}

* couple of adjustment that make sense
replace unauthorizedabsent = 0 if unauthorizedabsent < 0
replace original_mar_tpres = 100 if original_mar_tpres > 100
replace mar_tpres = 100 if mar_tpres > 100

bys emis: egen temp = max(longitude)
replace longitude = temp if longitude == .
drop temp

bys emis: egen temp = max(latitude)
replace latitude = temp if latitude == .
drop temp
	
* save
compress
save "$analysis/processed/cc_datapacks.dta", replace

}

*---------------------------------------------------------------------------------------------------
**# 7. assign flagging status #

/* We assign as flagged markaz/tehsil wing to those that lies below the variables threshold. Note 
that we should have done this in the beggining, but because we balanced the dataset, then we create 
the treatments in this step. Still, because of how the sampling was made and how we balanced the 
data, the inner structure of the treatment remains unchanged
*/

* assign flagging 
if(1){
	
*red flagging
local vars mar tehsil
foreach v of local vars{
	
	if("`v'" == "mar"){
		
		*markaz flagged var: tpres, satt and fac, which we observe for all the period of analysis
		foreach var in tpres satt fac{
			gen treat_`var'_ = mar_`var' < red_`var' 
			replace treat_`var'_ = . if mar_`var' == .  
			label variable treat_`var'_ "1 if mar's `var' is below threshold, 0 if not"	
			}     

		*markaz flagged var: english, math and urdu, which we observe since datapack 2 onwards
		foreach var in math eng urdu{
			gen treat_`var'_ = mar_`var' < red_`var' 
			replace treat_`var'_ = . if mar_`var' == .  
			label variable treat_`var'_ "1 if mar's `var' is below threshold, 0 if not"	
			}     
			
		*create leads for all the variables
				/*Note that the decision of flagging occurs in the moment t, when the mar variable 
				effectively lies below the threshold. Nevertheless, the real effect is observed one 
				period after, as is  the moment when the flagging gets "activated", or when the 
				consequences of flagging might be observed through punishment*/

		foreach var in treat_tpres_ treat_satt_ treat_fac_{
			/*if in the previous period mar was flagged, the mar is treated in t*/
			bys academic_per emis (date_treat): gen `var'lead = `var'[_n-1]
			replace `var'lead = 0 if `var'lead == .
			label var `var'lead "1 if last month `v' markaz below red threshold"
			}
			
		foreach var in treat_math_ treat_eng_ treat_urdu_{
			/*if in the previous period mar was flagged, the mar is treated in t*/
			bys academic_per emis (date_treat): gen `var'lead = `var'[_n-1]
			replace `var'lead = 0 if `var'lead == . & datapack > 1
			label var `var'lead "1 if last month `v' markaz below red threshold"
			}	

		*for each variable we define as 0 the values bafore the first datapacks
		local treat_vars treat_tpres_ treat_satt_ treat_fac_ treat_tpres_lead treat_satt_lead treat_fac_lead
		foreach v of local treat_vars{
			replace `v' = 0 if date_treat < tm(2011m12)
			}	
		
	}
	else if("`v'" == "tehsil"){
		
		*tehsil flagged var: tpres, satt and fac, which we observe for all the period of analysis
		foreach var in tpres satt fac{
			gen tehsil_treat_`var'_ = tehsil_`var' < red_`var' 
			replace tehsil_treat_`var'_ = . if tehsil_`var' == .  
			label variable tehsil_treat_`var'_ "1 if tehsil_'s `var' is below threshold, 0 if not"	
			}     

		*tehsil flagged var: english, math and urdu, which we observe since datapack 2 onwards
		foreach var in math eng urdu{
			gen tehsil_treat_`var'_ = tehsil_`var' < red_`var' 
			replace tehsil_treat_`var'_ = . if tehsil_`var' == .  
			label variable tehsil_treat_`var'_ "1 if tehsil's `var' is below threshold, 0 if not"	
			}     
			
		*create leads for all the variables
				/*Note that the decision of flagging occurs in the moment t, when the mar variable 
				effectively lies below the threshold. Nevertheless, the real effect is observed one 
				period after, as is the moment when the flagging gets "activated", or when the 
				consequences of flagging might be observed through punishment*/

		foreach var in tehsil_treat_tpres_ tehsil_treat_satt_ tehsil_treat_fac_{
			/*if in the previous period mar was flagged, the mar is treated in t*/
			bys academic_per emis (date_treat): gen `var'lead = `var'[_n-1]
			replace `var'lead = 0 if `var'lead == .
			label var `var'lead "1 if last month `v' tehsil below red threshold"
			}
			
		foreach var in tehsil_treat_math_ tehsil_treat_eng_ tehsil_treat_urdu_{
			/*if in the previous period mar was flagged, the mar is treated in t*/
			bys academic_per emis (date_treat): gen `var'lead = `var'[_n-1]
			replace `var'lead = 0 if `var'lead == . & datapack > 1
			label var `var'lead "1 if last month `v' tehsil below red threshold"
			}	

		*for each variable we define as 0 the values bafore the first datapacks
		local treat_vars tehsil_treat_tpres_ tehsil_treat_satt_ tehsil_treat_fac_ ///
			tehsil_treat_tpres_lead tehsil_treat_satt_lead tehsil_treat_fac_lead
		foreach v of local treat_vars{
			replace `v' = 0 if date_treat < tm(2011m12)
			}	
		
	}
	
}

*orange flagging
local vars mar tehsil
foreach v of local vars{
	
	if("`v'" == "mar"){
		
		*markaz flagged var: tpres, satt and fac, which we observe for all the period of analysis
		foreach var in tpres satt fac{
			gen or_treat_`var'_ = mar_`var' < green_`var' 
			replace or_treat_`var'_ = . if mar_`var' == .  
			label variable or_treat_`var'_ "1 if mar's `var' is below green threshold, 0 if not"	
			}     

		*markaz flagged var: english, math and urdu, which we observe since datapack 2 onwards
		foreach var in math eng urdu{
			gen or_treat_`var'_ = mar_`var' < green_`var' 
			replace or_treat_`var'_ = . if mar_`var' == .  
			label variable or_treat_`var'_ "1 if mar's `var' is below green threshold, 0 if not"	
			}     
			
		*create leads for all the variables
				/*Note that the decision of flagging occurs in the moment t, when the mar variable 
				effectively lies below the threshold. Nevertheless, the real effect is observed one 
				period after, as is  the moment when the flagging gets "activated", or when the 
				consequences of flagging might be observed through punishment*/

		foreach var in or_treat_tpres_ or_treat_satt_ or_treat_fac_{
			/*if in the previous period mar was flagged, the mar is treated in t*/
			bys academic_per emis (date_treat): gen `var'lead = `var'[_n-1]
			replace `var'lead = 0 if `var'lead == .
			label var `var'lead "1 if last month `v' markaz below red threshold"
			}
			
		foreach var in or_treat_math_ or_treat_eng_ or_treat_urdu_{
			/*if in the previous period mar was flagged, the mar is treated in t*/
			bys academic_per emis (date_treat): gen `var'lead = `var'[_n-1]
			replace `var'lead = 0 if `var'lead == . & datapack > 1
			label var `var'lead "1 if last month `v' markaz below red threshold"
			}	

		*for each variable we define as 0 the values bafore the first datapacks
		local treat_vars or_treat_tpres_ or_treat_satt_ or_treat_fac_ ///
			or_treat_tpres_lead or_treat_satt_lead or_treat_fac_lead
		foreach v of local treat_vars{
			replace `v' = 0 if date_treat < tm(2011m12)
			}	
		
	}
	else if("`v'" == "tehsil"){
		
		*tehsil flagged var: tpres, satt and fac, which we observe for all the period of analysis
		foreach var in tpres satt fac{
			gen or_tehsil_treat_`var'_ = tehsil_`var' < green_`var' 
			replace or_tehsil_treat_`var'_ = . if tehsil_`var' == .  
			label variable or_tehsil_treat_`var'_ "1 if tehsil_'s `var' is below green threshold, 0 if not"	
			}     

		*tehsil flagged var: english, math and urdu, which we observe since datapack 2 onwards
		foreach var in math eng urdu{
			gen or_tehsil_treat_`var'_ = tehsil_`var' < green_`var' 
			replace or_tehsil_treat_`var'_ = . if tehsil_`var' == .  
			label variable or_tehsil_treat_`var'_ "1 if tehsil's `var' is below green threshold, 0 if not"	
			}     
			
		*create leads for all the variables
				/*Note that the decision of flagging occurs in the moment t, when the mar variable 
				effectively lies below the threshold. Nevertheless, the real effect is observed one 
				period after, as is the moment when the flagging gets "activated", or when the 
				consequences of flagging might be observed through punishment*/

		foreach var in or_tehsil_treat_tpres_ or_tehsil_treat_satt_ or_tehsil_treat_fac_{
			/*if in the previous period mar was flagged, the mar is treated in t*/
			bys academic_per emis (date_treat): gen `var'lead = `var'[_n-1]
			replace `var'lead = 0 if `var'lead == .
			label var `var'lead "1 if last month `v' tehsil below red threshold"
			}
			
		foreach var in or_tehsil_treat_math_ or_tehsil_treat_eng_ or_tehsil_treat_urdu_{
			/*if in the previous period mar was flagged, the mar is treated in t*/
			bys academic_per emis (date_treat): gen `var'lead = `var'[_n-1]
			replace `var'lead = 0 if `var'lead == . & datapack > 1
			label var `var'lead "1 if last month `v' tehsil below red threshold"
			}	

		*for each variable we define as 0 the values bafore the first datapacks
		local treat_vars or_tehsil_treat_tpres_ or_tehsil_treat_satt_ or_tehsil_treat_fac_ ///
			or_tehsil_treat_tpres_lead or_tehsil_treat_satt_lead or_tehsil_treat_fac_lead
		foreach v of local treat_vars{
			replace `v' = 0 if date_treat < tm(2011m12)
			}	
		
	}
	
}

}

*---------------------------------------------------------------------------------------------------
**# 8. additional variables #

if(1){
	
*red flagging
local vars mar tehsil
foreach v of local vars{
	
	if("`v'" == "mar"){
		
		*define dates at which a treatment appear
		global treat_leads treat_tpres_lead treat_satt_lead treat_fac_lead treat_math_lead ///
			treat_eng_lead treat_urdu_lead
			
		foreach v of global treat_leads{
				gen `v'_dates = date_treat if `v' == 1
				label var `v'_dates "date when in last month `v' markaz below red threshold"		
			}

		* create variables for flagging history
			/*in some regression analysis we want to account for what happened with the flagging in 
			the periods before the flagging happen, then we calculate a measure of flagging history 
			equal to a set of collapsed dummies that indicate in which of the previous periods the 
			mar was flagged*/

		foreach v in tpres satt fac{
			*create flagging histories: maximum of 3 periods before the	flagging
			forvalues i = 1(1)3{
				bys emis (date_treat): gen `v'_flag`i' = treat_`v'_lead[_n-`i'-1]
				replace `v'_flag`i' = 0 if `v'_flag`i' == .
			}
				*group histories for various periods
				egen `v'_flag_hist_e = concat(`v'_flag1 `v'_flag2 `v'_flag3)
				
				*encode for memory and regression purposes
				encode `v'_flag_hist_e, gen(`v'_flag_hist)
				
				*drop no needed variables
				drop `v'_flag1 `v'_flag2 `v'_flag3 `v'_flag_hist_e
				
				*label variables
				label var `v'_flag_hist "`v' flagging history t-2 to t-4"
			}
			
		foreach v in math eng urdu{
			*create flagging histories: maximum of 3 periods before the	flagging
			forvalues i = 1(1)3{
				bys emis (date_treat): gen `v'_flag`i' = treat_`v'_lead[_n-`i'-1] if datapack > 1
				replace `v'_flag`i' = 0 if `v'_flag`i' == . &  datapack > 1
			}
				*group histories for various periods
				egen `v'_flag_hist_e = concat(`v'_flag1 `v'_flag2 `v'_flag3)
				
				*encode for memory and regression purposes
				encode `v'_flag_hist_e, gen(`v'_flag_hist)
				
				*drop no needed variables
				drop `v'_flag1 `v'_flag2 `v'_flag3 `v'_flag_hist_e
				
				*label variables
				label var `v'_flag_hist "`v' flagging history t-2 to t-4"
			}
		
	}	
	else if("`v'" == "tehsil"){
		
		*define dates at which a treatment appear
		global treat_leads tehsil_treat_tpres_lead tehsil_treat_satt_lead tehsil_treat_fac_lead ///
			tehsil_treat_math_lead tehsil_treat_eng_lead tehsil_treat_urdu_lead 	

		foreach v of global treat_leads{
				gen `v'_dates = date_treat if `v' == 1
				label var `v'_dates "date when in last month `v' tehsil below red threshold"		
			}

		* create variables for flagging history
			/*in some regression analysis we want to account for what happened with the flagging in 
			the periods before the flagging happen, then we calculate a measure of flagging history 
			equal to a set of collapsed dummies that indicate in which of the previous periods the 
			mar was flagged*/

		foreach v in tpres satt fac{
			*create flagging histories: maximum of 3 periods before the	flagging
			forvalues i = 1(1)3{
				bys emis (date_treat): gen `v'_flag`i' = tehsil_treat_`v'_lead[_n-`i'-1]
				replace `v'_flag`i' = 0 if `v'_flag`i' == .
			}
				*group histories for various periods
				egen `v'_flag_hist_e = concat(`v'_flag1 `v'_flag2 `v'_flag3)
				
				*encode for memory and regression purposes
				encode `v'_flag_hist_e, gen(tehsil_`v'_flag_hist)
				
				*drop no needed variables
				drop `v'_flag1 `v'_flag2 `v'_flag3 `v'_flag_hist_e
				
				*label variables
				label var tehsil_`v'_flag_hist "`v' flagging history t-2 to t-4"
			}
			
		foreach v in math eng urdu{
			*create flagging histories: maximum of 3 periods before the	flagging
			forvalues i = 1(1)3{
				bys emis (date_treat): gen `v'_flag`i' = tehsil_treat_`v'_lead[_n-`i'-1] if datapack > 1
				replace `v'_flag`i' = 0 if `v'_flag`i' == . &  datapack > 1
			}
				*group histories for various periods
				egen `v'_flag_hist_e = concat(`v'_flag1 `v'_flag2 `v'_flag3)
				
				*encode for memory and regression purposes
				encode `v'_flag_hist_e, gen(tehsil_`v'_flag_hist)
				
				*drop no needed variables
				drop `v'_flag1 `v'_flag2 `v'_flag3 `v'_flag_hist_e
				
				*label variables
				label var tehsil_`v'_flag_hist "`v' flagging history t-2 to t-4"
			}
	
		
	}

}

*orange flagging
local vars mar tehsil
foreach v of local vars{
	
	if("`v'" == "mar"){
		
		*define dates at which a treatment appear
		global treat_leads or_treat_tpres_lead or_treat_satt_lead or_treat_fac_lead or_treat_math_lead ///
			or_treat_eng_lead or_treat_urdu_lead
			
		foreach v of global treat_leads{
				gen `v'_dates = date_treat if `v' == 1
				label var `v'_dates "date when in last month `v' markaz below red threshold"		
			}

		* create variables for flagging history
			/*in some regression analysis we want to account for what happened with the flagging in 
			the periods before the flagging happen, then we calculate a measure of flagging history 
			equal to a set of collapsed dummies that indicate in which of the previous periods the 
			mar was flagged*/

		foreach v in tpres satt fac{
			*create flagging histories: maximum of 3 periods before the	flagging
			forvalues i = 1(1)3{
				bys emis (date_treat): gen `v'_flag`i' = or_treat_`v'_lead[_n-`i'-1]
				replace `v'_flag`i' = 0 if `v'_flag`i' == .
			}
				*group histories for various periods
				egen `v'_flag_hist_e = concat(`v'_flag1 `v'_flag2 `v'_flag3)
				
				*encode for memory and regression purposes
				encode `v'_flag_hist_e, gen(or_`v'_flag_hist)
				
				*drop no needed variables
				drop `v'_flag1 `v'_flag2 `v'_flag3 `v'_flag_hist_e
				
				*label variables
				label var or_`v'_flag_hist "`v' flagging history t-2 to t-4"
			}
			
		foreach v in math eng urdu{
			*create flagging histories: maximum of 3 periods before the	flagging
			forvalues i = 1(1)3{
				bys emis (date_treat): gen `v'_flag`i' = or_treat_`v'_lead[_n-`i'-1] if datapack > 1
				replace `v'_flag`i' = 0 if `v'_flag`i' == . &  datapack > 1
			}
				*group histories for various periods
				egen `v'_flag_hist_e = concat(`v'_flag1 `v'_flag2 `v'_flag3)
				
				*encode for memory and regression purposes
				encode `v'_flag_hist_e, gen(or_`v'_flag_hist)
				
				*drop no needed variables
				drop `v'_flag1 `v'_flag2 `v'_flag3 `v'_flag_hist_e
				
				*label variables
				label var or_`v'_flag_hist "`v' flagging history t-2 to t-4"
			}
		
	}	
	else if("`v'" == "tehsil"){
		
		*define dates at which a treatment appear
		global treat_leads or_tehsil_treat_tpres_lead or_tehsil_treat_satt_lead or_tehsil_treat_fac_lead ///
			or_tehsil_treat_math_lead or_tehsil_treat_eng_lead or_tehsil_treat_urdu_lead 	

		foreach v of global treat_leads{
				gen `v'_dates = date_treat if `v' == 1
				label var `v'_dates "date when in last month `v' tehsil below red threshold"		
			}

		* create variables for flagging history
			/*in some regression analysis we want to account for what happened with the flagging in 
			the periods before the flagging happen, then we calculate a measure of flagging history 
			equal to a set of collapsed dummies that indicate in which of the previous periods the 
			mar was flagged*/

		foreach v in tpres satt fac{
			*create flagging histories: maximum of 3 periods before the	flagging
			forvalues i = 1(1)3{
				bys emis (date_treat): gen `v'_flag`i' = or_tehsil_treat_`v'_lead[_n-`i'-1]
				replace `v'_flag`i' = 0 if `v'_flag`i' == .
			}
				*group histories for various periods
				egen `v'_flag_hist_e = concat(`v'_flag1 `v'_flag2 `v'_flag3)
				
				*encode for memory and regression purposes
				encode `v'_flag_hist_e, gen(or_tehsil_`v'_flag_hist)
				
				*drop no needed variables
				drop `v'_flag1 `v'_flag2 `v'_flag3 `v'_flag_hist_e
				
				*label variables
				label var or_tehsil_`v'_flag_hist "`v' flagging history t-2 to t-4"
			}
			
		foreach v in math eng urdu{
			*create flagging histories: maximum of 3 periods before the	flagging
			forvalues i = 1(1)3{
				bys emis (date_treat): gen `v'_flag`i' = or_tehsil_treat_`v'_lead[_n-`i'-1] if datapack > 1
				replace `v'_flag`i' = 0 if `v'_flag`i' == . &  datapack > 1
			}
				*group histories for various periods
				egen `v'_flag_hist_e = concat(`v'_flag1 `v'_flag2 `v'_flag3)
				
				*encode for memory and regression purposes
				encode `v'_flag_hist_e, gen(or_tehsil_`v'_flag_hist)
				
				*drop no needed variables
				drop `v'_flag1 `v'_flag2 `v'_flag3 `v'_flag_hist_e
				
				*label variables
				label var or_tehsil_`v'_flag_hist "`v' flagging history t-2 to t-4"
			}
	
		
	}

}

}

*---------------------------------------------------------------------------------------------------
**# 9. additional data considerations #

if(1){

* gen lagged values of outcomes
global treatments tpres satt fac
foreach v of global treatments{
	
	bys emis (date_treat): gen `v'_lag_1 = `v'[_n-1]
	bys emis (date_treat): gen `v'_lag_2 = `v'[_n-2]
	bys emis (date_treat): gen `v'_lag_3 = `v'[_n-3]
	
}

* last id for tehsil: tehsil wing
egen tehsilwing = group(tehsil wing)

* create year and month
gen year = year(dofm(date_treat))
gen month = month(dofm(date_treat))

* save
compress
save "$analysis/processed/cc_datapacks.dta", replace

}

*---------------------------------------------------------------------------------------------------
**# 10. head teacher data #

/*so far we have been cleaning the main data, nevertheless there is still additional information that 
might be useful for other analysis, such aas the head teachers for each school. This is text data 
collected by each MEA by hand, then as ther is no unique id for each ehad teacher, require some text 
mining and assumptions in how the head teachers are distributed. We use some proximity measures to 
assign similar names as the same head teacher if it is in the same geographic area */

if(1){
	
use "$analysis/processed/cc_datapacks.dta", clear

*keep desired variables
	/*school id and dates, head teacher identifiers, geographic information: same name can appear 
	in multiple locations*/
keep emis year month school_head_name school_head_phone school_head_designation ///
	district tehsil markaz wing
		
*forloop to better control the changes in the data (and for a cleaner code)
local vars phone name additional 
foreach v of local vars{ // note it loops in order of the local variables
	
	if("`v'" == "phone"){
		
		*cleaning phone number:
			*we do not have the head teacher id, so we standardize name by the same contac numbers
		gen school_head_phone_num = subinstr(school_head_phone, "-", "", .)
		replace school_head_phone_num = subinstr(school_head_phone_num, " ", "", .)
		replace school_head_phone_num = subinstr(school_head_phone_num, ".", "", .)
		replace school_head_phone_num = subinstr(school_head_phone_num, "+", "", .)
		replace school_head_phone_num = subinstr(school_head_phone_num, "|", "", .)
		replace school_head_phone_num = subinstr(school_head_phone_num, "*", "", .)
		replace school_head_phone_num = subinstr(school_head_phone_num, "`", "", .)
		replace school_head_phone_num = subinstr(school_head_phone_num, "'", "", .)
		replace school_head_phone_num = subinstr(school_head_phone_num, "/", "", .)
		replace school_head_phone_num = subinstr(school_head_phone_num, "\", "", .)
		replace school_head_phone_num = subinstr(school_head_phone_num, "ATTOCK", "", .)
		replace school_head_phone_num  = "" if school_head_phone_num  == "NULL"
		replace school_head_phone_num  = "" if school_head_phone_num  == "0"
		destring school_head_phone_num, replace force
		recast long school_head_phone_num
		format %20.0g school_head_phone_num
		replace school_head_phone_num  = . if school_head_phone_num  < 1000	
		
	}
	else if("`v'" == "name"){
		
		*cleaning name
			/*we do further cleaning of names to try an fuzzy name matching to go deeper in name 
			standarization*/

				* symbols cleaning
		replace school_head_name = subinstr(school_head_name, "]", "", .)
		replace school_head_name = subinstr(school_head_name, "[", "", .)
		replace school_head_name = subinstr(school_head_name, "-", "", .)
		replace school_head_name = subinstr(school_head_name, ".", "", .)
		replace school_head_name = subinstr(school_head_name, ",", "", .)
		replace school_head_name = subinstr(school_head_name, "/", "", .)
		replace school_head_name = subinstr(school_head_name, "\", "", .)
		replace school_head_name = subinstr(school_head_name, "*", "", .)
		replace school_head_name = subinstr(school_head_name, "(", "", .)
		replace school_head_name = subinstr(school_head_name, ")", "", .)
		replace school_head_name = subinstr(school_head_name, "+", "", .)
		replace school_head_name = subinstr(school_head_name, "`", "", .)
		replace school_head_name = subinstr(school_head_name, "'", "", .)
		replace school_head_name = subinstr(school_head_name, ";", "", .)
		replace school_head_name = subinstr(school_head_name, "?", "", .)
		replace school_head_name = subinstr(school_head_name, "SCHOOL NOT FOUND", "", .)

				* number cleaning
		local numbers 0 1 2 3 4 5 6 7 8 9
		foreach n of local numbers{
			replace school_head_name = subinstr(school_head_name, "`n'", "", .)
			}

				* white spaces clenaing
		replace school_head_name = subinstr(school_head_name, "  ", " ", .)
		replace school_head_name = strtrim(school_head_name)
		replace school_head_name = stritrim(school_head_name)
		replace school_head_name = strltrim(school_head_name)
		replace school_head_name = strrtrim(school_head_name)
		replace school_head_name = ustrtrim(school_head_name)
		replace school_head_name = ustrltrim(school_head_name)
		replace school_head_name = ustrrtrim(school_head_name)
		drop if school_head_name == ""

				* letters cleaning
		local letters A B C D E F G H I J K L M N O P Q R S T U V W X Y Z 
		foreach l of local letters{
			replace school_head_name = subinstr(school_head_name, "`l'`l'", "`l'", .)
			}
			
		replace school_head_name = subinstr(school_head_name, "SH", "S", .)
		replace school_head_name = subinstr(school_head_name, "JAM ", "", .)
		replace school_head_name = subinstr(school_head_name, "MRS", "", .)
		replace school_head_name = subinstr(school_head_name, "MR ", "", .)
		replace school_head_name = subinstr(school_head_name, "M ", "", .)
		replace school_head_name = subinstr(school_head_name, "CH ", "", .)

		local letters A B C D E F G H I J K L M N O P Q R S T U V W X Y Z 
		foreach l of local letters{
					/*because of very repetitive names that starts with M, there are lot of mistakes.
					To avoid these, replace all M combinations, do not affect structure of names*/
			replace school_head_name = subinstr(school_head_name, "M`l'", "`l'", .)
			}
			
				* white spaces cleaning 2
		replace school_head_name = strtrim(school_head_name)
		drop if school_head_name == ""

		
	}
	else if("`v'" == "additional"){
		
		* assign first name that appears for the same phone number: standardize names
		bys emis school_head_phone_num (year month district tehsil markaz wing school_head_name school_head_designation): gen id = _n
		bys emis school_head_phone_num (year month district tehsil markaz wing school_head_name school_head_designation): gen temp = school_head_name if id == 1
		bys emis school_head_phone_num (id): replace temp = temp[1] if temp == ""

		* create name without whitespaces
		drop id
		rename temp new_head_name
		gen head_name = subinstr(new_head_name, " ", "", .)

		* create geocode variable: identify names in the same geographic area
		egen geo = concat(district tehsil markaz)
		encode geo, gen(geocode)

		tempfile temp_names_dup
		save `temp_names_dup'

	}

}

* adjust new names
	/*note that until here i standardize teachar names based on telephone number, still, most of the
	names might be not well written, hence, we require more effort*/
use `temp_names_dup', clear //produced from the previous loop

* duplicates drop new_head_name district tehsil markaz, force //note there exist geographic dispersion
duplicates drop new_head_name head_name district tehsil markaz geocode, force

* drop not wanted names
split new_head_name, gen(name)

* there are a lot of places where there are no head teachers
drop if name1 == "SCHOOL" | name1 == "TEACHER" | name1 == "THERE" 
drop if name2 == "STAFF"

* create first name 
rename name1 first_name
	
* create lastname
rename name2 last_name
replace last_name = first_name if last_name == ""
	
* drop not required variables
drop name*
	
* drop unwanted variables
keep head_name first_name last_name district tehsil markaz geocode
	
* eliminate white spaces
duplicates drop head_name first_name last_name district tehsil markaz geocode, force

tempfile temp_dup_group
save `temp_dup_group'

/*we know implement the jaro wrinkler proximity for fuzzy matching of text chains. To make it 
tighter we create the jaro wrinkler measures and match it based on geographic aspects, first name, 
last name and full name */
					
use `temp_dup_group', clear

* identify for each observation potential matches based on same district tehsil and same first letter
drop district tehsil markaz
gen f_first = substr(first_name, 1, 1)
gen f_last = substr(last_name, 1, 1)
duplicates drop head_name geocode, force

* create a tempfile for merging
preserve
rename head_name head_name2
rename first_name first_name2
rename last_name last_name2
tempfile temp
save `temp'
restore 

/* merging with potential pairwise matches: merge such that each observation have its own potential 
matches*/	
joinby geocode f_first f_last using `temp', unmatched(master)

* calculate distances for fuzzy matching using jarowinkler
jarowinkler head_name head_name2, gen(jaro_head)
jarowinkler first_name first_name2, gen(jaro_first)
jarowinkler last_name last_name2, gen(jaro_last)

* order variables
order head_name head_name2 jaro_head first_name first_name2 jaro_first last_name last_name2 jaro_last

* keep only very close matches
keep if jaro_head >= 0.9 & jaro_first >= 0.9 & jaro_last >= 0.9

* keep ids
keep head_name head_name2 geocode
rename head_name head_name1
gen long new_id = _n
reshape long head_name, i(new_id geocode) j(n)

* group by main id variables
group_id new_id , matchby(head_name geocode)	

* obtain unique identifiers for merging with main
duplicates drop new_id head_name geocode, force //decrease from 60 thousand to 20 thousand

* merge with main data
merge 1:m head_name geocode using `temp_names_dup'
drop if _merge == 2
drop _merge

* keep only desired variables
keep emis new_id month year geocode 
rename new_id school_head_name
gen date_treat = ym(year, month)
format date_treat %tm

/*after having the ids for head teachers, we create additional variables to merge it with 
the main data */

* calculate change of teacher
bys emis (date_treat): gen change_teacher = (school_head_name != school_head_name[_n-1])
bys emis (date_treat): gen time = _n
replace change_teacher = 0 if time == 1
drop time

* calculate change of school
bys school_head_name (date_treat emis): gen change_school = (emis != emis[_n-1])
bys school_head_name (date_treat emis): gen time = _n
replace change_school = 0 if time == 1
drop time

* merge with original data for outcomes
preserve
use "$analysis/processed/cc_datapacks.dta", clear
drop school_head_name
tempfile temp
save `temp'
restore

merge 1:1 emis date_treat using `temp'
drop _merge

* rename 
rename school_math math
rename school_eng eng
rename school_urdu urdu

* save data

save "$analysis/processed/cc_datapacks.dta", replace

}




