/*--------------------------------------------------------------------------------------------------
Bulding datasets

For buiding our IV dataset at the year level we first need to know the flagging and bandwidth 
thresholds for each month of each year. The stacking helps us with this. In essence, the stacking allow 
us to have, for each event (month) the flagged and non-flagged units, so we can identify all the information 
required for each case of flagging.

We need to consider that the stacking (for diff-in-diff) we need to ensure clean controls, so forcing the 
comparisson for units that in the pre-periods were not flagged. To ensure we are using all possible events we 
will create an stacked dataset that does not force for clean controls, but allow us to have flagging in the pre-periods 
to the event in which each stack is based on.  

	Outline

	1. markaz red flagging with flagging history --> allow us to build the IV datasets. The stacked data is used for robustness in appendix D 
	2. school by school year panel dataset --> IV for main analysis
	3. markaz by school year panel dataset --> IV for balance and assumptions

	Additional stacked datsets 

	4. markaz red flagging --> section 6 and appendix D main dataset
	5. markaz orange flagging stacking --> robustness
	6. tehsil red flagging stacking --> robustness
	
	
stacking notes:

note 1: the stacking requires defining arbitrarily pre/post periods, thus, any change in the 
        number of periods would require a new dataset
note 2: because the stacking is based in events where units are treated, and we have treatment 
        (flagging) for each outcome, we need to build an stacked dataset for each outcome

- our main specification will use 4 pre-periods and 7 post-periods. We will obtain stacked datasets 
  for all post periods after the punishment phase
- we will build for each stacked dataset an indicator for threshold sample (with rd procedures)
--------------------------------------------------------------------------------------------------*/
*
*
*
*
*
*---------------------------------------------------------------------------------------------------
**# 1. markaz red flagging with flagging history #

/* we allow to units to be treated before our main event*/

//1. create event panel
//2. create and adjust event-panel: threshold sample, additionales variables
local treatments tpres satt fac eng math urdu // all flagging outcomes
foreach v of local treatments{
	
	*iterate over all possible post-periods
	
	forvalues i = 5(1)5{ // only run for the full set of post periods
		
		* trick for later create empty temporary file to apend all other evet-panels
		
		clear		
		gen stack = 0
		tempfile stack
		save `stack'
		
		* main data: balanced dataset
		
		use "$analysis/processed/cc_datapacks.dta", clear
		drop if wing == 3 // we do not consider secondary schools (not subject to monitoring)
		
		/* create time id: date version has gaps between may and september. The new variable takes 
		continuous values since 1, hence, there is no gap
		*/
		
		egen date_treat_e = group(date_treat) // date indicator for iterations

		* validate mar with double assignment of flagging
		
		gen copy = treat_`v'_lead // create a copy of the original variable
		bys mar date_treat: egen templead = nvals(treat_`v'_lead) //some obs with double accounting
		bys mar date_treat: egen temp = nvals(treat_`v'_) // original date is correct
		bys mar (date_treat `v' emis): gen t = treat_`v'_[_n-1] // update flagging
		bys mar date_treat (`v' emis): gen tord = _n // set order based on `v'
		replace t = . if tord != 1 // set to missing all except the immediatly before observation for each mar
		bys mar date_treat: egen tmax = max(t) // generalize flagging
		replace treat_`v'_lead = tmax if templead == 2 // apply only to those needed to be adjusted
		replace treat_`v'_lead = copy if templead == 2 & treat_`v'_lead == . // missing replace with original
		drop templead temp t tord tmax copy
		
		* still double accounting, basically from schools changing mar into a new mar
		* define as the majority of schools reporting (less than 1% so no sensitive)
		bys mar date_treat: egen templead = nvals(treat_`v'_lead) //some obs with double accounting
			*count ones and zeroes
		gen zero = 1 if templead == 2 & treat_`v'_lead == 0
		gen ones = 1 if templead == 2 & treat_`v'_lead == 1
		bys mar date_treat: egen numzeros = sum(zero) if templead == 2
		bys mar date_treat: egen numones = sum(ones) if templead == 2
		replace treat_`v'_lead = 0 if numzeros > numones & templead == 2
		replace treat_`v'_lead = 1 if numzeros <= numones & templead == 2
		
		drop zero ones numzeros numones templead
				
		* keep unique mar and date_treat

		*duplicates drop mar date_treat, force // this way of dropping duplicates might be unstable
		* stable solution to drop duplicates
		sort mar date_treat treat_`v'_lead `v' emis
		gen random = runiform() // generate random variable (note the seed in 0_setup)
		sort mar date_treat treat_`v'_lead `v' emis random
        bys mar date_treat (treat_`v'_lead `v' emis random): gen ord = _n // ordering
		keep if ord == 1
		drop random ord
		
		keep mar date_treat date_treat_e mar_`v' treat_`v'_lead red_`v'

		* define dates at which a treatment will be stackedators by which 

		gen treat_dates = date_treat_e if ((treat_`v'_lead == 1) & date_treat > tm(2011m12)) // 2011m12 first flag, but we are using as event the lead

		/* we define datasets for each date where a flag ocurred, so the flag date is the center of 
		each event-data. Note also that date_treat_e correspond to the relative time 1 (punish), 
		then we always will have date_treat_e - 5 to have preperiods (-1, -2, -3, -4) and 0 (flag). 
		We are only changing t based on the post periods, where the minimum is date_treat_e + 1 
		*/

		display("starting variable `v' time `i'")

		* iterate creation of event-panels 
		levelsof treat_dates
		foreach d in `r(levels)'{ 
			
			preserve
			
			*dataset between t+i to t-5 
			
			keep if ((date_treat_e <= `d' + `i') & (date_treat_e >= `d' - 5)) // keep desired time span
			
			*drop if mar outcome is empty
			
			drop if missing(mar_`v')
			
			*adjust treatment in case of missings
			
			bys mar (date_treat): replace treat_`v'_lead = treat_`v'_[_n-1] if missing(treat_`v'_lead)
			
			*drop units that do not have t and t-1
			
			bys mar: egen num_mar = count(mar) //count number of times mar appear
			gen num_periods = 6 + `i' // markaz that appear consecutively 6 + i periods
			keep if num_mar == num_periods // only mars that appear all the time span
			drop num_periods num_mar

			*conditional if exist data
			
			if(_N > 0){
				
				bys mar (date_treat): gen time_id = _n // create time id
					
				/* in the previous section we droppe units treated before our main event, here we 
				keep them and allow for flagging history fixed effects
				*/
									
				*if there still exist data: dropping treated before might lead to no-data for event
				if(_N > 0){
						
					/*if treated in t+1 but not in t, we must drop, as would not be treated in 
					the main event data we are centering the event-data
					*/
						
					*treated in t+1
					gen stag1 = ((treat_`v'_lead == 1) & (time_id > 6))
						
					*treated in t
					gen stag2 = ((treat_`v'_lead == 1) & (time_id == 6))
						
					*generalizing to all units
					
					bys mar: egen sum_stag1 = max(stag1)
					bys mar: egen sum_stag2 = max(stag2)

					*drop not treated in main event
					
					gen drop_units = (sum_stag2 == 0 & sum_stag1 == 1) // not treated in t, but treated in t+1
					drop if drop_units == 1
					drop stag1 stag2 sum_stag1 sum_stag2 drop_units
						
					*stack unique id
					
					gen stack = `d'
					drop time_id
					bys mar (date_treat): gen time_id = _n // readjust timeid
					
					
				} // end if statement
				else if(_N == 0){ // if there is no data after dropping the not clean controls
						
					*display if no observations
					display "`d' have 0 observations"
						
				} // end else statement 
			
			} // end if statement
			else if(_N == 0){ // if there is no data for the particular event date
				
				*display if no observations
				display "`d' have 0 observations"

			} // end else statement
			
			*append evet-panel datatsets
			append using `stack' // append to original stack! then for next iterations we rewritte
			tempfile stack
			save `stack'
				
			restore // recover original data to create the next event time panel
		
		} // end of loop statement for event panels of outcomes
		
		* use temporary stacked dataset
		
		use `stack', clear
		
		* drop "temporary file stack"

		drop if stack == 0

		* compress for memory purposes

		compress

		* relative time: normalize to 0 the flag period (time_id == 5)
		
		gen relativetime = time_id - 5

		/* create constant treatment variable: if flag_period = 1 in relativetime == 1 to validate, 
		recreate main treatment
		*/
		
		bys stack mar: gen temp_lead = ((treat_`v'_lead == 1) & (time_id == 6))
		bys stack mar: egen flagged = max(temp_lead) //if ever flagged, then treated
		drop temp_lead
		drop if missing(flagged) // drop all the observations that do not report data en the flagging period

		* post-periods
		
		//after punish period
		gen postpunish = (relativetime > 0)
		//after flag period
		gen postflag = (relativetime > -1)
 
		/* regression discontinuity samples:
		
		we need a tighter comparisson of treated and control units, then we use an optimal bandwidth 
		to define for each event-dataset the group of markaz that are around the threshold
		*/
		
		*define thresholds: scores have the same threshold and for student attendance need to defined it separately
		
		if("`v'" == "tpres"){
			local thres = 86
			local min = 86
		}
		else if("`v'" == "fac"){
			local thres = 90
			local min = 87 // for functional facilities there is less variation, then being close to 90 is not enough
		}
		else{
			local thres = 70
			local min = 70
		}
		
		*run rd 
		
		if("`v'" != "satt"){
			
			preserve
			
			*keep event mar relative time and variable of interest
			
			keep stack mar relativetime mar_`v'
			
			/*for the rd we need to compare the flagging period (relative time 0) with the period of 
			the punishment (relative time 1). Then we create the lag of the markaz variable for 1, 
			to have both values of 1 and 0 in the  same row*/
			
			gen temp = mar_`v' if relativetime == 0
			bys stack mar (relativetime): egen mar_`v'_lag0 = max(temp) // period 0 outcome
			drop temp
			
			*keep only the iterest relative time
			
			keep if relativetime == 1 // so compare outcome in 1 with just created outcome in 0
			drop relativetime
			
			*create variables to populate
			
			gen bw1 = .
			gen bias1 = .
			
			* estimate rd: we have to iterate over each event dataset
			
			levelsof stack // all possible event-dates 
			foreach d in `r(levels)'{
				
				display `d'
				qui sum mar_`v'_lag0 if stack == `d'
				*conditions to ensure if threshold sample exist

				if((`r(min)' < `min' & `r(N)' > 50 & "`v'" == "tpres" & `d' != 43)     | /// general conditions
				   (`r(min)' < `min' & `r(N)' > 50 & "`v'" == "fac"              )     | /// general conditions
				   (`r(min)' < `min' & `r(N)' > 50 & "`v'" == "eng"              )     | /// conditions for math
				   (`r(min)' < `min' & `r(N)' > 50 & "`v'" == "math"  & `d' != 48)     | /// conditions for math
				   (`r(min)' < `min' & `r(N)' > 50 & "`v'" == "urdu"  & `d' != 47)       /// conditions for urdu
				  ){ // set up conditions for events that have enough obs (fix some urdu problems)
					
					*run the optimal bandwidth selection: Cattaneo and Calonico
					
					rdbwselect mar_`v' mar_`v'_lag0 if stack == `d', ///
						c(`thres') p(2) q(3) kernel(triangular) bwselect(mserd) vce(cluster mar) all
					
					if(`e(h_mserd)' < `e(b_mserd)'){ //if effectively exist a bandwidth
						
						*calculate auxiliary variables
						
						replace bw1 = `e(h_cercomb1)' if stack == `d'
						replace bias1 = `e(b_cercomb1)' if stack == `d'
						
					} // end of if statement of existance of bandwidth
				
				} // end of if statament of existance of rd for each stack

			} // end of loop over stacks for rd procedure
			
			* variables for rd samples	
			
			gen rd1 = (mar_`v'_lag0 >= `thres' - bw1 & mar_`v'_lag0 <= `thres' + bw1 & !missing(bw1)) 
			gen biasrd1 = (mar_`v'_lag0 >= `thres' - bias1 & mar_`v'_lag0 <= `thres' + bias1 & !missing(bw1))

			
		} //  end if statement for all except student attendance
		else{ // because student attendance threshold is not constant, need to recenter to 0	
		
			/*for student attendance the thresholds change in time, then we have to normalize 
			threshold to 0*/
			
			preserve
			
			*keep event mar relative time and variable of interest
			
			keep stack mar relativetime mar_`v' red_`v'
			
			/*for the rd we need to compare the flagging period (relative time 0) with the period of 
			the punishment (relative time 1). Then we create the lag of the markaz variable for 1, 
			to have both values of 1 and 0 in the  same row*/
			
			gen temp = mar_`v' if relativetime == 0
			bys stack mar (relativetime): egen mar_`v'_lag0 = max(temp) // period 0 outcome
			drop temp
			
			*keep only the iterest relative time
			
			keep if relativetime == 1 // so compare outcome in 1 with just created outcome in 0
			drop relativetime
			
			*create variables to populate
			
			gen bw1 = .
			gen bias1 = .

			* need to center as in satt thresholds are not constant
			
			gen c_mar_`v' = mar_`v' - red_`v'
			gen c_mar_`v'_lag0 = mar_`v'_lag0 - red_`v'
			
			* estimate rd: we have to iterate over each event dataset
			
			levelsof stack // all possible event-dates 
			foreach d in `r(levels)'{

				qui sum c_mar_`v'_lag0 if stack == `d'
				if(`r(min)' < -2 &  `r(N)' > 50 ){ // from 0 to -2 to avoid conformability error
					
					*run the optimal bandwidth selection: Cattaneo and Calonico
					
					rdbwselect c_mar_`v' c_mar_`v'_lag0 if stack == `d', ///
						c(0) p(2) q(3) kernel(triangular) bwselect(mserd) vce(cluster mar) all
						
					if(`e(h_mserd)' < `e(b_mserd)'){
						
						*calculate auxiliary variables
						replace bw1 = `e(h_cercomb1)' if stack == `d'
						replace bias1 = `e(b_cercomb1)' if stack == `d'
						
					} // end of if statement of existance of bandwidth
					
				} // end of if statament of existance of rd for each stack

			} // end of loop over stacks for rd procedure
			
			*variables for samples	
			
			gen rd1 = (c_mar_`v'_lag0 >= 0 - bw1 & c_mar_`v'_lag0 <= 0 + bw1 & !missing(bw1)) 
			gen biasrd1 = (c_mar_`v'_lag0 >= 0 - bias1 & c_mar_`v'_lag0 <= 0 + bias1 & !missing(bw1))
		
		} //  end else statement for student attendance
		
		* save tempfile
		
		keep stack mar rd1 biasrd1 bw1 bias1
		tempfile rd_sample
		save `rd_sample'
		restore //note the preserve for this restore is within the rd procedure
		
		*merge it with the original stacked data
		
		merge m:1 stack mar using `rd_sample'
		
		* keep desired observations
		
		keep if _merge == 3
		drop _merge

		* merge with original: all schools per mar and date

		joinby mar date_treat using "$analysis/processed/cc_datapacks.dta"

		* mean teachers per markaz
		gen temp = totalteachers if relativetime < 0
		bys stack mar: egen avg_totalreportedteachers_mar = mean(temp) 
		drop temp

		* save
	
		save "$analysis/processed/stacked/cc_stackdata`i'_`v'_flaghist.dta", replace // i = post period, v = outcome
	
		display("finish variable `v' with post periods `i'")

	} // end loop statement for post period i
	
	*after the last `i' post period, it starts again for the next variable v
	display("finish variable `v', pasing to the next one")

} // end loop statement for all variables

*---------------------------------------------------------------------------------------------------
**# 2. school by school year panel dataset #

/* we aggregate the school by month data at the school by school year level. We do so by averaging the
outcomes over the school year, so each shcool has an average yearly performance. For the flagging 
measure, we count the number of times an school was in a flagged markaz in a school year*/

if(1){
	
use "$analysis/processed/cc_datapacks.dta", clear
drop if wing == 3 // we do not consider secondary schools (not subject to monitoring)
	
*need to create dataset with thresholds for each variable/date
local vars tpres satt fac eng math urdu
foreach yvar of local vars{
		
preserve
		 
use "$analysis/processed/stacked/cc_stackdata5_`yvar'_flaghist.dta", clear

keep if relativetime == 0
keep if rd1 == 1
keep date_treat bw
sort date_treat bw
gen random = runiform()
sort date_treat bw random
bys date_treat bw (random): gen ord = _n
keep if ord == 1
drop random ord
tempfile temp
save `temp'
		
restore
		
merge m:1 date_treat using `temp'
drop _merge
rename bw1 bw`yvar'

}

*gen year census --> the same as school year
if(1){
gen     yearcensus = 2011 if (date_treat >= tm(2010m9) & date_treat <= tm(2011m5))
replace yearcensus = 2012 if (date_treat >= tm(2011m9) & date_treat <= tm(2012m5))
replace yearcensus = 2013 if (date_treat >= tm(2012m9) & date_treat <= tm(2013m5))
replace yearcensus = 2014 if (date_treat >= tm(2013m9) & date_treat <= tm(2014m5))
replace yearcensus = 2015 if (date_treat >= tm(2014m9) & date_treat <= tm(2015m5))
replace yearcensus = 2016 if (date_treat >= tm(2015m9) & date_treat <= tm(2016m5))
replace yearcensus = 2017 if (date_treat >= tm(2016m9) & date_treat <= tm(2017m5))
replace yearcensus = 2018 if (date_treat >= tm(2017m9) & date_treat <= tm(2018m5))

}

*create flagged
local vars tpres satt fac eng math urdu
foreach yvar of local vars{
	
	gen flag`yvar' = treat_`yvar'_
	
}

*create flagged in threshold sample
local vars tpres satt fac eng math urdu
foreach yvar of local vars{
	
	gen lowthres = red_`yvar' - bw`yvar'
	gen flag`yvar'_thres = (mar_`yvar' < red_`yvar' & mar_`yvar' >= lowthres & flag`yvar' == 1)
	drop lowthres
	
}

*create in threshold sample
local vars tpres satt fac eng math urdu
foreach yvar of local vars{
	
	gen lowthres = red_`yvar' - bw`yvar'
	gen highthres = red_`yvar' + bw`yvar'
	gen thres`yvar' = (mar_`yvar' >= lowthres & mar_`yvar' <= highthres & date_treat >= tm(2011m12))
	drop lowthres highthres
	
}
	
local vars flagmath flageng flagurdu flagmath_thres flageng_thres flagurdu_thres thresmath threseng thresurdu math eng urdu
foreach v of local vars{
	
	replace `v' = . if year < 2016
}

* create dummies for flagged in each month
local vars tpres satt fac eng math urdu
foreach yvar of local vars{

	forvalues i=1(1)12{
		
		bys mar year: gen flagmonth`yvar'`i' = (flag`yvar'_thres == 1 & month == `i')
		bys mar year: gen thresmonth`yvar'`i' = (thres`yvar' == 1 & month == `i')
		bys mar year: gen bw`yvar'`i' = bw`yvar' if month == `i'
		
	}
}

*merge with other datasets
if(1){
	
* financial variables
merge m:1 emis yearcensus using "$data/cc_budget.dta"
drop if _merge == 2
drop _merge

* district ranking
preserve
use "$analysis/data/ranking", replace
gen quarterly_meet = 1 // date of meeting
drop district_bottom district_top
gen district_bottom = (rank_position < 6) // bottom 5
gen district_top = (rank_position > 31) // top 5
tempfile rank
save `rank'
restore

merge m:1 district date_treat using `rank' // merge main with rankings data
drop if _merge == 2
drop _merge

*political alignment
merge m:1 emis using "$data/political_alignment"
drop if _merge == 2
drop _merge
bys mar: egen tempmax = max(samewin)
bys mar: egen tempmin = min(samewin)
gen align = 2 if (tempmax == tempmin) & tempmax == 1
replace align = 0 if (tempmax == tempmin) & tempmax == 0 | samewin == .
replace align = 1 if align == .

}

*rename yearcensus /year school
drop year
rename yearcensus year

*aggregate at the school-mar by year level

* 1. first aggregate treatments and other stuff at the mar level

if(1){
preserve	

gen schools = 1

* first: aggregate at the mar-month level
collapse (max) flagtpres flagsatt flagfac flagmath flageng flagurdu  /// if flagged
			   flagtpres_thres flagsatt_thres flagfac_thres flagmath_thres flageng_thres flagurdu_thres /// if flagged in threshold sample
			   threstpres thressatt thresfac thresmath threseng thresurdu /// if in htreshold sample
			   flagmonth* thresmonth* rank_position district_bottom district_top align  ///
		 (mean) avg_totalreportedteachers_mar = totalteachers mar_tpres = tpres mar_satt = satt mar_fac = fac ///
			    mar_math = math mar_eng = eng mar_urdu = urdu bw* ///
		 (sum) advis change_teacher schools, ///
		by(mar district date_treat year)
		
gen mar_visited = (advis/schools)*100
gen mar_change   = (change_teacher/schools)*100
					
* now aggregate at the year level
collapse (sum) flagtpres* flagsatt* flagfac* flagmath* flageng* flagurdu* thres* flagmonth* district_bottom district_top ///
		 (mean) rank_position avg_totalreportedteachers_mar mar_tpres mar_satt mar_fac mar_math mar_eng mar_urdu mar_visited mar_change bw* ///
		 (max) align, ///
		 by(mar district year)
		 
		 
*fix flagging in the threshold
/*
For student attendance and functional facilities the last categories of flagging in the threshold
are powered enough to obtain a good estimate. Yet, for 6,7,8 in teacher presence flagging in the
threshold there is only one markaz, which might result in noisy estimates when extending to schools
*/
		 
*forward treatments (move to t the treatments if t - 1)
local vars flagtpres flagsatt flagfac flagmath flageng flagurdu ///
		   flagtpres_thres flagsatt_thres flagfac_thres flagmath_thres flageng_thres flagurdu_thres ///
		   threstpres thressatt thresfac thresmath threseng thresurdu 
foreach v of local vars{

	bys mar (year): gen `v'_f = `v'[_n-1]
	*replace `v'_f = 0 if `v'_f == .
	
}

*forward treatments 2 (move to t the treatments if t - 1)
local vars tpres satt fac math eng urdu
foreach yvar of local vars{

	forvalues i=1(1)12{
		
		bys mar (year district): gen flagmonth`yvar'`i'_f = flagmonth`yvar'`i'[_n-1]
		*replace flagmonth`yvar'`i'_f = 0 if flagmonth`yvar'`i'_f == .

		bys mar (year district): gen thresmonth`yvar'`i'_f = thresmonth`yvar'`i'[_n-1]
		*replace thresmonth`yvar'`i'_f = 0 if thresmonth`yvar'`i'_f == .

	}
}

*forward outcomes (move outcomes to t from t-1)
local vars tpres satt fac math eng urdu visited change
foreach v of local vars{

	bys mar (year district): gen mar_`v'_f = mar_`v'[_n-1]
}

* relaxed linearity assumption

** two categories: non falgged and above-below median
local vars tpres satt fac math eng urdu
foreach v of local vars{
	
	xtile flag`v'_q2 = flag`v'_f if flag`v'_f > 0, n(2)
	replace flag`v'_q2 = 0 if flag`v'_q2 == .
	
}

local vars tpres satt fac math eng urdu
foreach v of local vars{
	
	gen flag`v'_thres_q2 = flag`v'_thres_f
	replace flag`v'_thres_q2 = 2 if flag`v'_thres_q2 > 2
	
}

** three categories 
local vars tpres satt fac math eng urdu
foreach v of local vars{
	
	gen flag`v'_q3 = flag`v'_f
	replace flag`v'_q3 = 3 if flag`v'_q3 > 2
			
}

local vars tpres satt fac math eng urdu
foreach v of local vars{
		
	gen flag`v'_thres_q3 = flag`v'_thres_f
	replace flag`v'_thres_q3 = 3 if flag`v'_thres_q3 > 3
	
}

** four categories
local vars tpres satt fac math eng urdu
foreach v of local vars{
	
	gen flag`v'_q4 = flag`v'_f
	replace flag`v'_q4 = 4 if flag`v'_q4 > 3
	
}

local vars tpres satt fac math eng urdu
foreach v of local vars{
	
	gen flag`v'_thres_q4 = flag`v'_thres_f
	replace flag`v'_thres_q4 = 4 if flag`v'_thres_q4 > 4
	
}

*other instruments
local vars tpres satt fac math eng urdu
foreach v of local vars{

	gen flag`v'_thresever = (flag`v'_thres_f > 0)
}

* other endogenous
local vars tpres satt fac math eng urdu
foreach v of local vars{

	gen flag`v'_ever = (flag`v'_f > 0)
}

* normalized outcomes
local vars flagtpres flagsatt flagfac flagmath flageng flagurdu ///
		   flagtpres_thres flagsatt_thres flagfac_thres flagmath_thres flageng_thres flagurdu_thres ///
           flagtpres_f flagsatt_f flagfac_f flagmath_f flageng_f flagurdu_f ///
		   flagtpres_thres_f flagsatt_thres_f flagfac_thres_f flagmath_thres_f flageng_thres_f flagurdu_thres_f
foreach v of local vars{
	
	sum `v', d
	gen `v'norm = (`v' - r(mean))/r(sd)
}
	 
*tempfile 
tempfile temp
save `temp'

restore

}

* 2. aggregate at the school level and then we will see
if(1){
	
* first: aggregate at the mar-month level
collapse (mean) tpres satt fac math eng urdu red_tpres red_satt red_fac red_math red_eng red_urdu govfunds nongovfunds exp ///
		       change_teacher advis, ///
		       ///totalteachers students numschools summale sumfemale, /// mar mean of outcomes
		by(emis mar district date_treat year)
						
* now aggregate at the year level
collapse (mean) tpres satt fac math eng urdu red_tpres red_satt red_fac red_math red_eng red_urdu ///
				govfunds nongovfunds exp ///
		 (max) max_tpres = tpres max_satt = satt max_fac = fac max_math = math max_eng = eng max_urdu = urdu ///
		 (min) min_tpres = tpres min_satt = satt min_fac = fac min_math = math min_eng = eng min_urdu = urdu ///
		 (sum) change_teacher advis, ///
		 by(emis mar district year)
		 
gen share_visited = (advis/9)*100
gen share_change = (change_teacher/9)*100
}

merge m:1 mar district year using `temp'
drop _merge 

*forward outcomes (move outcomes to t from t-1)
local vars tpres satt fac math eng urdu max_tpres max_satt max_fac min_tpres ///
	       min_satt min_fac max_math max_eng max_urdu min_math min_eng min_urdu share_visited share_change
foreach v of local vars{

	bys emis (year mar district): gen `v'_f = `v'[_n-1]
}

drop if year == 2011 // we only needed some outcomes from here

}

compress
save "$analysis/processed/cc_mar_emis_year_data.dta", replace // adjusted mar

/* create a different dataset for RDA controls
we assume each month have the same weiht in the next year outcome s_j = 1/9
we have z_j = 1 if unit was flagged in month j

* X_i = sum_{1}^{9} s_j * z_j --> sum_{1}^{9} 0.111111 * z_j for all units
* Z_i = sum_{1}^{9} s_j * z_j only for units close to the threshold 

now RDA controls

- sum of subunits near the threshold: this is basically = # in threshold/ 9
- avg running in narrow elections: sum running * 1/9 for those in threshold
- avg running in narrow wins: sum running * 1/9 for those winning in threshold
*/

if(1){
	
use "$analysis/processed/cc_datapacks.dta", clear
drop if wing == 3 // we do not consider secondary schools (not subject to monitoring)
	
*need to create dataset with thresholds for each variable/date
local vars tpres satt fac eng math urdu
foreach yvar of local vars{
		
preserve
		 
use "$analysis/processed/stacked/cc_stackdata5_`yvar'_flaghist.dta", clear

keep if relativetime == 0
keep if rd1 == 1
keep date_treat bw
sort date_treat bw
gen random = runiform()
sort date_treat bw random
bys date_treat bw (random): gen ord = _n
keep if ord == 1
drop random ord
tempfile temp
save `temp'
		
restore
		
merge m:1 date_treat using `temp'
drop _merge
rename bw1 bw`yvar'

}

*gen year census --> the same as school year
if(1){
gen     yearcensus = 2011 if (date_treat >= tm(2010m9) & date_treat <= tm(2011m5))
replace yearcensus = 2012 if (date_treat >= tm(2011m9) & date_treat <= tm(2012m5))
replace yearcensus = 2013 if (date_treat >= tm(2012m9) & date_treat <= tm(2013m5))
replace yearcensus = 2014 if (date_treat >= tm(2013m9) & date_treat <= tm(2014m5))
replace yearcensus = 2015 if (date_treat >= tm(2014m9) & date_treat <= tm(2015m5))
replace yearcensus = 2016 if (date_treat >= tm(2015m9) & date_treat <= tm(2016m5))
replace yearcensus = 2017 if (date_treat >= tm(2016m9) & date_treat <= tm(2017m5))
replace yearcensus = 2018 if (date_treat >= tm(2017m9) & date_treat <= tm(2018m5))

}

*create flagged
local vars tpres satt fac eng math urdu
foreach yvar of local vars{
	
	gen flag`yvar' = treat_`yvar'_
	
}

*create flagged in threshold sample
local vars tpres satt fac eng math urdu
foreach yvar of local vars{
	
	gen lowthres = red_`yvar' - bw`yvar'
	gen flag`yvar'_thres = (mar_`yvar' < red_`yvar' & mar_`yvar' >= lowthres & flag`yvar' == 1)
	drop lowthres
	
}

*create in threshold sample
local vars tpres satt fac eng math urdu
foreach yvar of local vars{
	
	gen lowthres = red_`yvar' - bw`yvar'
	gen highthres = red_`yvar' + bw`yvar'
	gen thres`yvar' = (mar_`yvar' >= lowthres & mar_`yvar' <= highthres & date_treat >= tm(2011m12))
	drop lowthres highthres
	
}
	
local vars flagmath flageng flagurdu flagmath_thres flageng_thres flagurdu_thres thresmath threseng thresurdu math eng urdu
foreach v of local vars{
	
	replace `v' = . if year < 2016
}

* create dummies for flagged in each month and outcomes for each month
local vars tpres satt fac eng math urdu
foreach yvar of local vars{

	forvalues i=1(1)12{
		
		bys mar year: gen flagmonth`yvar'`i' = (flag`yvar'_thres == 1 & month == `i')
		bys mar year: gen thresmonth`yvar'`i' = (thres`yvar' == 1 & month == `i')
		bys mar year: gen month`yvar'`i' = `yvar' if month == `i'

		
	}
}

*rename yearcensus /year school
drop year
rename yearcensus year

*aggregate at the school-mar by year level

* 1. first aggregate treatments and other stuff at the mar level

if(1){
preserve	

* first: aggregate at the mar-month level
collapse (max) flagtpres flagsatt flagfac flagmath flageng flagurdu  /// if flagged
			   flagtpres_thres flagsatt_thres flagfac_thres flagmath_thres flageng_thres flagurdu_thres /// if flagged in threshold sample
			   threstpres thressatt thresfac thresmath threseng thresurdu /// if in htreshold sample
			   flagmonth* thresmonth*  ///
		 (mean) avg_totalreportedteachers_mar = totalteachers mar_tpres = tpres mar_satt = satt mar_fac = fac ///
			    mar_math = math mar_eng = eng mar_urdu = urdu  month*, ///
		by(mar district date_treat year)
		
* now aggregate at the year level
collapse (sum) flagtpres* flagsatt* flagfac* flagmath* flageng* flagurdu* thres* flagmonth* ///
		 (mean) avg_totalreportedteachers_mar mar_tpres mar_satt mar_fac mar_math mar_eng mar_urdu month*, ///
		 by(mar district year)
		 
*fix flagging in the threshold
/*
For student attendance and functional facilities the last categories of flagging in the threshold
are powered enough to obtain a good estimate. Yet, for 6,7,8 in teacher presence flagging in the
threshold there is only one markaz, which might result in noisy estimates when extending to schools
*/
		 
*forward treatments (move to t the treatments if t - 1)
local vars flagtpres flagsatt flagfac flagmath flageng flagurdu ///
		   flagtpres_thres flagsatt_thres flagfac_thres flagmath_thres flageng_thres flagurdu_thres ///
		   threstpres thressatt thresfac thresmath threseng thresurdu 
foreach v of local vars{

	bys mar (year): gen `v'_f = `v'[_n-1]
	*replace `v'_f = 0 if `v'_f == .
	
}

*forward treatments 2 (move to t the treatments if t - 1)
local vars tpres satt fac math eng urdu
foreach yvar of local vars{

	forvalues i=1(1)12{
		
		bys mar (year district): gen flagmonth`yvar'`i'_f = flagmonth`yvar'`i'[_n-1]
		*replace flagmonth`yvar'`i'_f = 0 if flagmonth`yvar'`i'_f == .

		bys mar (year district): gen thresmonth`yvar'`i'_f = thresmonth`yvar'`i'[_n-1]
		*replace thresmonth`yvar'`i'_f = 0 if thresmonth`yvar'`i'_f == .

	}
}

*forward outcomes (move outcomes to t from t-1)
local vars tpres satt fac math eng urdu 
foreach v of local vars{

	bys mar (year district): gen mar_`v'_f = mar_`v'[_n-1]
}

local vars tpres satt fac math eng urdu 
foreach v of local vars{

	local mvar month`v'1 month`v'2 month`v'3 month`v'4 month`v'5 month`v'9 month`v'10 month`v'11 month`v'12
	
	foreach j of local mvar{
		bys mar (year district): gen `j'_f = `j'[_n-1]
	}
}

* normalized outcomes
local vars flagtpres flagsatt flagfac flagmath flageng flagurdu ///
		   flagtpres_thres flagsatt_thres flagfac_thres flagmath_thres flageng_thres flagurdu_thres ///
           flagtpres_f flagsatt_f flagfac_f flagmath_f flageng_f flagurdu_f ///
		   flagtpres_thres_f flagsatt_thres_f flagfac_thres_f flagmath_thres_f flageng_thres_f flagurdu_thres_f
foreach v of local vars{
	
	sum `v', d
	gen `v'norm = (`v' - r(mean))/r(sd)
}


drop month*6 month*7 month*8
 
*tempfile 
tempfile temp
save `temp'

restore

}

* 2. aggregate at the school level and then we will see
if(1){
	
* first: aggregate at the mar-month level
collapse (mean) tpres satt fac math eng urdu red_tpres red_satt red_fac red_math red_eng red_urdu, ///
		       ///totalteachers students numschools summale sumfemale, /// mar mean of outcomes
		by(emis mar district date_treat year)
						
* now aggregate at the year level
collapse (mean) tpres satt fac math eng urdu red_tpres red_satt red_fac red_math red_eng red_urdu, ///
		 by(emis mar district year)
		 
}

merge m:1 mar district year using `temp'
drop _merge 

*forward outcomes (move outcomes to t from t-1)
local vars tpres satt fac math eng urdu 
foreach v of local vars{

	bys emis (year mar district): gen `v'_f = `v'[_n-1]
}

drop if year == 2011 // we only needed some outcomes from here


}

compress
save "$analysis/processed/cc_mar_emis_year_data_rda.dta", replace // adjusted mar

*---------------------------------------------------------------------------------------------------
**# 3. markas by school year panel dataset #

/* we aggregate the school by month data at the markaz by school year level. We do so by averaging the
outcomes over the school year, so each shcool has an average yearly performance. For the flagging 
measure, we count the number of times an school was in a flagged markaz in a school year*/
		
if(1){
	
use "$analysis/processed/cc_datapacks.dta", clear
drop if wing == 3 // we do not consider secondary schools (not subject to monitoring)

*need to create dataset with thresholds for each variable/date
local vars tpres satt fac eng math urdu
foreach yvar of local vars{
		
preserve

* use flagging history as the origin of the monthly flagging as it has more flagging events because it allows for pre-period flagging
use "$analysis/processed/stacked/cc_stackdata5_`yvar'_flaghist.dta", clear

keep if relativetime == 0 // keep period where the flagging is measured
keep if rd1 == 1 // keep only observations in the bandwidth
keep date_treat bw // keep date and bw size
sort date_treat bw
gen random = runiform() // there are duplicates as multiple schoools / markaz within the bandwidth, we want a unique observations by date
sort date_treat bw random
bys date_treat bw (random): gen ord = _n
keep if ord == 1
drop random ord
tempfile temp
save `temp'
		
restore
		
merge m:1 date_treat using `temp'
drop _merge
rename bw1 bw`yvar'

}

*gen year census --> the same as school year
if(1){
*gen     yearcensus = 2011 if (date_treat >= tm(2010m9) & date_treat <= tm(2011m5))
gen yearcensus = 2012 if (date_treat >= tm(2011m9) & date_treat <= tm(2012m5))
replace yearcensus = 2013 if (date_treat >= tm(2012m9) & date_treat <= tm(2013m5))
replace yearcensus = 2014 if (date_treat >= tm(2013m9) & date_treat <= tm(2014m5))
replace yearcensus = 2015 if (date_treat >= tm(2014m9) & date_treat <= tm(2015m5))
replace yearcensus = 2016 if (date_treat >= tm(2015m9) & date_treat <= tm(2016m5))
replace yearcensus = 2017 if (date_treat >= tm(2016m9) & date_treat <= tm(2017m5))
replace yearcensus = 2018 if (date_treat >= tm(2017m9) & date_treat <= tm(2018m5))

}

*create flagged
local vars tpres satt fac eng math urdu
foreach yvar of local vars{
	
	gen flag`yvar' = treat_`yvar'_
	
}

*create flagged in threshold sample
local vars tpres satt fac eng math urdu
foreach yvar of local vars{
	
	gen lowthres = red_`yvar' - bw`yvar'
	gen flag`yvar'_thres = (mar_`yvar' < red_`yvar' & mar_`yvar' >= lowthres & flag`yvar' == 1)
	drop lowthres
	
}

*create in threshold sample
local vars tpres satt fac eng math urdu
foreach yvar of local vars{
	
	gen lowthres = red_`yvar' - bw`yvar'
	gen highthres = red_`yvar' + bw`yvar'
	gen thres`yvar' = (mar_`yvar' >= lowthres & mar_`yvar' <= highthres & date_treat >= tm(2011m12))
	drop lowthres highthres
	
}

/*adjust student scores: 

data on scores started to be collected in september 2015, yet, in was only made official in the datapacks since january 2016. 
The first months were used to testthe data collection procedure for that data. We then use student scores data since 2016
*/

local vars flagmath flageng flagurdu flagmath_thres flageng_thres flagurdu_thres thresmath threseng thresurdu math eng urdu
foreach v of local vars{
	
	replace `v' = . if year < 2016
}
	
* create dummies for flagged in each month
local vars tpres satt fac eng math urdu
foreach yvar of local vars{

	forvalues i=1(1)12{
		
		bys mar year: gen flagmonth`yvar'`i' = (flag`yvar'_thres == 1 & month == `i')
		bys mar year: gen thresmonth`yvar'`i' = (thres`yvar' == 1 & month == `i')
		
	}
}

*rename yearcensus /year school
drop year
rename yearcensus year

*aggregate at the school-mar by year level

* 1. first aggregate treatments and other stuff at the mar level

if(1){

gen schools = 1
bys mar date_treat: egen numschools = nvals(emis)

* first: aggregate at the mar-month level
collapse (max) flagtpres flagsatt flagfac flagmath flageng flagurdu /// if flagged
			   flagtpres_thres flagsatt_thres flagfac_thres flagmath_thres flageng_thres flagurdu_thres /// if flagged in threshold sample
			   threstpres thressatt thresfac thresmath threseng thresurdu numschools /// if in htreshold sample
			   flagmonth* thresmonth* ///
		 (mean) avg_totalreportedteachers_mar = totalteachers mar_tpres = tpres mar_satt = satt mar_fac = fac mar_eng = eng mar_math = math mar_urdu = urdu ///
		 (sum) advis change_teacher schools, ///
		by(mar district date_treat year)
		
gen mar_visited = (advis/schools)*100
gen mar_change   = (change_teacher/schools)*100

* now aggregate at the year level
collapse (sum) flagtpres* flagsatt* flagfac* flagmath* flageng* flagurdu* thres* flagmonth* ///
		 (mean) avg_totalreportedteachers_mar mar_tpres mar_satt mar_fac mar_math mar_eng mar_urdu mar_visited mar_change numschools ///
		 (max) max_mar_tpres = mar_tpres max_mar_satt = mar_satt max_mar_fac = mar_fac max_mar_math = mar_math max_mar_eng = mar_eng max_mar_urdu = mar_urdu ///
		 (min) min_mar_tpres = mar_tpres min_mar_satt = mar_satt min_mar_fac = mar_fac min_mar_math = mar_math min_mar_eng = mar_eng min_mar_urdu = mar_urdu, ///
		 by(mar district year)
		 
		 
*fix flagging in the threshold
/*
For student attendance and functional facilities the last categories of flagging in the threshold
are powered enough to obtain a good estimate. Yet, for 6,7,8 in teacher presence flagging in the
threshold there is only one markaz, which might result in noisy estimates when extending to schools
*/
		 
*forward treatments (move to t the treatments if t - 1)
local vars flagtpres flagsatt flagfac flagmath flageng flagurdu flagtpres_thres flagsatt_thres flagfac_thres ///
		   flagmath_thres flageng_thres flagurdu_thres threstpres thressatt thresfac thresmath threseng thresurdu
foreach v of local vars{

	bys mar (year): gen `v'_f = `v'[_n-1]
	*replace `v'_f = 0 if `v'_f == .
	
}

*forward outcomes (move outcomes to t from t-1)
local vars mar_tpres mar_satt mar_fac mar_math mar_eng mar_urdu ///
	       max_mar_tpres max_mar_satt max_mar_fac max_mar_math max_mar_eng max_mar_urdu ///
		   min_mar_tpres min_mar_satt min_mar_fac min_mar_math min_mar_eng min_mar_urdu mar_visited mar_change
foreach v of local vars{

	bys mar (year): gen `v'_f = `v'[_n-1]
}

* normalized outcomes
local vars flagtpres flagsatt flagfac flagmath flageng flagurdu ///
		   flagtpres_thres flagsatt_thres flagfac_thres flagmath_thres flageng_thres flagurdu_thres ///
		   flagtpres_f flagsatt_f flagfac_f flagmath_f flageng_f flagurdu_f ///
		   flagtpres_thres_f flagsatt_thres_f flagfac_thres_f flagmath_thres_f flageng_thres_f flagurdu_thres_f
foreach v of local vars{
	
	sum `v', d
	gen `v'norm = (`v' - r(mean))/r(sd)
}

}

drop if year == 2011 // we only needed some outcomes from here

* standardize observations relative to teacher presence
replace mar_satt_f = . if mar_tpres_f == .
replace mar_fac_f = . if mar_tpres_f == .

}

save "$analysis/processed/cc_mar_year_data.dta", replace // adjusted mar

*---------------------------------------------------------------------------------------------------
**# 4. markaz red flagging #

//1. create event panel
//2. create and adjust event-panel: threshold sample, additionales variables
local treatments tpres satt fac eng math urdu //all flagging outcomes
foreach v of local treatments{
	
	*iterate over all possible post-periods
	forvalues i = 2(3)5{ // we create a long and short stack
		
		* trick for later create empty temporary file to apend all other evet-panels
		
		clear		
		gen stack = 0
		tempfile stack
		save `stack'
		
		* main data: balanced dataset
		use "$analysis/processed/cc_datapacks.dta", clear
		drop if wing == 3 // we do not consider secondary schools (not subject to monitoring)
		
		/* create time id: date version has gaps between may and september. The new variable takes 
		continuous values since 1, hence, there is no gap*/
		
		egen date_treat_e = group(date_treat) // date indicator for iterations
		
		* validate mar with double assignment of flagging
		
		gen copy = treat_`v'_lead // create a copy of the original variable
		bys mar date_treat: egen templead = nvals(treat_`v'_lead) //some obs with double accounting
		bys mar date_treat: egen temp = nvals(treat_`v'_) // original date is correct
		bys mar (date_treat `v' emis): gen t = treat_`v'_[_n-1] // update flagging
		bys mar date_treat (`v' emis): gen tord = _n // set order based on `v'
		replace t = . if tord != 1 // set to missing all except the immediatly before observation for each mar
		bys mar date_treat: egen tmax = max(t) // generalize flagging
		replace treat_`v'_lead = tmax if templead == 2 // apply only to those needed to be adjusted
		replace treat_`v'_lead = copy if templead == 2 & treat_`v'_lead == . // missing replace with original
		drop templead temp t tord tmax copy
		
		* still double accounting, basically from schools changing mar into a new mar
		* define as the majority of schools reporting (less than 1% so no sensitive)
		bys mar date_treat: egen templead = nvals(treat_`v'_lead) //some obs with double accounting
			*count ones and zeroes
		gen zero = 1 if templead == 2 & treat_`v'_lead == 0
		gen ones = 1 if templead == 2 & treat_`v'_lead == 1
		bys mar date_treat: egen numzeros = sum(zero) if templead == 2
		bys mar date_treat: egen numones = sum(ones) if templead == 2
		replace treat_`v'_lead = 0 if numzeros > numones & templead == 2
		replace treat_`v'_lead = 1 if numzeros <= numones & templead == 2
		
		drop zero ones numzeros numones templead
				
		* keep unique mar and date_treat

		*duplicates drop mar date_treat, force // this way of dropping duplicates might be unstable
		* stable solution to drop duplicates
		sort mar date_treat treat_`v'_lead mar_`v' `v' emis
		gen random = runiform() // generate random variable (note the seed in 0_setup)
		sort mar date_treat treat_`v'_lead mar_`v' `v' emis random
        bys mar date_treat (treat_`v'_lead mar_`v' `v' emis random): gen ord = _n // ordering
		keep if ord == 1
		drop random ord
		
		keep mar date_treat date_treat_e mar_`v' treat_`v'_lead red_`v'

		* define dates at which a treatment will be stackedators by which 
		
		gen treat_dates = date_treat_e if ((treat_`v'_lead == 1) & date_treat > tm(2011m12)) // 2011m12 first flag, but we are using as event the lead
	
		/* we define datasets for each date where a flag ocurred, so the flag date is the center of 
		each event-data. Note also that date_treat_e correspond to the relative time 1 (punish), 
		then we always will have date_treat_e - 5 to have preperiods (-1, -2, -3, -4) and 0 (flag). 
		We are only changing t based on the post periods, where the minimum is date_treat_e + 1 
		*/

		display("starting variable `v' time `i'")

		* iterate creation of event-panels 
		levelsof treat_dates
		foreach d in `r(levels)'{ 
			
			preserve
			
			*dataset between t+i to t-5 
			
			keep if ((date_treat_e <= `d' + `i') & (date_treat_e >= `d' - 5)) // keep desired time span
			
			*drop if mar outcome is empty
			
			drop if missing(mar_`v')
						
			*drop units that do not have t and t-1
			
			bys mar: egen num_mar = count(mar) //count number of times mar appear
			gen num_periods = 6 + `i' // markaz that appear consecutively 6 + i periods
			keep if num_mar == num_periods // only mars that appear all the time span
			drop num_periods num_mar
						
			*conditional if exist data
			
			if(_N > 0){
				
				bys mar (date_treat): gen time_id = _n // create time id
					
				/* we must eliminate mar treated in t-n: in such case, a unit would be treated 
				twice (in t-1 and t) or would be treated only on t-1, in which case would not be 
				a clean control
				*/
				
				gen before = (time_id < 6)  // goes from 1 to 6 + `i', so always drop treated in < 6
				sort mar date_treat // sort by date within mar
				bys mar (date_treat): egen treated_before = max(treat_`v'_lead) if (before == 1) // treated before time 6
				bys mar: egen max_before = max(treated_before)
				drop if max_before == 1 // drop if treated before
				drop treated_before max_before
					
				*if there still exist data: dropping treated before might lead to no-data for event
				if(_N > 0){
						
					/*if treated in t+1 but not in t, we must drop, as would not be treated in 
					the main event data we are centering the event-data
					*/
						
					*treated in t+1
					gen stag1 = ((treat_`v'_lead == 1) & (time_id > 6))
						
					*treated in t
					gen stag2 = ((treat_`v'_lead == 1) & (time_id == 6))
						
					*generalizing to all units
					
					bys mar: egen sum_stag1 = max(stag1)
					bys mar: egen sum_stag2 = max(stag2)

					*drop not treated in main event
					
					gen drop_units = (sum_stag2 == 0 & sum_stag1 == 1) // not treated in t, but treated in t+1
					drop if drop_units == 1
					drop before stag1 stag2 sum_stag1 sum_stag2 drop_units
						
					*stack unique id
					
					gen stack = `d'
					drop time_id
					bys mar (date_treat): gen time_id = _n // readjust timeid
					
					
				} // end if statement
				else if(_N == 0){ // if there is no data after dropping the not clean controls
						
					*display if no observations
					display "`d' have 0 observations"
						
				} // end else statement 
			
			} // end if statement
			else if(_N == 0){ // if there is no data for the particular event date
				
				*display if no observations
				display "`d' have 0 observations"

			} // end else statement
			
			*append evet-panel datatsets
			append using `stack' // append to original stack! then for next iterations we rewritte
			tempfile stack
			save `stack'
				
			restore // recover original data to create the next event time panel
		
		} // end of loop statement for event panels of outcomes
		
		* use temporary stacked dataset
		
		use `stack', clear
		
		* drop "temporary file stack"

		drop if stack == 0

		* compress for memory purposes

		compress

		* relative time: normalize to 0 the flag period (time_id == 5)
		
		gen relativetime = time_id - 5

		/* create constant treatment variable: if flag_period = 1 in relativetime == 1 to validate, 
		recreate main treatment
		*/
		
		bys stack mar: gen temp_lead = ((treat_`v'_lead == 1) & (time_id == 6) & (date_treat > tm(2011m12)))
		bys stack mar: egen flagged = max(temp_lead) //if ever flagged, then treated
		drop temp_lead
		drop if missing(flagged) // drop all the observations that do not report data en the flagging period
		
		* post-periods
		
		//after punish period
		gen postpunish = (relativetime > 0)
		//after flag period
		gen postflag = (relativetime > -1)
 
		/* regression discontinuity samples:
		
		we need a tighter comparisson of treated and control units, then we use an optimal bandwidth 
		to define for each event-dataset the group of markaz that are around the threshold
		*/
		
		*define thresholds: scores have the same threshold and for student attendance need to defined it separately
		
		if("`v'" == "tpres"){
			local thres = 86
			local min = 86
		}
		else if("`v'" == "fac"){
			local thres = 90
			local min = 87 // for functional facilities there is less variation, then being close to 90 is not enough
		}
		else{
			local thres = 70
			local min = 70
		}
		
		*run rd 
		
		if("`v'" != "satt"){
			
			preserve
			
			*keep event mar relative time and variable of interest
			
			keep stack mar relativetime mar_`v'
			
			/*for the rd we need to compare the flagging period (relative time 0) with the period of 
			the punishment (relative time 1). Then we create the lag of the markaz variable for 1, 
			to have both values of 1 and 0 in the  same row*/
			
			gen temp = mar_`v' if relativetime == 0
			bys stack mar (relativetime): egen mar_`v'_lag0 = max(temp) // period 0 outcome
			drop temp
			
			*keep only the iterest relative time
			
			keep if relativetime == 1 // so compare outcome in 1 with just created outcome in 0
			drop relativetime
			
			*create variables to populate

			gen bw1 = .
			gen bias1 = .
			
			* estimate rd: we have to iterate over each event dataset
			
			levelsof stack // all possible event-dates 
			foreach d in `r(levels)'{
				
				display `d'
				qui sum mar_`v'_lag0 if stack == `d'
				if((`r(min)' < `min' & `r(N)' > 50 & "`v'" == "tpres"           ) | /// general conditions
				   (`r(min)' < `min' & `r(N)' > 50 & "`v'" == "fac"  & `d' != 44 & `d' != 62 & `d' != 64) | /// conditions for mar
				   (`r(min)' < `min' & `r(N)' > 50 & "`v'" == "eng"  & `d' != 47) | /// conditions for eng
				   (`r(min)' < `min' & `r(N)' > 50 & "`v'" == "math" & `d' != 48) | /// conditions for math
				   (`r(min)' < `min' & `r(N)' > 50 & "`v'" == "urdu" & `d' != 47)   /// conditions for urdu
				  ){ // set up conditions for events that have enough obs (fix some urdu problems)
					
					*run the optimal bandwidth selection: Cattaneo and Calonico

					rdbwselect mar_`v' mar_`v'_lag0 if stack == `d', ///
						c(`thres') p(2) q(3) kernel(triangular) bwselect(mserd) vce(cluster mar) all
						
						if(`e(h_mserd)' < `e(b_mserd)'){ //if effectively exist a bandwidth
						
						*calculate auxiliary variables
						
						replace bw1 = `e(h_cercomb1)' if stack == `d' // msecomb1 cercomb1
						replace bias1 = `e(b_cercomb1)' if stack == `d'
						
					} // end of if statement of existance of bandwidth
				
				} // end of if statament of existance of rd for each stack

			} // end of loop over stacks for rd procedure
			
			* variables for rd samples	
			
			gen rd1 = (mar_`v'_lag0 >= `thres' - bw1 & mar_`v'_lag0 <= `thres' + bw1 & !missing(bw1)) 
			gen biasrd1 = (mar_`v'_lag0 >= `thres' - bias1 & mar_`v'_lag0 <= `thres' + bias1 & !missing(bw1))

			
		} //  end if statement for all except student attendance
		else{ // because student attendance threshold is not constant, need to recenter to 0	
		
			/*for student attendance the thresholds change in time, then we have to normalize 
			threshold to 0*/
			
			preserve
			
			*keep event mar relative time and variable of interest
			
			keep stack mar relativetime mar_`v' red_`v'
			
			/*for the rd we need to compare the flagging period (relative time 0) with the period of 
			the punishment (relative time 1). Then we create the lag of the markaz variable for 1, 
			to have both values of 1 and 0 in the  same row*/
			
			gen temp = mar_`v' if relativetime == 0
			bys stack mar (relativetime): egen mar_`v'_lag0 = max(temp) // period 0 outcome
			drop temp
			
			*keep only the iterest relative time
			
			keep if relativetime == 1 // so compare outcome in 1 with just created outcome in 0
			drop relativetime
			
			*create variables to populate
			
			gen bw1 = .
			gen bias1 = .

			* need to center as in satt thresholds are not constant
			
			gen c_mar_`v' = mar_`v' - red_`v'
			gen c_mar_`v'_lag0 = mar_`v'_lag0 - red_`v'
			
			* estimate rd: we have to iterate over each event dataset
			
			levelsof stack // all possible event-dates 
			foreach d in `r(levels)'{
				display `d'
				qui sum c_mar_`v'_lag0 if stack == `d'
				if(`r(min)' < -2 &  `r(N)' > 50  & `d' != 57){ // from 0 to -2 to avoid conformability error 37 57
					
					*run the optimal bandwidth selection: Cattaneo and Calonico
					
					rdbwselect c_mar_`v' c_mar_`v'_lag0 if stack == `d', ///
						c(0) p(2) q(3) kernel(triangular) bwselect(mserd) vce(cluster mar) all
						
					if(`e(h_mserd)' < `e(b_mserd)'){
						
						*calculate auxiliary variables
						replace bw1 = `e(h_cercomb1)' if stack == `d'
						replace bias1 = `e(b_cercomb1)' if stack == `d'
						
					} // end of if statement of existance of bandwidth
					
				} // end of if statament of existance of rd for each stack

			} // end of loop over stacks for rd procedure
			
			*variables for samples	
			
			gen rd1 = (c_mar_`v'_lag0 >= 0 - bw1 & c_mar_`v'_lag0 <= 0 + bw1 & !missing(bw1)) 
			gen biasrd1 = (c_mar_`v'_lag0 >= 0 - bias1 & c_mar_`v'_lag0 <= 0 + bias1 & !missing(bw1))
		
		} //  end else statement for student attendance
		
		* save tempfile
		
		keep stack mar rd1 biasrd1 bw1 bias1
		tempfile rd_sample
		save `rd_sample'
		restore //note the preserve for this restore is within the rd procedure
		
		*merge it with the original stacked data
		
		merge m:1 stack mar using `rd_sample'

		* keep desired observations
		
		keep if _merge == 3
		drop _merge

		* merge with original: all schools per mar and date

		joinby mar date_treat using "$analysis/processed/cc_datapacks.dta"
		
		* mean teachers per markaz
		gen temp = totalteachers if relativetime < 0
		bys stack mar: egen avg_totalreportedteachers_mar = mean(temp) 
		drop temp
		
		*drop unnecesary variables
		drop school_head_designation school_head_name school_head_phone original*
		* save
		compress
		save "$analysis/processed/stacked/cc_stackdata`i'_`v'.dta", replace // i = post period, v = outcome
	
		display("finish variable `v' with post periods `i'")

	} // end loop statement for post period i
	
	*after the last `i' post period, it starts again for the next variable v
	display("finish variable `v', pasing to the next one")

} // end loop statement for all variables

*---------------------------------------------------------------------------------------------------
**# 5. markaz orange flagging stacking #

//1. create event panel
//2. create and adjust event-panel: threshold sample, additionales variables

/*note: for english scores there is not enough sample for RD or full, so the sample size is 
significantly smaller compared with the other scores*/

local treatments tpres satt fac eng math urdu // all flagging outcomes 
foreach v of local treatments{
	
	*iterate over all possible post-periods
	
	forvalues i = 5(1)5{ 
		
		* trick for later create empty temporary file to apend all other evet-panels
		 
		clear		
		gen stack = 0
		tempfile stack
		save `stack'
		
		* main data: balanced dataset
		
		use "$analysis/processed/cc_datapacks.dta", clear
		drop if wing == 3 // we do not consider secondary schools (not subject to monitoring)
		
		/* create time id: date version has gaps between may and september. The new variable takes 
		continuous values since 1, hence, there is no gap
		*/
		
		egen date_treat_e = group(date_treat) // date indicator for iterations

		* validate mar with double assignment of flagging		
		
		gen copy = or_treat_`v'_lead // create a copy of the original variable
		bys mar date_treat: egen templead = nvals(or_treat_`v'_lead) //some obs with double accounting
		bys mar date_treat: egen temp = nvals(or_treat_`v'_) // original date is correct
		bys mar (date_treat `v' emis): gen t = or_treat_`v'_[_n-1] // update flagging
		bys mar date_treat (`v' emis): gen tord = _n // set order based on `v'
		replace t = . if tord != 1 // set to missing all except the immediatly before observation for each mar
		bys mar date_treat: egen tmax = max(t) // generalize flagging
		replace or_treat_`v'_lead = tmax if templead == 2 // apply only to those needed to be adjusted
		replace or_treat_`v'_lead = copy if templead == 2 & or_treat_`v'_lead == . // missing replace with original
		drop templead temp t tord tmax copy

		* still double accounting, basically from schools changing mar into a new mar
		* define as the majority of schools reporting (less than 1% so no sensitive)
		bys mar date_treat: egen templead = nvals(or_treat_`v'_lead) //some obs with double accounting
			*count ones and zeroes
		gen zero = 1 if templead == 2 & or_treat_`v'_lead == 0
		gen ones = 1 if templead == 2 & or_treat_`v'_lead == 1
		bys mar date_treat (`v' emis): egen numzeros = sum(zero) if templead == 2
		bys mar date_treat (`v' emis): egen numones = sum(ones) if templead == 2
		replace or_treat_`v'_lead = 0 if numzeros > numones & templead == 2
		replace or_treat_`v'_lead = 1 if numzeros <= numones & templead == 2
		
		drop zero ones numzeros numones templead

		* keep unique mar and date_treat

		*duplicates drop mar date_treat, force // this way of dropping duplicates might be unstable
		* stable solution to drop duplicates
		sort mar date_treat treat_`v'_lead `v' emis
		gen random = runiform() // generate random variable (note the seed in 0_setup)
		sort mar date_treat treat_`v'_lead `v' emis random
        bys mar date_treat (treat_`v'_lead `v' emis random): gen ord = _n // ordering
		keep if ord == 1
		drop random ord			
		
		keep mar date_treat date_treat_e mar_`v' or_treat_`v'_lead green_`v'

		* define dates at which a treatment will be stackedators by which 

		gen treat_dates = date_treat_e if ((or_treat_`v'_lead == 1) & date_treat > tm(2011m12)) // 2011m12 first flag, but we are using as event the lead
	
		/* we define datasets for each date where a flag ocurred, so the flag date is the center of 
		each event-data. Note also that date_treat_e correspond to the relative time 1 (punish), 
		then we always will have date_treat_e - 5 to have preperiods (-1, -2, -3, -4) and 0 (flag). 
		We are only changing t based on the post periods, where the minimum is date_treat_e + 1 
		*/

		display("starting variable `v' time `i'")

		* iterate creation of event-panels 
		levelsof treat_dates
		foreach d in `r(levels)'{ 
			
			preserve
			
			*dataset between t+i to t-5 
			
			keep if ((date_treat_e <= `d' + `i') & (date_treat_e >= `d' - 5)) // keep desired time span
			
			*drop if mar outcome is empty
			
			drop if missing(mar_`v')
			
			*adjust treatment in case of missings
			
			bys mar (date_treat): replace or_treat_`v'_lead = or_treat_`v'_[_n-1] if missing(or_treat_`v'_lead)
			
			*drop units that do not have t and t-1
			
			bys mar: egen num_mar = count(mar) //count number of times mar appear
			gen num_periods = 6 + `i' // markaz that appear consecutively 6 + i periods
			keep if num_mar == num_periods // only mars that appear all the time span
			drop num_periods num_mar

			*conditional if exist data
			
			if(_N > 0){
				
				bys mar (date_treat): gen time_id = _n // create time id
					
				/* we must eliminate mar treated in t-n: in such case, a unit would be treated 
				twice (in t-1 and t) or would be treated only on t-1, in which case would not be 
				a clean control
				*/
				
				gen before = (time_id < 6)  // goes from 1 to 6 + `i', so always drop treated in < 6
				sort mar date_treat // sort by date within mar
				bys mar (date_treat): egen treated_before = max(or_treat_`v'_lead) if (before == 1) // treated before time 6
				bys mar: egen max_before = max(treated_before)
				drop if max_before == 1 // drop if treated before
				drop treated_before max_before
					
				*if there still exist data: dropping treated before might lead to no-data for event
				if(_N > 0){
						
					/*if treated in t+1 but not in t, we must drop, as would not be treated in 
					the main event data we are centering the event-data
					*/
						
					*treated in t+1
					gen stag1 = ((or_treat_`v'_lead == 1) & (time_id > 6))
						
					*treated in t
					gen stag2 = ((or_treat_`v'_lead == 1) & (time_id == 6))
						
					*generalizing to all units
					
					bys mar: egen sum_stag1 = max(stag1)
					bys mar: egen sum_stag2 = max(stag2)

					*drop not treated in main event
					
					gen drop_units = (sum_stag2 == 0 & sum_stag1 == 1) // not treated in t, but treated in t+1
					drop if drop_units == 1
					drop before stag1 stag2 sum_stag1 sum_stag2 drop_units
						
					*stack unique id
					
					gen stack = `d'
					drop time_id
					bys mar (date_treat): gen time_id = _n // readjust timeid
					
					
				} // end if statement
				else if(_N == 0){ // if there is no data after dropping the not clean controls
						
					*display if no observations
					display "`d' have 0 observations"
						
				} // end else statement 
			
			} // end if statement
			else if(_N == 0){ // if there is no data for the particular event date
				
				*display if no observations
				display "`d' have 0 observations"

			} // end else statement
			
			*append evet-panel datatsets
			append using `stack' // append to original stack! then for next iterations we rewritte
			tempfile stack
			save `stack'
				
			restore // recover original data to create the next event time panel
		
		} // end of loop statement for event panels of outcomes
		
		* use temporary stacked dataset
		
		use `stack', clear
		
		* drop "temporary file stack"

		drop if stack == 0

		* compress for memory purposes

		compress

		* relative time: normalize to 0 the flag period (time_id == 5)
		
		gen relativetime = time_id - 5

		/* create constant treatment variable: if flag_period = 1 in relativetime == 1 to validate, 
		recreate main treatment
		*/
		
		bys stack mar: gen temp_lead = ((or_treat_`v'_lead == 1) & (time_id == 6))
		bys stack mar: egen flagged = max(temp_lead) //if ever flagged, then treated
		drop temp_lead
		drop if missing(flagged) // drop all the observations that do not report data en the flagging period

		* post-periods
		
		//after punish period
		gen postpunish = (relativetime > 0)
		//after flag period
		gen postflag = (relativetime > -1)
 
		/* regression discontinuity samples:
		
		we need a tighter comparisson of treated and control units, then we use an optimal bandwidth 
		to define for each event-dataset the group of markaz that are around the threshold
		*/
		
		*define thresholds: scores have the same threshold and for student attendance need to defined it separately
		
		if("`v'" == "tpres"){
			local thres = 90
			local min = 90
		}
		else if("`v'" == "fac"){
			local thres = 95
			local min = 93 // for functional facilities there is less variation, then being close to 90 is not enough
		}
		else{
			local thres = 80
			local min = 80
		}
		
		*run rd 
		
		if("`v'" != "satt"){
			
			preserve
			
			*keep event mar relative time and variable of interest
			
			keep stack mar relativetime mar_`v'
			
			/*for the rd we need to compare the flagging period (relative time 0) with the period of 
			the punishment (relative time 1). Then we create the lag of the markaz variable for 1, 
			to have both values of 1 and 0 in the  same row*/
			
			gen temp = mar_`v' if relativetime == 0
			bys stack mar (relativetime): egen mar_`v'_lag0 = max(temp) // period 0 outcome
			drop temp
			
			*keep only the iterest relative time
			
			keep if relativetime == 1 // so compare outcome in 1 with just created outcome in 0
			drop relativetime
			
			*create variables to populate
			
			gen bw1 = .
			gen bias1 = .
			
			* estimate rd: we have to iterate over each event dataset
			
			levelsof stack // all possible event-dates 
			foreach d in `r(levels)'{
				
				display `d'
				qui sum mar_`v'_lag0 if stack == `d'
				*conditions to ensure if threshold sample exist

				if((`r(min)' < `min' & `r(N)' > 50 & "`v'" == "tpres"  )     | /// general conditions
				   (`r(min)' < `min' & `r(N)' > 50 & "`v'" == "fac" & `d' != 44 & `d' != 62 & `d' != 64)     | /// general conditions
				   (`r(min)' < `min' & `r(N)' > 30 & "`v'" == "eng" & `d' != 47 )     | /// general conditions: less N for eng to ensure "some" threshold
				   (`r(min)' < `min' & `r(N)' > 50 & "`v'" == "math" & `d' != 47)     | /// conditions for math
				   (`r(min)' < `min' & `r(N)' > 50 & "`v'" == "urdu" & `d' != 49)       /// conditions for urdu
				  ){ // set up conditions for events that have enough obs (fix some urdu problems)
					
					*run the optimal bandwidth selection: Cattaneo and Calonico
					
					rdbwselect mar_`v' mar_`v'_lag0 if stack == `d', ///
						c(`thres') p(2) q(3) kernel(triangular) bwselect(mserd) vce(cluster mar) all

					if(`e(h_mserd)' < `e(b_mserd)'){ //if effectively exist a bandwidth
						
						*calculate auxiliary variables
						
						replace bw1 = `e(h_cercomb1)' if stack == `d'
						replace bias1 = `e(b_cercomb1)' if stack == `d'
						
					} // end of if statement of existance of bandwidth
				
				} // end of if statament of existance of rd for each stack

			} // end of loop over stacks for rd procedure
			
			* variables for rd samples	
			
			gen rd1 = (mar_`v'_lag0 >= `thres' - bw1 & mar_`v'_lag0 <= `thres' + bw1 & !missing(bw1)) 
			gen biasrd1 = (mar_`v'_lag0 >= `thres' - bias1 & mar_`v'_lag0 <= `thres' + bias1 & !missing(bw1))

			
		} //  end if statement for all except student attendance
		else{ // because student attendance threshold is not constant, need to recenter to 0	
		
			/*for student attendance the thresholds change in time, then we have to normalize 
			threshold to 0*/
			
			preserve
			
			*keep event mar relative time and variable of interest
			
			keep stack mar relativetime mar_`v' green_`v'
			
			/*for the rd we need to compare the flagging period (relative time 0) with the period of 
			the punishment (relative time 1). Then we create the lag of the markaz variable for 1, 
			to have both values of 1 and 0 in the  same row*/
			
			gen temp = mar_`v' if relativetime == 0
			bys stack mar (relativetime): egen mar_`v'_lag0 = max(temp) // period 0 outcome
			drop temp
			
			*keep only the iterest relative time
			
			keep if relativetime == 1 // so compare outcome in 1 with just created outcome in 0
			drop relativetime
			
			*create variables to populate
			
			gen bw1 = .
			gen bias1 = .

			* need to center as in satt thresholds are not constant
			
			gen c_mar_`v' = mar_`v' - green_`v'
			gen c_mar_`v'_lag0 = mar_`v'_lag0 - green_`v'
			
			* estimate rd: we have to iterate over each event dataset
			
			levelsof stack // all possible event-dates 
			foreach d in `r(levels)'{

				qui sum c_mar_`v'_lag0 if stack == `d'
				if(`r(min)' < -2 &  `r(N)' > 50 ){ // from 0 to -2 to avoid conformability error
					
					*run the optimal bandwidth selection: Cattaneo and Calonico
					
					rdbwselect c_mar_`v' c_mar_`v'_lag0 if stack == `d', ///
						c(0) p(2) q(3) kernel(triangular) bwselect(mserd) vce(cluster mar) all
						
					if(`e(h_mserd)' < `e(b_mserd)'){
						
						*calculate auxiliary variables
						replace bw1 = `e(h_cercomb1)' if stack == `d'
						replace bias1 = `e(b_cercomb1)' if stack == `d'
						
					} // end of if statement of existance of bandwidth
					
				} // end of if statament of existance of rd for each stack

			} // end of loop over stacks for rd procedure
			
			*variables for samples	
			
			gen rd1 = (c_mar_`v'_lag0 >= 0 - bw1 & c_mar_`v'_lag0 <= 0 + bw1 & !missing(bw1)) 
			gen biasrd1 = (c_mar_`v'_lag0 >= 0 - bias1 & c_mar_`v'_lag0 <= 0 + bias1 & !missing(bw1))
		
		} //  end else statement for student attendance
		
		* save tempfile
		
		keep stack mar rd1 biasrd1 bw1 bias1
		tempfile rd_sample
		save `rd_sample'
		restore //note the preserve for this restore is within the rd procedure
		
		*merge it with the original stacked data
		
		merge m:1 stack mar using `rd_sample'
		
		* keep desired observations
		
		keep if _merge == 3
		drop _merge

		* merge with original: all schools per mar and date
		joinby mar date_treat using "$analysis/processed/cc_datapacks.dta"

		* mean teachers per markaz
		gen temp = totalteachers if relativetime < 0
		bys stack mar: egen avg_totalreportedteachers_mar = mean(temp) 
		drop temp

		* save
	
		save "$analysis/processed/stacked/cc_stackdata`i'_`v'_orange.dta", replace // i = post period, v = outcome
	
		display("finish variable `v' with post periods `i'")

	} // end loop statement for post period i
	
	*after the last `i' post period, it starts again for the next variable v
	display("finish variable `v', pasing to the next one")

} // end loop statement for all variables

*---------------------------------------------------------------------------------------------------
**# 6. tehsil red flagging stacking #

//1. create event panel
//2. create and adjust event-panel: threshold sample, additionales variables

/*to ensure enough variation we were using 50 markaz minimum per stack. Because we are now using 
tehsils, we need to use an smaller sample size per markaz to define flagged tehsils around the 
threshold and some specific tweking by variable to ensure it works */

local treatments tpres satt fac eng math urdu // all flagging outcomes
foreach v of local treatments{
	
	*iterate over all possible post-periods
	
	forvalues i = 5(1)5{ 
		
		* trick for later create empty temporary file to apend all other evet-panels
		
		clear		
		gen stack = 0
		tempfile stack
		save `stack'
		
		* main data: balanced dataset
		
		use "$analysis/processed/cc_datapacks.dta", clear
		drop if wing == 3 // we do not consider secondary schools (not subject to monitoring)
		/* create time id: date version has gaps between may and september. The new variable takes 
		continuous values since 1, hence, there is no gap
		*/
		egen date_treat_e = group(date_treat) // date indicator for iterations

		* validate mar with double assignment of flagging		
		gen copy = tehsil_treat_`v'_lead // create a copy of the original variable
		bys tehsilwing date_treat: egen templead = nvals(tehsil_treat_`v'_lead) //some obs with double accounting
		bys tehsilwing date_treat: egen temp = nvals(tehsil_treat_`v'_) // original date also have doubles
		
		*fix original date
		* define as the majority of schools reporting (less than 1% so no sensitive)
			*count ones and zeroes
		gen zero = 1 if temp == 2 & tehsil_treat_`v'_ == 0
		gen ones = 1 if temp == 2 & tehsil_treat_`v'_ == 1
		bys tehsilwing date_treat: egen numzeros = sum(zero) if temp == 2
		bys tehsilwing date_treat: egen numones = sum(ones) if temp == 2
		replace tehsil_treat_`v'_ = 0 if numzeros > numones & temp == 2
		replace tehsil_treat_`v'_ = 1 if numzeros <= numones & temp == 2
		
		drop zero ones numzeros numones
		
		* fix lead flagging
		
		bys tehsilwing (date_treat `v' emis): gen t = tehsil_treat_`v'_[_n-1] // update flagging
		bys tehsilwing date_treat (`v' emis): gen tord = _n // set order based on `v'
		replace t = . if tord != 1 // set to missing all except the immediatly before observation for each mar
		bys tehsilwing date_treat: egen tmax = max(t) // generalize flagging
		replace tehsil_treat_`v'_lead = tmax if templead == 2 // apply only to those needed to be adjusted
		replace tehsil_treat_`v'_lead = copy if templead == 2 & tehsil_treat_`v'_lead == . // missing replace with original
		drop templead temp t tord tmax copy

		* still double accounting, basically from schools changing mar into a new mar
		* define as the majority of schools reporting (less than 1% so no sensitive)
		bys tehsilwing date_treat: egen templead = nvals(tehsil_treat_`v'_lead) //some obs with double accounting
			*count ones and zeroes
		gen zero = 1 if templead == 2 & tehsil_treat_`v'_lead == 0
		gen ones = 1 if templead == 2 & tehsil_treat_`v'_lead == 1
		bys tehsilwing date_treat: egen numzeros = sum(zero) if templead == 2
		bys tehsilwing date_treat: egen numones = sum(ones) if templead == 2
		replace tehsil_treat_`v'_lead = 0 if numzeros > numones & templead == 2
		replace tehsil_treat_`v'_lead = 1 if numzeros <= numones & templead == 2
		
		drop zero ones numzeros numones templead
		
		/* one additional thing making results unstable: tehsil might have 
		multiple values */
		bys tehsilwing date_treat: egen temp = nvals(tehsil_`v')
		bys tehsilwing date_treat: egen t = mean(tehsil_`v') if temp > 1
		replace tehsil_`v' = t if temp > 1
		
		drop temp t 
		
		* last, standardize thresholds!
		* mainly for tehsil, where markaz have different red threshold, it might be problematic
		bys tehsilwing: egen temp = mean(red_`v')
		replace red_`v' = temp
		drop temp

		* keep unique mar and date_treat

		*duplicates drop mar date_treat, force // this way of dropping duplicates might be unstable
		* stable solution to drop duplicates
		sort tehsilwing date_treat tehsil_treat_`v'_lead tehsil_`v' `v' emis
		gen random = runiform() // generate random variable (note the seed in 0_setup)
		sort tehsilwing date_treat tehsil_treat_`v'_lead tehsil_`v' `v' emis random
        bys tehsilwing date_treat (tehsil_treat_`v'_lead tehsil_`v' `v' emis random): gen ord = _n // ordering
		keep if ord == 1
		drop random ord		
				
		keep tehsilwing date_treat date_treat_e tehsil_`v' tehsil_treat_`v'_lead red_`v'

		* define dates at which a treatment will be stackedators by which 

		gen treat_dates = date_treat_e if ((tehsil_treat_`v'_lead == 1) & date_treat > tm(2011m12)) // 2011m12 first flag, but we are using as event the lead

		/* we define datasets for each date where a flag ocurred, so the flag date is the center of 
		each event-data. Note also that date_treat_e correspond to the relative time 1 (punish), 
		then we always will have date_treat_e - 5 to have preperiods (-1, -2, -3, -4) and 0 (flag). 
		We are only changing t based on the post periods, where the minimum is date_treat_e + 1 
		*/

		display("starting variable `v' time `i'")

		* iterate creation of event-panels 
		levelsof treat_dates
		foreach d in `r(levels)'{ 
			
			preserve
			
			*dataset between t+i to t-5 
			
			keep if ((date_treat_e <= `d' + `i') & (date_treat_e >= `d' - 5)) // keep desired time span
			
			*drop if mar outcome is empty
			
			drop if missing(tehsil_`v')
			
			*adjust treatment in case of missings
			
			bys tehsilwing (date_treat): replace tehsil_treat_`v'_lead = tehsil_treat_`v'_[_n-1] if missing(tehsil_treat_`v'_lead)
			
			*drop units that do not have t and t-1
			
			bys tehsilwing: egen num_tehsil = count(tehsilwing) //count number of times mar appear
			gen num_periods = 6 + `i' // markaz that appear consecutively 6 + i periods
			keep if num_tehsil == num_periods // only mars that appear all the time span
			drop num_periods num_tehsil

			*conditional if exist data
			
			if(_N > 0){
				
				bys tehsilwing (date_treat): gen time_id = _n // create time id
					
				/* we must eliminate mar treated in t-n: in such case, a unit would be treated 
				twice (in t-1 and t) or would be treated only on t-1, in which case would not be 
				a clean control
				*/
				
				gen before = (time_id < 6)  // goes from 1 to 6 + `i', so always drop treated in < 6
				sort tehsilwing date_treat // sort by date within mar
				bys tehsilwing (date_treat): egen treated_before = max(tehsil_treat_`v'_lead) if (before == 1) // treated before time 6
				bys tehsilwing: egen max_before = max(treated_before)
				drop if max_before == 1 // drop if treated before
				drop treated_before max_before
					
				*if there still exist data: dropping treated before might lead to no-data for event
				if(_N > 0){
						
					/*if treated in t+1 but not in t, we must drop, as would not be treated in 
					the main event data we are centering the event-data
					*/
						
					*treated in t+1
					gen stag1 = ((tehsil_treat_`v'_lead == 1) & (time_id > 6))
						
					*treated in t
					gen stag2 = ((tehsil_treat_`v'_lead == 1) & (time_id == 6))
						
					*generalizing to all units
					
					bys tehsilwing: egen sum_stag1 = max(stag1)
					bys tehsilwing: egen sum_stag2 = max(stag2)

					*drop not treated in main event
					
					gen drop_units = (sum_stag2 == 0 & sum_stag1 == 1) // not treated in t, but treated in t+1
					drop if drop_units == 1
					drop before stag1 stag2 sum_stag1 sum_stag2 drop_units
						
					*stack unique id
					
					gen stack = `d'
					drop time_id
					bys tehsilwing (date_treat): gen time_id = _n // readjust timeid
					
					
				} // end if statement
				else if(_N == 0){ // if there is no data after dropping the not clean controls
						
					*display if no observations
					display "`d' have 0 observations"
						
				} // end else statement 
			
			} // end if statement
			else if(_N == 0){ // if there is no data for the particular event date
				
				*display if no observations
				display "`d' have 0 observations"

			} // end else statement
			
			*append evet-panel datatsets
			append using `stack' // append to original stack! then for next iterations we rewritte
			tempfile stack
			save `stack'
				
			restore // recover original data to create the next event time panel
		
		} // end of loop statement for event panels of outcomes
		
		* use temporary stacked dataset
		
		use `stack', clear

		* drop "temporary file stack"

		drop if stack == 0

		* compress for memory purposes

		compress

		* relative time: normalize to 0 the flag period (time_id == 5)
		
		gen relativetime = time_id - 5

		/* create constant treatment variable: if flag_period = 1 in relativetime == 1 to validate, 
		recreate main treatment
		*/
		
		bys stack tehsilwing: gen temp_lead = ((tehsil_treat_`v'_lead == 1) & (time_id == 6))
		bys stack tehsilwing: egen flagged = max(temp_lead) //if ever flagged, then treated
		drop temp_lead
		drop if missing(flagged) // drop all the observations that do not report data en the flagging period

		* post-periods
		
		//after punish period
		gen postpunish = (relativetime > 0)
		//after flag period
		gen postflag = (relativetime > -1)
 
		/* regression discontinuity samples:
		
		we need a tighter comparisson of treated and control units, then we use an optimal bandwidth 
		to define for each event-dataset the group of markaz that are around the threshold
		*/
		
		*define thresholds: scores have the same threshold and for student attendance need to defined it separately
		
		if("`v'" == "tpres"){
			local thres = 86
			local min = 84
		}
		else if("`v'" == "fac"){
			local thres = 90
			local min = 87 // for functional facilities there is less variation, then being close to 90 is not enough
		}
		else{
			local thres = 70
			local min = 68
		}
		
		*run rd 
		
		if("`v'" == "tpres" | "`v'" == "fac"){
			
			preserve
			
			*keep event mar relative time and variable of interest
			
			keep stack tehsilwing relativetime tehsil_`v'
			
			/*for the rd we need to compare the flagging period (relative time 0) with the period of 
			the punishment (relative time 1). Then we create the lag of the markaz variable for 1, 
			to have both values of 1 and 0 in the  same row*/
			
			gen temp = tehsil_`v' if relativetime == 0
			bys stack tehsilwing (relativetime): egen tehsil_`v'_lag0 = max(temp) // period 0 outcome
			drop temp
			
			*keep only the iterest relative time
			
			keep if relativetime == 1 // so compare outcome in 1 with just created outcome in 0
			drop relativetime
			
			*create variables to populate
			
			gen bw1 = .
			gen bias1 = .
			
			* estimate rd: we have to iterate over each event dataset
			
			levelsof stack // all possible event-dates 
			foreach d in `r(levels)'{
				
				display `d'
				qui sum tehsil_`v'_lag0 if stack == `d'
				
				*conditions to ensure if threshold sample exist
				if((`r(min)' < `min' & `r(N)' > 10 & "`v'" == "tpres" & `d' != 37) | /// general conditions - for stack 23 there is a bug with rdbwselect!
				   (`r(min)' < `min' & `r(N)' > 10 & "`v'" == "fac"   & `d' != 40) /// general conditions: specific for fac
				  ){ // set up conditions for events that have enough obs (fix some urdu problems)
					
					*run the optimal bandwidth selection: Cattaneo and Calonico
					
					rdbwselect tehsil_`v' tehsil_`v'_lag0 if stack == `d', ///
						c(`thres') p(2) q(3) kernel(triangular) bwselect(mserd) vce(cluster tehsilwing) all
					
					if(`e(h_mserd)' < `e(b_mserd)'){ //if effectively exist a bandwidth
						
						*calculate auxiliary variables
						
						replace bw1 = `e(h_cercomb1)' if stack == `d'
						replace bias1 = `e(b_cercomb1)' if stack == `d'
						
					} // end of if statement of existance of bandwidth
				
				} // end of if statament of existance of rd for each stack

			} // end of loop over stacks for rd procedure
			
			* variables for rd samples	
			
			gen rd1 = (tehsil_`v'_lag0 >= `thres' - bw1 & tehsil_`v'_lag0 <= `thres' + bw1 & !missing(bw1)) 
			gen biasrd1 = (tehsil_`v'_lag0 >= `thres' - bias1 & tehsil_`v'_lag0 <= `thres' + bias1 & !missing(bw1))

			
		} //  end if statement for all except student attendance
		else if("`v'" == "eng" | "`v'" == "math" | "`v'" == "urdu"){ // low number of observations, use different bandwidth definition
			
			preserve
			
			*keep event mar relative time and variable of interest
			
			keep stack tehsilwing relativetime tehsil_`v'
			
			/*for the rd we need to compare the flagging period (relative time 0) with the period of 
			the punishment (relative time 1). Then we create the lag of the markaz variable for 1, 
			to have both values of 1 and 0 in the  same row*/
			
			gen temp = tehsil_`v' if relativetime == 0
			bys stack tehsilwing (relativetime): egen tehsil_`v'_lag0 = max(temp) // period 0 outcome
			drop temp
			
			*keep only the iterest relative time
			
			keep if relativetime == 1 // so compare outcome in 1 with just created outcome in 0
			drop relativetime
			
			*create variables to populate
			
			gen bw1 = .
			gen bias1 = .
			
			* estimate rd: we have to iterate over each event dataset
			
			levelsof stack // all possible event-dates 
			foreach d in `r(levels)'{
				
				display `d'
				qui sum tehsil_`v'_lag0 if stack == `d'
				if((`r(min)' < `min' & `r(N)' > 10 & "`v'" == "eng"  & `d' != 65)     | /// general conditions
				   (`r(min)' < `min' & `r(N)' > 10 & "`v'" == "math" & `d' != 57)     | /// conditions for math
				   (`r(min)' < `min' & `r(N)' > 10 & "`v'" == "urdu" & `d' != 55 & `d' != 56)       /// conditions for urdu
				  ){ // set up conditions for events that have enough obs (fix some urdu problems)
					
					*run the optimal bandwidth selection: Cattaneo and Calonico
					
					rdbwselect tehsil_`v' tehsil_`v'_lag0 if stack == `d', ///
						c(`thres') p(2) q(3) kernel(triangular) bwselect(msetwo) vce(cluster tehsilwing) all
					
					*calculate auxiliary variables
					if(`e(h_mserd)' < `e(b_mserd)'){
						
						*calculate auxiliary variables
						replace bw1 = `e(h_cercomb1)' if stack == `d'
						replace bias1 = `e(b_cercomb1)' if stack == `d'
						
					} // end of if statement of existance of bandwidth
				
				} // end of if statament of existance of rd for each stack

			} // end of loop over stacks for rd procedure
			
			* variables for rd samples	
			
			gen rd1 = (tehsil_`v'_lag0 >= `thres' - bw1 & tehsil_`v'_lag0 <= `thres' + bw1 & !missing(bw1)) 
			gen biasrd1 = (tehsil_`v'_lag0 >= `thres' - bias1 & tehsil_`v'_lag0 <= `thres' + bias1 & !missing(bw1))

			
		} //  end if statement for all except student attendance
		else{ // because student attendance threshold is not constant, need to recenter to 0	
		
			/*for student attendance the thresholds change in time, then we have to normalize 
			threshold to 0*/
			
			preserve
			
			*keep event mar relative time and variable of interest
			
			keep stack tehsilwing relativetime tehsil_`v' red_`v'
			
			/*for the rd we need to compare the flagging period (relative time 0) with the period of 
			the punishment (relative time 1). Then we create the lag of the markaz variable for 1, 
			to have both values of 1 and 0 in the  same row*/
			
			gen temp = tehsil_`v' if relativetime == 0
			bys stack tehsilwing (relativetime): egen tehsil_`v'_lag0 = mean(temp) // period 0 outcome
			drop temp
			
			*keep only the iterest relative time
			
			keep if relativetime == 1 // so compare outcome in 1 with just created outcome in 0
			drop relativetime
			
			*create variables to populate
			
			gen bw1 = .
			gen bias1 = .

			* need to center as in satt thresholds are not constant
			
			gen c_tehsil_`v' = tehsil_`v' - red_`v'
			gen c_tehsil_`v'_lag0 = tehsil_`v'_lag0 - red_`v'
			
			* estimate rd: we have to iterate over each event dataset
			
			levelsof stack // all possible event-dates 
			foreach d in `r(levels)'{
				
				display `d'
				qui sum c_tehsil_`v'_lag0 if stack == `d'
				if(`r(min)' < -3 &  `r(N)' > 10 & `d' != 16){ // from 0 to -2 to avoid conformability error
					
					*run the optimal bandwidth selection: Cattaneo and Calonico
					
					rdbwselect c_tehsil_`v' c_tehsil_`v'_lag0 if stack == `d', ///
						c(0) p(2) q(3) kernel(triangular) bwselect(mserd) vce(cluster tehsilwing) all
						
					if(`e(h_mserd)' < `e(b_mserd)'){
						
						*calculate auxiliary variables
						replace bw1 = `e(h_cercomb1)' if stack == `d'
						replace bias1 = `e(b_cercomb1)' if stack == `d'
						
					} // end of if statement of existance of bandwidth
					
				} // end of if statament of existance of rd for each stack

			} // end of loop over stacks for rd procedure
			
			*variables for samples	
			
			gen rd1 = (c_tehsil_`v'_lag0 >= 0 - bw1 & c_tehsil_`v'_lag0 <= 0 + bw1 & !missing(bw1)) 
			gen biasrd1 = (c_tehsil_`v'_lag0 >= 0 - bias1 & c_tehsil_`v'_lag0 <= 0 + bias1 & !missing(bw1))
		
		} //  end else statement for student attendance
		
		* save tempfile
		
		keep stack tehsilwing rd1 biasrd1 bw1 bias1
		tempfile rd_sample
		save `rd_sample'
		restore //note the preserve for this restore is within the rd procedure
		
		*merge it with the original stacked data
		
		merge m:1 stack tehsilwing using `rd_sample'
		
		* keep desired observations
		
		keep if _merge == 3
		drop _merge

		* merge with original: all schools per mar and date
		
		joinby tehsilwing date_treat using "$analysis/processed/cc_datapacks.dta"

		* mean teachers per markaz
		gen temp = totalteachers if relativetime < 0
		bys stack tehsilwing: egen avg_totalreportedteachers_tehsil = mean(temp) 
		drop temp

		* save
	
		save "$analysis/processed/stacked/cc_stackdata`i'_`v'_tehsil.dta", replace // i = post period, v = outcome
	
		display("finish variable `v' with post periods `i'")

	} // end loop statement for post period i
	
	*after the last `i' post period, it starts again for the next variable v
	display("finish variable `v', pasing to the next one")

} // end loop statement for all variables
















