/*--------------------------------------------------------------------------------------------------
Intensity to exposure to command and control

	Outline:
	
	1. RDD continuity assumption
	   - Figure B1  

	2. monotonicity assumption
	   - Figure B2

	3. orthogonality of the instrument
		- Table 3
		- Table B2
		
	4. regressions: non-parametric approach
		- Table 4
		- Table B5
		- Figure B3
		
	5. RDA controls	
		- Table B3
		
	6. alternative instrument definitions
		- Table B4
		
	7. regressions: relaxing linearity assumption
		- Figure B4

	8.	school performance
		- Table B6
	   
	9. regressions: heterogeneity by district performance
		- Table B7
	
	10. regressions: heterogeneity by political alignment
		- Table B8
		
	11. regressions: effect on budget
		- Table 5
		- Figure C2

	12. regressions: effect on effort
	   - Table C1
	   - Figure C1
	
--------------------------------------------------------------------------------------------------*/
*
*
*
*
*
*---------------------------------------------------------------------------------------------------
**# 1. RDD continuity assumption #

***** Figure B1
if(1){
	
use "$analysis/processed/cc_datapacks.dta", clear

drop if wing == 3 // we do not consider secondary schools (not subject to monitoring)
drop if year == 2011
keep if original == 1

bys mar date_treat: egen school = nvals(emis)

collapse (mean) mar_tpres = tpres mar_satt = satt mar_fac = fac mar_math = math mar_eng = eng mar_urdu = urdu ///
		        red_tpres red_satt red_fac red_math red_eng red_urdu ///
				school, by(date_treat mar year)

gen tpres = mar_tpres - red_tpres
gen satt =  mar_satt - red_satt
gen fac = mar_fac - red_fac
gen math = mar_math - red_math 
gen eng = mar_eng - red_eng 
gen urdu = mar_urdu - red_urdu

*graphs for outcomes
if(1){

rddensity tpres
rddensity tpres, plot hist_width(0.6 0.6) ///
	graph_opt( ///
		graphregion(col(white)) ///
		ylabel(, nogrid) ///
		xlabel(-6(1)5, nogrid) ///
		xscale(r(-6 5)) ///
		xline(0) ///
		legend(off) ///
		title("") ///
		xtitle("Distance to the threshold", size(vlarge)) ///
		note("Bias-corrected manipulation test p-value: `=string(`=e(pv_q)',"%8,2f")'", size(vlarge)) ///
	)
	
* save graph
graph export "$analysis/figures/causal/FigureB1_tpres.pdf", replace		

rddensity satt 	
rddensity satt, plot hist_width(0.6 0.6) ///
	graph_opt( ///
		graphregion(col(white)) ///
		ylabel(, nogrid) ///
		xlabel(-8(1)6, nogrid) ///
		xscale(r(-8 6)) ///
		xline(0) ///
		legend(off) ///
		title("") ///
		xtitle("Distance to the threshold", size(vlarge)) ///
		note("Bias-corrected manipulation test p-value: `=string(`=e(pv_q)',"%8,2f")'", size(vlarge)) ///
	)
	
* save graph
graph export "$analysis/figures/causal/FigureB1_satt.pdf", replace

rddensity fac, fitselect(restricted) nomasspoints
rddensity fac, fitselect(restricted) nomasspoints plot hist_width(1 1) ///
	graph_opt( ///
		graphregion(col(white)) ///
		ylabel(, nogrid) ///
		xlabel(-4(1)4, nogrid) ///
		xscale(r(-4 4)) ///
		xline(0) ///
		legend(off) ///
		title("") ///
		xtitle("Distance to the threshold", size(vlarge)) ///
		note("Bias-corrected manipulation test p-value: `=string(`=e(pv_q)',"%8,2f")'", size(vlarge)) ///
	)
	
* save graph
graph export "$analysis/figures/causal/FigureB1_fac.pdf", replace
}

*graphs for scores
if(1){
	
rddensity math if year >= 2016
rddensity math if year >= 2016, plot hist_width(0.8 0.8) ///
	graph_opt( ///
		graphregion(col(white)) ///
		ylabel(, nogrid) ///
		xlabel(-12(2)18, nogrid) ///
		xscale(r(-12 18)) ///
		xline(0) ///
		legend(off) ///
		title("") ///
		xtitle("Distance to the threshold", size(vlarge)) ///
		note("Bias-corrected manipulation test p-value: `=string(`=e(pv_q)',"%8,2f")'", size(vlarge)) ///
	)

* save graph
graph export "$analysis/figures/causal/FigureB1_math.pdf", replace

rddensity eng if year >= 2016	
rddensity eng if year >= 2016, plot hist_width(0.8 0.8) ///
	graph_opt( ///
		graphregion(col(white)) ///
		ylabel(, nogrid) ///
		xlabel(-12(2)12, nogrid) ///
		xscale(r(-12 12)) ///
		xline(0) ///
		legend(off) ///
		title("") ///
		xtitle("Distance to the threshold", size(vlarge)) ///
		note("Bias-corrected manipulation test p-value: `=string(`=e(pv_q)',"%8,2f")'", size(vlarge)) ///
	)
	
* save graph
graph export "$analysis/figures/causal/FigureB1_eng.pdf", replace

rddensity urdu if year >= 2016
rddensity urdu if year >= 2016, plot hist_width(0.8 0.8) ///
	graph_opt( ///
		graphregion(col(white)) ///
		ylabel(, nogrid) ///
		xlabel(-8(2)8, nogrid) ///
		xscale(r(-8 8)) ///
		xline(0) ///
		legend(off) ///
		title("") ///
		xtitle("Distance to the threshold", size(vlarge)) ///
		note("Bias-corrected manipulation test p-value: `=string(`=e(pv_q)',"%8,2f")'", size(vlarge)) ///
	)
	
* save graph
graph export "$analysis/figures/causal/FigureB1_urdu.pdf", replace
}

}

*---------------------------------------------------------------------------------------------------
**# 2. monotonicity assumption #

use "$analysis/processed/cc_mar_year_data.dta", clear

***** Figure B2
if(1){
	
*residualize both
local vars tpres satt fac
foreach t of local vars{

reghdfe flag`t' [aw = avg_totalreportedteachers_mar], absorb(mar year district##c.year thres`t') vce(cluster mar) resid(flag`t'resid) 
reghdfe flag`t'_thres [aw = avg_totalreportedteachers_mar], absorb(mar year district##c.year thres`t') vce(cluster mar) resid(flag`t'_thresresid) 

}

*graph!

cmogram flagtpresresid flagtpres_thresresid, scatter histopts(bin(8)) gen(tpresbins) 
scatter tpresbinsy0 tpresbinsx0, ///
	connect(L) graphregion(col(white)) mcol(navy) lcol(navy) ///
	ytitle("# Times flagged - D (residual)", size(vlarge)) ///
	xtitle("# Times flagged threshold - Z (residual)", size(vlarge)) ///
	xlabel(-3(1)4, nogrid) xscale(r(-3 4)) ylabel(-3(1)5, nogrid) yscale(r(-3 5))
	
	* save graph
graph export "$analysis/figures/causal/FigureB2_tpres.pdf", replace		

cmogram flagsattresid flagsatt_thresresid, scatter histopts(bin(8)) gen(sattbins) 
scatter sattbinsy0 sattbinsx0, ///
	connect(L) graphregion(col(white)) mcol(navy) lcol(navy) ///
	ytitle("# Times flagged - D (residual)", size(vlarge)) ///
	xtitle("# Times flagged threshold - Z (residual)", size(vlarge)) ///
	xlabel(-3(1)3, nogrid) xscale(r(-3 3)) ylabel(-3(1)5, nogrid) yscale(r(-3 5))
	
	* save graph
graph export "$analysis/figures/causal/FigureB2_satt.pdf", replace		

cmogram flagfacresid flagfac_thresresid, scatter histopts(bin(8)) gen(facbins) 
scatter facbinsy0 facbinsx0, ///
	connect(L) graphregion(col(white)) mcol(navy) lcol(navy) ///
	ytitle("# Times flagged - D (residual)", size(vlarge)) ///
	xtitle("# Times flagged threshold - Z (residual)", size(vlarge)) ///
	xlabel(-3(1)4, nogrid) xscale(r(-3 4)) ylabel(-3(1)5, nogrid) yscale(r(-3 5))
	
	* save graph
graph export "$analysis/figures/causal/FigureB2_fac.pdf", replace	


*residualize both
local vars math eng urdu
foreach t of local vars{

reghdfe flag`t' if year >= 2016 [aw = avg_totalreportedteachers_mar], absorb(mar year district##c.year thres`t') vce(cluster mar) resid(flag`t'resid)
reghdfe flag`t'_thres if year >= 2016 [aw = avg_totalreportedteachers_mar], absorb(mar year district##c.year thres`t') vce(cluster mar) resid(flag`t'_thresresid)

}

cmogram flagmathresid flagmath_thresresid, scatter histopts(bin(7)) gen(mathbins) 
scatter mathbinsy0 mathbinsx0, ///
	connect(L) graphregion(col(white)) mcol(navy) lcol(navy) ///
	ytitle("# Times flagged - D (residual)", size(vlarge)) ///
	xtitle("# Times flagged threshold - Z (residual)", size(vlarge)) ///
	xlabel(-3(1)2, nogrid) xscale(r(-3 2)) ylabel(-4(1)3, nogrid) yscale(r(-4 3))
	
	* save graph
graph export "$analysis/figures/causal/FigureB2_math.pdf", replace		

cmogram flagengresid flageng_thresresid, scatter histopts(bin(7)) gen(engbins) 
scatter engbinsy0 engbinsx0, ///
	connect(L) graphregion(col(white)) mcol(navy) lcol(navy) ///
	ytitle("# Times flagged - D (residual)", size(vlarge)) ///
	xtitle("# Times flagged threshold - Z (residual)", size(vlarge)) ///
	xlabel(-4(1)3, nogrid) xscale(r(-4 3)) ylabel(-6(1)4, nogrid) yscale(r(-6 4))
	
	* save graph
graph export "$analysis/figures/causal/FigureB2_eng.pdf", replace		

cmogram flagurduresid flagurdu_thresresid, scatter histopts(bin(7)) gen(urdubins) 
scatter urdubinsy0 urdubinsx0, ///
	connect(L) graphregion(col(white)) mcol(navy) lcol(navy) ///
	ytitle("# Times flagged - D (residual)", size(vlarge)) ///
	xtitle("# Times flagged threshold - Z (residual)", size(vlarge)) ///
	xlabel(-2(1)2, nogrid) xscale(r(-2 2)) ylabel(-2(1)3, nogrid) yscale(r(-2 3))
	
	* save graph
graph export "$analysis/figures/causal/FigureB2_urdu.pdf", replace		

}

*---------------------------------------------------------------------------------------------------
**# 3. orthogonality of the instrument #

**** Table 3
*our current version uses flag in t and outcome in t + 1
*orthogonality use flag in t and outcomes in t-1
use "$analysis/processed/cc_mar_year_data.dta", clear

local vars tpres satt fac math eng urdu
foreach t of local vars{
	
rename mar_`t'_f mar_f
rename flag`t'norm flagnorm
rename flag`t'_thresnorm flag_thresnorm
	
* endogenous as outcomes

eststo olse`t'1: reghdfe mar_f flagnorm  if year !=., /// 
		absorb(mar year district##c.year) vce(cluster mar) 

qui estadd ysumm
qui sum mar_`t' if e(sample)
qui estadd scalar yobs `r(N)'
qui sum mar_f  
qui estadd scalar ymeanbef `r(mean)'
qui sum flag`t'	
qui estadd scalar ymeanflag `r(mean)'
qui estadd scalar ysdbef `r(sd)'
qui estadd local marfe "Yes"
qui estadd local timefe "Yes"
qui estadd local disfe "Yes"
qui estadd local thresfe "No"

eststo olse`t'2: reghdfe mar_f flagnorm if year !=., /// 
		absorb(mar year district##c.year thres`t') vce(cluster mar) 

qui estadd ysumm
qui sum mar_`t' if e(sample)
qui estadd scalar yobs `r(N)'
qui sum mar_f  
qui estadd scalar ymeanbef `r(mean)'
qui sum flag`t'_thres	
qui estadd scalar ymeanflag `r(mean)'
qui estadd scalar ysdbef `r(sd)'
qui estadd local marfe "Yes"
qui estadd local timefe "Yes"
qui estadd local disfe "Yes"
qui estadd local thresfe "Yes"

* instrument as outcomes

eststo olsi`t'1: reghdfe  mar_f flag_thresnorm  if year !=., /// 
		absorb(mar year district##c.year) vce(cluster mar) 
		
qui estadd ysumm
qui sum mar_`t' if e(sample)
qui estadd scalar yobs `r(N)'
qui sum mar_f  
qui estadd scalar ymeanbef `r(mean)'
qui sum flag`t'	
qui estadd scalar ymeanflag `r(mean)'
qui estadd scalar ysdbef `r(sd)'
qui estadd local marfe "Yes"
qui estadd local timefe "Yes"
qui estadd local disfe "Yes"
qui estadd local thresfe "No"

eststo olsi`t'2: reghdfe mar_f flag_thresnorm if year !=., /// 
		absorb(mar year district##c.year thres`t') vce(cluster mar) 
		
qui estadd ysumm
qui sum mar_`t' if e(sample)
qui estadd scalar yobs `r(N)'
qui sum mar_f  
qui estadd scalar ymeanbef `r(mean)'
qui sum flag`t'_thres
qui estadd scalar ymeanflag `r(mean)'
qui estadd scalar ysdbef `r(sd)'
qui estadd local marfe "Yes"
qui estadd local timefe "Yes"
qui estadd local disfe "Yes"
qui estadd local thresfe "Yes"

rename mar_f mar_`t'_f
rename flagnorm flag`t'norm 
rename flag_thresnorm flag`t'_thresnorm 

}

if(1){

*school performance
estout olsetpres2 olsesatt2 olsefac2 ///
	   olsitpres2 olsisatt2 olsifac2 ///
	using "$analysis/tables/causal/99_balance_marperf.tex", ///
	style(tex) /// style of exporting
	starl(* 0.10 ** 0.05 *** 0.01) /// significance stars
	cells(b(star fmt(%6.3f)) se(par fmt(%6.3f))) /// format of cells (coefficient and se)
	mlabels(none) /// no label for models
	collabels(none) /// no label for columns
	label /// labels for variables 
	varlabels(flagnorm "\# Times flagged\$_{t}$ -- D (z-score)" flag_thresnorm "\# Times flagged threshold\$_{t}$ -- Z (z-score)") /// rename vars in case no labels
	prehead(\begin{tabular}{lccc@{\hskip 0.1in}ccc} \toprule /// start of heading in tex table
	"\multicolumn{7}{l}{\textbf{Panel A: Markaz average schooling outcomes}} \\" /// panel name
	" & \multicolumn{6}{c}{\underline{Dependent variables (range: 0-100)}} \\" /// dependent variable title
	" & \multicolumn{1}{c}{Teacher} & \multicolumn{1}{c}{Student} & \multicolumn{1}{c}{Functional} & \multicolumn{1}{c}{Teacher} & \multicolumn{1}{c}{Student} & \multicolumn{1}{c}{Functional} \\" /// actual dependent variables
	"& \multicolumn{1}{c}{presence\$_{t-1}$} & \multicolumn{1}{c}{attendance\$_{t-1}$} & \multicolumn{1}{c}{facilities\$_{t-1}$} & \multicolumn{1}{c}{presence\$_{t-1}$} & \multicolumn{1}{c}{attendance\$_{t-1}$} & \multicolumn{1}{c}{facilities\$_{t-1}$} \\" /// this is just trick to have them in two lines
	" & (1) & (2) & (3) & (4) & (5) & (6) \\" ///
	"\cline{2-7} \addlinespace[0.5em]") ///
	///posthead(\midrule) /// line after heading
    prefoot(\midrule) /// line before footer
	stats(N N_clust ymeanbef ymeanflag ysdbef, fmt(%11.2gc %11.2gc a2 a2 a2) ///
	labels("N. of obs." "Number markaz" "Mean Dep. Var" "Mean \# Times flagged" "SD \# Times flagged")) /// stats to keep
	keep(flagnorm flag_thresnorm) /// order of variables
	replace // replace if it exist

*scores
estout olsemath2 olseeng2 olseurdu2 ///
	   olsimath2 olsieng2 olsiurdu2 ///
	using "$analysis/tables/causal/Table3.tex", ///
	style(tex) /// style of exporting
	starl(* 0.10 ** 0.05 *** 0.01) /// significance stars
	cells(b(star fmt(%6.3f)) se(par fmt(%6.3f))) /// format of cells (coefficient and se)
	mlabels(none) /// no label for models
	collabels(none) /// no label for columns
	label ///
	varlabels(flagnorm "\# Times flagged\$_{t}$ -- D (z-score)" flag_thresnorm " \# Times flagged threshold\$_{t}$ -- Z (z-score)") ///
	prehead("\midrule \multicolumn{7}{l}{\textbf{Panel B: Markaz average student scores}} \\" ///
	" & \multicolumn{6}{c}{\underline{Dependent variables (range: 0-100)}} \\" /// dependent variable title
	" & \multicolumn{1}{c}{Math\$_{t-1}$} & \multicolumn{1}{c}{English\$_{t-1}$} & \multicolumn{1}{c}{Urdu\$_{t-1}$} & \multicolumn{1}{c}{Math\$_{t-1}$} & \multicolumn{1}{c}{English\$_{t-1}$} & \multicolumn{1}{c}{Urdu\$_{t-1}$} \\" ///
	" & (1) & (2) & (3) & (4) & (5) & (6) \\" ///
	"\cline{2-7} \addlinespace[0.5em]") ///
	///posthead(\midrule) /// line after heading
	prefoot(\midrule) ///
	postfoot(\bottomrule \end{tabular}) /// this set end to table, note we put it here as we want to append panels
	stats(N N_clust ymeanbef ymeanflag ysdbef marfe timefe disfe thresfe, fmt(%11.2gc %11.2gc a2 a2 a2 a2 a2 a2 a2) ///
	labels("N. of obs." "Number markaz" "Mean Dep. Var" "Mean \#Times flagged" "SD \# Times flagged" ///
		   "\midrule Markaz FE" "Time FE" "District time trends" "\#Times in threshold\$_t$ FE")) /// stats to keep
	keep(flagnorm flag_thresnorm) /// order of variables
	topfile("$analysis/tables/causal/99_balance_marperf.tex") /// this joins the two panels into a single table
	replace // replace if it exist
}	

**** Table B2
* robustness non-parametric approach using sample from balanced table

if(1){
	
use "$analysis/processed/cc_mar_year_data.dta", clear

local vars tpres math // maximum sample for outcomes and scores
foreach t of local vars{

sort mar year // order so fixed effects use the same base
reghdfe  mar_`t'_f flag`t'norm if year !=., /// 
		absorb(mar year district##c.year) vce(cluster mar) 

gen mar`t'_sample = e(sample)

}

keep mar year martpres_sample marmath_sample
rename martpres_sample outcomes_sample
rename marmath_sample scores_samples

*tempfile
tempfile temp
save `temp'

use "$analysis/processed/cc_mar_emis_year_data.dta", clear

merge m:1 mar year using `temp'
	
*mean outcomes
local treatments tpres satt fac 
foreach t of local treatments{
	
	
	rename flag`t'_fnorm flagnorm
	rename flag`t'_thres_fnorm flag_thresnorm
	rename thres`t'_f thres
	
	label var flagnorm "Times flagged\$_{t}$ (Z-Score)"
	
	*ols
	eststo olsmar_`t': reghdfe `t' flagnorm if outcomes_sample == 1, /// 
		absorb(mar year district##c.year thres) vce(cluster mar) 
	qui estadd ysumm
	qui sum `t' if e(sample)
	qui estadd scalar yobs `r(N)'
	qui sum `t'_f  
	qui estadd scalar ymeanbef `r(mean)'
	qui sum flag`t'_f	
	qui estadd scalar ymeanflag `r(mean)'
	qui estadd scalar ysdbef `r(sd)'
	qui estadd local marfe "Yes"
	qui estadd local timefe "Yes"
	qui estadd local disfe "Yes"
	qui estadd local thresfe "Yes"

	*iv
	eststo ivmar_`t': ivreghdfe `t'  (flagnorm = ///
			 i.flagmonth`t'1_f i.flagmonth`t'2_f i.flagmonth`t'3_f i.flagmonth`t'4_f ///
			 i.flagmonth`t'10_f i.flagmonth`t'11_f i.flagmonth`t'12_f) if outcomes_sample == 1, ///
		ffirst absorb(mar year district##c.year thres) cluster(mar) 
		
	qui estadd ysumm
	qui sum `t' if e(sample)
	qui estadd scalar yobs `r(N)'
	qui sum `t'_f  
	qui estadd scalar ymeanbef `r(mean)'
	qui sum flag`t'_f	
	qui estadd scalar ymeanflag `r(mean)'
	qui estadd scalar ysdbef `r(sd)'
	qui estadd scalar ftest e(widstat)
	qui estadd local marfe "Yes"
	qui estadd local timefe "Yes"
	qui estadd local disfe "Yes"
	qui estadd local thresfe "Yes"
	
	rename thres thres`t'_f
	rename flagnorm flag`t'_fnorm 
	rename flag_thresnorm flag`t'_thres_fnorm 

}

*mean scores
local treatments math eng urdu
foreach t of local treatments{
	
	
	rename flag`t'_fnorm flagnorm
	rename flag`t'_thres_fnorm flag_thresnorm
	rename thres`t'_f thres
	
	label var flagnorm "Times flagged\$_{t}$ (Z-Score)"
	
	*ols
	eststo olsmar_`t': reghdfe `t' flagnorm if scores_sample == 1, /// 
		absorb(mar year district##c.year thres) vce(cluster mar) 
	qui estadd ysumm
	qui sum `t' if e(sample)
	qui estadd scalar yobs `r(N)'
	qui sum `t'_f  
	qui estadd scalar ymeanbef `r(mean)'
	qui sum flag`t'_f	
	qui estadd scalar ymeanflag `r(mean)'
	qui estadd scalar ysdbef `r(sd)'
	qui estadd local marfe "Yes"
	qui estadd local timefe "Yes"
	qui estadd local disfe "Yes"
	qui estadd local thresfe "Yes"

	*iv
	eststo ivmar_`t': ivreghdfe `t'  (flagnorm = ///
			 i.flagmonth`t'1_f i.flagmonth`t'2_f i.flagmonth`t'3_f i.flagmonth`t'4_f ///
			 i.flagmonth`t'10_f i.flagmonth`t'11_f i.flagmonth`t'12_f) if scores_sample == 1, ///
		ffirst absorb(mar year district##c.year thres) cluster(mar) 
		
	qui estadd ysumm
	qui sum `t' if e(sample)
	qui estadd scalar yobs `r(N)'
	qui sum `t'_f  
	qui estadd scalar ymeanbef `r(mean)'
	qui sum flag`t'_f	
	qui estadd scalar ymeanflag `r(mean)'
	qui estadd scalar ysdbef `r(sd)'
	qui estadd scalar ftest e(widstat)
	qui estadd local marfe "Yes"
	qui estadd local timefe "Yes"
	qui estadd local disfe "Yes"
	qui estadd local thresfe "Yes"
	
	rename thres thres`t'_f
	rename flagnorm flag`t'_fnorm 
	rename flag_thresnorm flag`t'_thres_fnorm 

}

* Panel A: school
estout olsmar_tpres ivmar_tpres olsmar_satt ivmar_satt olsmar_fac ivmar_fac using "$analysis/tables/causal/99_mean_performance_norm_alt_balance.tex", ///
	style(tex) /// style of exporting
	starl(* 0.10 ** 0.05 *** 0.01) /// significance stars
	cells(b(star fmt(%6.3f)) se(par fmt(%6.3f))) /// format of cells (coefficient and se)
	mlabels(none) /// no label for models
	collabels(none) /// no label for columns
	label ///
	varlabels(flagnorm "\# Times flagged\$_{t}$ (z-score)") ///
	prehead(\begin{tabular}{lcccccc} \toprule ///
	"\multicolumn{7}{l}{\textbf{Panel A: School outcomes}} \\" ///
	" & \multicolumn{6}{c}{\underline{Dependent variables (range: 0-100)}} \\" /// dependent variable title
	" & \multicolumn{2}{c}{Teacher presence\$_{t+1}$} & \multicolumn{2}{c}{Student attendance\$_{t+1}$} & \multicolumn{2}{c}{Functional facilities\$_{t+1}$} \\" ///
	" & OLS & 2SLS & OLS & 2SLS & OLS & 2SLS \\" ///
	" & (1) & (2) & (3) & (4) & (5) & (6) \\" ///
	"\cline{2-7} \addlinespace[0.5em]") ///
	///posthead(\midrule) ///
    prefoot(\midrule) ///
	drop(_cons) ///
	stats(N N_clust ymeanbef ymeanflag ysdbef ftest, fmt(%11.2gc %11.2gc a2 a2 a2 a2) ///
	labels("N. of obs." "Number markaz" "Mean Dep. Var." "Mean \# Times flagged" "SD \# Times flagged" "First stage F-stat")) /// stats to keep
	replace // replace if it exist
	
* Panel B: students
estout olsmar_math ivmar_math olsmar_eng ivmar_eng olsmar_urdu ivmar_urdu using "$analysis/tables/causal/TableB2.tex", ///
	style(tex) /// style of exporting
	starl(* 0.10 ** 0.05 *** 0.01) /// significance stars
	cells(b(star fmt(%6.3f)) se(par fmt(%6.3f))) /// format of cells (coefficient and se)
	mlabels(none) /// no label for models
	collabels(none) /// no label for columns
	label ///
	varlabels(flagnorm "\# Times flagged\$_{t}$ (z-score)") ///
	prehead("\midrule \multicolumn{7}{l}{\textbf{Panel B: Student scores}} \\" ///
	" & \multicolumn{6}{c}{\underline{Dependent variables (range: 0-100)}} \\" /// dependent variable title
	" & \multicolumn{2}{c}{Math\$_{t+1}$} & \multicolumn{2}{c}{English\$_{t+1}$} & \multicolumn{2}{c}{Urdu\$_{t+1}$} \\" ///
	" & OLS & 2SLS & OLS & 2SLS & OLS & 2SLS \\" ///
	" & (1) & (2) & (3) & (4) & (5) & (6) \\" ///
	"\cline{2-7} \addlinespace[0.5em]") ///
	///posthead(\midrule) ///
    prefoot(\midrule) ///
	postfoot(\bottomrule \end{tabular}) ///
	drop(_cons) ///
	stats(N N_clust ymeanbef ymeanflag ysdbef ftest marfe timefe disfe thresfe, fmt(%11.2gc %11.2gc a2 a2 a2 a2 a2 a2 a2) ///
	labels("N. of obs." "Number markaz" "Mean Dep. Var." "Mean \# Times flagged" "SD \# Times flagged" "First stage F-stat" ///
		   "\midrule Markaz FE" "Time FE" "District time trends" "\# Times in threshold\$_t$ FE")) /// stats to keep
	topfile("$analysis/tables/causal/99_mean_performance_norm_alt_balance.tex") /// this joins the two panels into a single table
	replace // replace if it exist	

}

*---------------------------------------------------------------------------------------------------
**# 4. regressions: non-parametric approach #

use "$analysis/processed/cc_mar_emis_year_data.dta", clear

***** Table 4
if(1){
	
*mean
local treatments tpres satt fac math eng urdu
foreach t of local treatments{
	
	
	rename flag`t'_fnorm flagnorm
	rename flag`t'_thres_fnorm flag_thresnorm
	rename thres`t'_f thres
	
	label var flagnorm "\# Times flagged\$_{t}$ (z-score)"
	
	*ols
	eststo olsmar_`t': reghdfe `t' flagnorm, /// 
		absorb(mar year district##c.year thres) vce(cluster mar) 
	qui estadd ysumm
	qui sum `t' if e(sample)
	qui estadd scalar yobs `r(N)'
	qui sum `t'_f  
	qui estadd scalar ymeanbef `r(mean)'
	qui sum flag`t'_f	
	qui estadd scalar ymeanflag `r(mean)'
	qui estadd scalar ysdbef `r(sd)'
	qui estadd local marfe "Yes"
	qui estadd local timefe "Yes"
	qui estadd local disfe "Yes"
	qui estadd local thresfe "Yes"

	*iv
	eststo ivmar_`t': ivreghdfe `t'  (flagnorm = ///
			 i.flagmonth`t'1_f i.flagmonth`t'2_f i.flagmonth`t'3_f i.flagmonth`t'4_f ///
			 i.flagmonth`t'10_f i.flagmonth`t'11_f i.flagmonth`t'12_f), ///
		ffirst absorb(mar year district##c.year thres) cluster(mar) 
		
	qui estadd ysumm
	qui sum `t' if e(sample)
	qui estadd scalar yobs `r(N)'
	qui sum `t'_f  
	qui estadd scalar ymeanbef `r(mean)'
	qui sum flag`t'_f	
	qui estadd scalar ymeanflag `r(mean)'
	qui estadd scalar ysdbef `r(sd)'
	qui estadd scalar ftest e(widstat)
	qui estadd local marfe "Yes"
	qui estadd local timefe "Yes"
	qui estadd local disfe "Yes"
	qui estadd local thresfe "Yes"
	
	rename thres thres`t'_f
	rename flagnorm flag`t'_fnorm 
	rename flag_thresnorm flag`t'_thres_fnorm 

}

* Panel A: school
estout olsmar_tpres ivmar_tpres olsmar_satt ivmar_satt olsmar_fac ivmar_fac using "$analysis/tables/causal/99_mean_performance_norm_alt.tex", ///
	style(tex) /// style of exporting
	starl(* 0.10 ** 0.05 *** 0.01) /// significance stars
	cells(b(star fmt(%6.3f)) se(par fmt(%6.3f))) /// format of cells (coefficient and se)
	mlabels(none) /// no label for models
	collabels(none) /// no label for columns
	label ///
	varlabels(flagnorm "\# Times flagged\$_{t}$ (z-score)") ///
	prehead(\begin{tabular}{lcccccc} \toprule ///
	"\multicolumn{7}{l}{\textbf{Panel A: School outcomes}} \\" ///
	" & \multicolumn{6}{c}{\underline{Dependent variables (range: 0-100)}} \\" /// dependent variable title
	" & \multicolumn{2}{c}{Teacher presence\$_{t+1}$} & \multicolumn{2}{c}{Student attendance\$_{t+1}$} & \multicolumn{2}{c}{Functional facilities\$_{t+1}$} \\" ///
	" & OLS & 2SLS & OLS & 2SLS & OLS & 2SLS \\" ///
	" & (1) & (2) & (3) & (4) & (5) & (6) \\" ///
	"\cline{2-7} \addlinespace[0.5em]") ///
	///posthead(\midrule) ///
    prefoot(\midrule) ///
	drop(_cons) ///
	stats(N N_clust ymeanbef ymeanflag ysdbef ftest, fmt(%11.2gc %11.2gc a2 a2 a2 a2) ///
	labels("N. of obs." "Number markaz" "Mean Dep. Var." "Mean \# Times flagged" "SD \# Times flagged" "First stage F-stat")) /// stats to keep
	replace // replace if it exist
	
* Panel B: students
estout olsmar_math ivmar_math olsmar_eng ivmar_eng olsmar_urdu ivmar_urdu using "$analysis/tables/causal/Table4.tex", ///
	style(tex) /// style of exporting
	starl(* 0.10 ** 0.05 *** 0.01) /// significance stars
	cells(b(star fmt(%6.3f)) se(par fmt(%6.3f))) /// format of cells (coefficient and se)
	mlabels(none) /// no label for models
	collabels(none) /// no label for columns
	label ///
	varlabels(flagnorm "\# Times flagged\$_{t}$ (z-score)") ///
	prehead("\midrule \multicolumn{7}{l}{\textbf{Panel B: Student scores}} \\" ///
	" & \multicolumn{6}{c}{\underline{Dependent variables (range: 0-100)}} \\" /// dependent variable title
	" & \multicolumn{2}{c}{Math\$_{t+1}$} & \multicolumn{2}{c}{English\$_{t+1}$} & \multicolumn{2}{c}{Urdu\$_{t+1}$} \\" ///
	" & OLS & 2SLS & OLS & 2SLS & OLS & 2SLS \\" ///
	" & (1) & (2) & (3) & (4) & (5) & (6) \\" ///
	"\cline{2-7} \addlinespace[0.5em]") ///
	///posthead(\midrule) ///
    prefoot(\midrule) ///
	postfoot(\bottomrule \end{tabular}) ///
	drop(_cons) ///
	stats(N N_clust ymeanbef ymeanflag ysdbef ftest marfe timefe disfe thresfe, fmt(%11.2gc %11.2gc a2 a2 a2 a2 a2 a2 a2) ///
	labels("N. of obs." "Number markaz" "Mean Dep. Var." "Mean \# Times flagged" "SD \# Times flagged" "First stage F-stat" ///
		   "\midrule Markaz FE" "Time FE" "District time trends" "\# Times in threshold\$_t$ FE")) /// stats to keep
	topfile("$analysis/tables/causal/99_mean_performance_norm_alt.tex") /// this joins the two panels into a single table
	replace // replace if it exist	

}

***** Figure B3
* first stage coefficients

local treatments tpres satt fac math eng urdu
foreach t of local treatments{
	
if("`t'" == "math" | "`t'" == "urdu"){
	eststo model: reghdfe flag`t'_fnorm i.flagmonth`t'9_f i.flagmonth`t'10_f i.flagmonth`t'11_f i.flagmonth`t'12_f ///
	                                    i.flagmonth`t'1_f  i.flagmonth`t'2_f  i.flagmonth`t'3_f ///
									    i.flagmonth`t'4_f , ///
				          absorb(mar year district##c.year thres`t'_f) cluster(mar) 
		
	coefplot model, ///
	keep(1.flagmonth`t'9_f 1.flagmonth`t'10_f 1.flagmonth`t'11_f 1.flagmonth`t'12_f 1.flagmonth`t'1_f ///
	     1.flagmonth`t'2_f  1.flagmonth`t'3_f 1.flagmonth`t'4_f) ///
	vertical ///
	graphregion(col(white)) mcol(navy) ciopts(lcol(navy)) ///
	xlabel(, nogrid) ///
	ylabel(-1.6(1.6)8, nogrid) yscale(r(-1.4 8)) yline(0, lcol(black) lpattern(dash)) ///
	coeflabel(1.flagmonth`t'9_f = "Sep" 1.flagmonth`t'10_f = "Oct" 1.flagmonth`t'11_f = "Nov" 1.flagmonth`t'12_f = "Dec" ///
	          1.flagmonth`t'1_f = "Jan" 1.flagmonth`t'2_f = "Feb" 1.flagmonth`t'3_f = "Mar" ///
			  1.flagmonth`t'4_f = "Apr", labsize(vlarge)) ///
	ytitle("Coefficient (SD)", size(vlarge)) ///
	xtitle("Month flagged in threshold during school year", size(vlarge))
	
	* save graph
	graph export "$analysis/figures/causal/FigureB3_`t'.pdf", replace
}
else{
	
	eststo model: reghdfe flag`t'_fnorm i.flagmonth`t'9_f i.flagmonth`t'10_f i.flagmonth`t'11_f i.flagmonth`t'12_f ///
	                                    i.flagmonth`t'1_f  i.flagmonth`t'2_f  i.flagmonth`t'3_f ///
									    i.flagmonth`t'4_f , ///
				          absorb(mar year district##c.year thres`t'_f) cluster(mar)
		
	coefplot model, ///
	keep(1.flagmonth`t'9_f 1.flagmonth`t'10_f 1.flagmonth`t'11_f 1.flagmonth`t'12_f 1.flagmonth`t'1_f ///
	     1.flagmonth`t'2_f  1.flagmonth`t'3_f 1.flagmonth`t'4_f) ///
	vertical ///
	graphregion(col(white)) mcol(navy) ciopts(lcol(navy)) ///
	xlabel(, nogrid) ///
	ylabel(-0.2(0.2)1.4, nogrid) yscale(r(-0.2 1.4)) yline(0, lcol(black) lpattern(dash)) ///
	coeflabel(1.flagmonth`t'9_f = "Sep" 1.flagmonth`t'10_f = "Oct" 1.flagmonth`t'11_f = "Nov" 1.flagmonth`t'12_f = "Dec" ///
	          1.flagmonth`t'1_f = "Jan" 1.flagmonth`t'2_f = "Feb" 1.flagmonth`t'3_f = "Mar" ///
			  1.flagmonth`t'4_f = "Apr", labsize(vlarge)) ///
	ytitle("Coefficient (SD)", size(vlarge)) ///
	xtitle("Month flagged in threshold during school year", size(vlarge))
	
	* save graph
	graph export "$analysis/figures/causal/FigureB3_`t'.pdf", replace
	
}

}

***** Table B5
* other performance metrics

if(1){

* outcomes and scores maximum
local treatments tpres satt fac math eng urdu
foreach t of local treatments{
	
	rename flag`t'_fnorm flagnorm
	rename flag`t'_thres_fnorm flag_thresnorm
	rename thres`t'_f thres
	
	label var flagnorm "\# Times flagged\$_{t}$ (z-score)"
		
	*ols
	eststo olsmax_mar_`t': reghdfe max_`t' flagnorm , /// 
		absorb(mar year district##c.year thres) vce(cluster mar) 
		
	qui estadd ysumm
	qui sum max_`t' if e(sample)
	qui estadd scalar yobs `r(N)'
	qui sum max_`t'_f
	qui estadd scalar ymeanbef `r(mean)'
	qui sum flag`t'_f	
	qui estadd scalar ymeanflag `r(mean)'
	qui estadd scalar ysdbef `r(sd)'
	qui estadd local marfe "Yes"
	qui estadd local timefe "Yes"
	qui estadd local disfe "Yes"
	qui estadd local thresfe "Yes"

	*iv
	eststo ivmax_mar_`t': ivreghdfe max_`t' (flagnorm = ///
			 i.flagmonth`t'1_f i.flagmonth`t'2_f i.flagmonth`t'3_f i.flagmonth`t'4_f ///
			 i.flagmonth`t'10_f i.flagmonth`t'11_f i.flagmonth`t'12_f) , ///
		ffirst absorb(mar year district##c.year thres) cluster(mar) 
		
	qui estadd ysumm
	qui sum max_`t' if e(sample)
	qui estadd scalar yobs `r(N)'
	qui sum max_`t'_f  
	qui estadd scalar ymeanbef `r(mean)'
	qui sum flag`t'_f	
	qui estadd scalar ymeanflag `r(mean)'
	qui estadd scalar ysdbef `r(sd)'
	qui estadd scalar ftest e(widstat)
	qui estadd local marfe "Yes"
	qui estadd local timefe "Yes"
	qui estadd local disfe "Yes"
	qui estadd local thresfe "Yes"
		
	rename thres thres`t'_f
	rename flagnorm flag`t'_fnorm 
	rename flag_thresnorm flag`t'_thres_fnorm 

}

* outcomes and scores minimum	
local treatments tpres satt fac math eng urdu
foreach t of local treatments{
	
	rename flag`t'_fnorm flagnorm
	rename flag`t'_thres_fnorm flag_thresnorm
	rename thres`t'_f thres
	
	label var flagnorm "Times flagged\$_{t}$ (z-score)"
	
	*ols
	eststo olsmin_mar_`t': reghdfe min_`t' flagnorm , /// 
		absorb(mar year district##c.year thres) vce(cluster mar) 
	qui estadd ysumm
	qui sum min_`t' if e(sample)
	qui estadd scalar yobs `r(N)'
	qui sum min_`t'_f
	qui estadd scalar ymeanbef `r(mean)'
	qui sum flag`t'_f	
	qui estadd scalar ymeanflag `r(mean)'
	qui estadd scalar ysdbef `r(sd)'
	qui estadd local marfe "Yes"
	qui estadd local timefe "Yes"
	qui estadd local disfe "Yes"
	qui estadd local thresfe "Yes"


	*iv
	eststo ivmin_mar_`t': ivreghdfe min_`t' (flagnorm = ///
			 i.flagmonth`t'1_f i.flagmonth`t'2_f i.flagmonth`t'3_f i.flagmonth`t'4_f ///
			 i.flagmonth`t'10_f i.flagmonth`t'11_f i.flagmonth`t'12_f), ///
		ffirst absorb(mar year district##c.year thres) cluster(mar) 
		
	qui estadd ysumm
	qui sum min_`t' if e(sample)
	qui estadd scalar yobs `r(N)'
	qui sum min_`t'_f 
	qui estadd scalar ymeanbef `r(mean)'
	qui sum flag`t'_f	
	qui estadd scalar ymeanflag `r(mean)'
	qui estadd scalar ysdbef `r(sd)'
	qui estadd scalar ftest e(widstat)
	qui estadd local marfe "Yes"
	qui estadd local timefe "Yes"
	qui estadd local disfe "Yes"
	qui estadd local thresfe "Yes"
	
	
	rename thres thres`t'_f
	rename flagnorm flag`t'_fnorm 
	rename flag_thresnorm flag`t'_thres_fnorm 

	
}

* table

* Panel A: best performance month	
estout olsmax_mar_tpres ivmax_mar_tpres olsmax_mar_satt ivmax_mar_satt olsmax_mar_fac ivmax_mar_fac ///
	   olsmax_mar_math ivmax_mar_math olsmax_mar_eng ivmax_mar_eng olsmax_mar_urdu ivmax_mar_urdu ///
	   using "$analysis/tables/causal/99_max_performance_norm_alt.tex", ///
	style(tex) /// style of exporting
	starl(* 0.10 ** 0.05 *** 0.01) /// significance stars
	cells(b(star fmt(a2)) se(par fmt(a2))) /// format of cells (coefficient and se)
	mlabels(none) /// no label for models
	collabels(none) /// no label for columns
	label ///
	varlabels(flagnorm "\# Times flagged\$_{t}$ (z-score)") ///
	prehead(\begin{tabular}{lcccccccccccc} \toprule ///
	"\multicolumn{13}{l}{\textbf{Panel A: Best performance month}} \\" ///
	" & \multicolumn{12}{c}{\underline{Dependent variables (range: 0-100)}} \\" /// dependent variable title
	" & \multicolumn{2}{c}{Teacher} & \multicolumn{2}{c}{Student} & \multicolumn{2}{c}{Functional} & \multicolumn{2}{c}{Math\$_{t+1}$} & \multicolumn{2}{c}{English\$_{t+1}$} & \multicolumn{2}{c}{Urdu\$_{t+1}$} \\" ///
	" & \multicolumn{2}{c}{presence\$_{t+1}$} & \multicolumn{2}{c}{attendance\$_{t+1}$} & \multicolumn{2}{c}{facilities\$_{t+1}$} & \multicolumn{2}{c}{} & \multicolumn{2}{c}{} & \multicolumn{2}{c}{} \\" ///
	" & OLS & 2SLS & OLS & 2SLS & OLS & 2SLS & OLS & 2SLS & OLS & 2SLS & OLS & 2SLS \\" ///
	" & (1) & (2) & (3) & (4) & (5) & (6) & (7) & (8) & (9) & (10) & (11) & (12) \\" ///
	"\cline{2-13} \addlinespace[0.5em]") /// 
	///posthead(\midrule) ///
    prefoot(\midrule) ///
	drop(_cons) ///
	stats(N N_clust ymeanbef ymeanflag ysdbef ftest, fmt(%11.2gc %11.2gc a2 a2 a2) ///
	labels("N. of obs." "Number markaz" "Mean Dep. Var." "Mean \# Times flagged" "SD \# Times flagged" "First stage F-stat")) /// stats to keep
	replace // replace if it exist
	
* Panel B: worst performance month	
estout olsmin_mar_tpres ivmin_mar_tpres olsmin_mar_satt ivmin_mar_satt olsmin_mar_fac ivmin_mar_fac ///
       olsmin_mar_math ivmin_mar_math olsmin_mar_eng ivmin_mar_eng olsmin_mar_urdu ivmin_mar_urdu ///
	   using "$analysis/tables/causal/TableB5.tex", ///
	style(tex) /// style of exporting
	starl(* 0.10 ** 0.05 *** 0.01) /// significance stars
	cells(b(star fmt(%6.3f)) se(par fmt(%6.3f))) /// format of cells (coefficient and se)
	mlabels(none) /// no label for models
	collabels(none) /// no label for columns
	label ///
	varlabels(flagnorm "\# Times flagged\$_{t}$ (z-score)") ///
	prehead("\midrule \multicolumn{7}{l}{\textbf{Panel B: Worst performance month}} \\" ///
	" & \multicolumn{12}{c}{\underline{Dependent variables (range: 0-100)}} \\" /// dependent variable title
	" & \multicolumn{2}{c}{Teacher} & \multicolumn{2}{c}{Student} & \multicolumn{2}{c}{Functional} & \multicolumn{2}{c}{Math\$_{t+1}$} & \multicolumn{2}{c}{English\$_{t+1}$} & \multicolumn{2}{c}{Urdu\$_{t+1}$} \\" ///
	" & \multicolumn{2}{c}{presence\$_{t+1}$} & \multicolumn{2}{c}{attendance\$_{t+1}$} & \multicolumn{2}{c}{facilities\$_{t+1}$} & \multicolumn{2}{c}{} & \multicolumn{2}{c}{} & \multicolumn{2}{c}{} \\" ///
	" & OLS & 2SLS & OLS & 2SLS & OLS & 2SLS & OLS & 2SLS & OLS & 2SLS & OLS & 2SLS \\" ///
	" & (1) & (2) & (3) & (4) & (5) & (6) & (7) & (8) & (9) & (10) & (11) & (12) \\" ///
	"\cline{2-13} \addlinespace[0.5em]") /// 
	///posthead(\midrule) ///
    prefoot(\midrule) ///
	postfoot(\bottomrule \end{tabular}) ///
	drop(_cons) ///
	stats(N N_clust ymeanbef ymeanflag ysdbef ftest marfe timefe disfe thresfe, fmt(%11.2gc %11.2gc a2 a2 a2 a2 a2 a2 a2) ///
	labels("N. of obs." "Number markaz" "Mean Dep. Var." "Mean \# Times flagged" "SD \# Times flagged" "First stage F-stat" ///
		   "\midrule Markaz FE" "Time FE" "District time trends" "\# Times in threshold\$_t$ FE")) /// stats to keep
	topfile("$analysis/tables/causal/99_max_performance_norm_alt.tex") /// this joins the two panels into a single table
	replace // replace if it exist


}

*---------------------------------------------------------------------------------------------------
* 5. regressions: RDA controls

use "$analysis/processed/cc_mar_emis_year_data_rda.dta", clear

***** Table B3
if(1){
	
*mean
local treatments tpres satt fac math eng urdu
foreach t of local treatments{

	*instrument: share of months flagged aorund the bandwidth
	*gen sz = flag`t'_thres_f/9 // share of months flagged while close to the cutoff from all months
	*we can do the above but will keep the same structure, only adding the additional controls
	
	gen sz = flag`t'_thres_f/9 // instrument: share of months flagged in the threshold
	gen s = thres`t'_f/9 // share of months close to the cutoff from all months
	
	local vars month`t'1_f month`t'2_f month`t'3_f month`t'4_f month`t'5_f month`t'9_f month`t'10_f month`t'11_f month`t'12_f
	foreach j of local vars{
		
		gen x`j' = `j' * (1/9) // i assume each month has the same share
		replace x`j' = 0 if x`j' == .
	}
	
	egen sr = rowtotal(xmonth`t'1_f xmonth`t'2_f xmonth`t'3_f xmonth`t'4_f xmonth`t'5_f xmonth`t'9_f xmonth`t'10_f xmonth`t'11_f xmonth`t'12_f) if thres`t'_f == 1
	replace sr = 0 if sr == .
	
	// running variable weighted by the share of months close to the cutoff
	egen sr_pos = rowtotal(xmonth`t'1_f xmonth`t'2_f xmonth`t'3_f xmonth`t'4_f xmonth`t'5_f xmonth`t'9_f xmonth`t'10_f xmonth`t'11_f xmonth`t'12_f) if flag`t'_thres_f == 1
	replace sr_pos = 0 if sr_pos == .
	
	rename flag`t'_fnorm flagnorm
	rename flag`t'_thres_fnorm flag_thresnorm
	rename thres`t'_f thres
	
	label var flagnorm "\# Times flagged\$_{t}$ (z-score)"
	
	*dependent variable
	eststo ivmar_`t': ivreghdfe `t' (flagnorm = sz) s sr sr_pos, ///
			ffirst absorb(mar year district##c.year) cluster(mar) 
		
	qui estadd ysumm
	qui sum `t' if e(sample)
	qui estadd scalar yobs `r(N)'
	qui sum `t'_f  
	qui estadd scalar ymeanbef `r(mean)'
	qui estadd scalar ftest e(widstat)
	qui estadd local marfe "Yes"
	qui estadd local timefe "Yes"
	qui estadd local disfe "Yes"
	qui estadd local thresfe "Yes"
	
	
	rename thres thres`t'_f
	rename flagnorm flag`t'_fnorm 
	rename flag_thresnorm flag`t'_thres_fnorm 

	
drop sz s sr sr_pos 
}

* Panel A: school
estout ivmar_tpres ivmar_satt ivmar_fac using "$analysis/tables/causal/99_mean_performance_rda_1.tex", ///
	style(tex) /// style of exporting
	starl(* 0.10 ** 0.05 *** 0.01) /// significance stars
	cells(b(star fmt(%6.3f)) se(par fmt(%6.3f))) /// format of cells (coefficient and se)
	mlabels(none) /// no label for models
	collabels(none) /// no label for columns
	label ///
	varlabels(flagnorm "\# Times flagged\$_{t}$ (z-score)") ///
	prehead(\begin{tabular}{lccc} \toprule ///
	" & \multicolumn{3}{c}{\underline{Dependent variables (range: 0-100)}} \\" /// dependent variable title
	" & \multicolumn{1}{c}{Teacher} & \multicolumn{1}{c}{Student} & \multicolumn{1}{c}{Functional} \\" ///
	" & \multicolumn{1}{c}{presence\$_{t+1}$} & \multicolumn{1}{c}{attendance\$_{t+1}$} & \multicolumn{1}{c}{facilities\$_{t+1}$} \\" ///
	" & 2SLS & 2SLS & 2SLS \\" ///
	" & (1) & (2) & (3) \\" ///
	"\cline{2-4} \addlinespace[0.5em]") ///
	///posthead(\midrule) ///
    prefoot(\midrule) ///
	drop(s sr sr_pos) ///
	stats(N N_clust ymeanbef ftest marfe timefe disfe thresfe, fmt(%11.2gc %11.2gc a2 a2 a2 a2 a2) ///
	labels("N. of obs." "Number markaz" "Mean Dep. Var." "First stage F-stat" ///
		   "\midrule Markaz FE" "Time FE" "District time trends" "RDA Controls")) /// stats to keep
	replace // replace if it exist
	
* Panel B: students
estout ivmar_math ivmar_eng ivmar_urdu using "$analysis/tables/causal/TableB3.tex", ///
	style(tex) /// style of exporting
	starl(* 0.10 ** 0.05 *** 0.01) /// significance stars
	cells(b(star fmt(%6.3f)) se(par fmt(%6.3f))) /// format of cells (coefficient and se)
	mlabels(none) /// no label for models
	collabels(none) /// no label for columns
	label ///
	varlabels(flagnorm "\# Times flagged\$_{t}$ (z-score)") ///
	prehead("\midrule \multicolumn{3}{l}{\textbf{Panel B: Student scores}} \\" ///
	" & \multicolumn{3}{c}{\underline{Dependent variables (range: 0-100)}} \\" /// dependent variable title
	" & \multicolumn{1}{c}{Math\$_{t+1}$} & \multicolumn{1}{c}{English\$_{t+1}$} & \multicolumn{1}{c}{Urdu\$_{t+1}$} \\" ///
	" & 2SLS & 2SLS & 2SLS \\" ///
	" & (1) & (2) & (3) \\" ///
	"\cline{2-4} \addlinespace[0.5em]") ///
	///posthead(\midrule) ///
    prefoot(\midrule) ///
	postfoot(\bottomrule \end{tabular}) ///
	drop(s sr sr_pos) ///
	stats(N N_clust ymeanbef ftest marfe timefe disfe thresfe, fmt(%11.2gc %11.2gc a2 a2 a2 a2 a2) ///
	labels("N. of obs." "Number markaz" "Mean Dep. Var." "First stage F-stat" ///
		   "\midrule Markaz FE" "Time FE" "District time trends" "RDA Controls")) /// stats to keep
	topfile("$analysis/tables/causal/99_mean_performance_rda_1.tex") /// this joins the two panels into a single table
	replace // replace if it exist	

}

*---------------------------------------------------------------------------------------------------
* 6. regressions: alternative definitions of the instrument

use "$analysis/processed/cc_mar_emis_year_data.dta", clear

***** Table B4
if(1){
	
local treatments tpres satt fac math eng urdu
foreach t of local treatments{
	
	rename flag`t'_fnorm flagnorm
	rename flag`t'_thres_fnorm flag_thresnorm
	rename thres`t'_f thres
	rename flag`t'_thresever flag_thresever
		
	*iv - linear 
	eststo ivlin_`t': ivreghdfe `t'  (flagnorm = ///
			 flag_thresnorm) , ///
		ffirst absorb(mar year district##c.year thres) cluster(mar) 
		
	qui estadd ysumm
	qui sum `t' if e(sample)
	qui estadd scalar yobs `r(N)'
	qui sum `t'_f  
	qui estadd scalar ymeanbef `r(mean)'
	qui sum flag`t'_f	
	qui estadd scalar ymeanflag `r(mean)'
	qui estadd scalar ysdbef `r(sd)'
	qui estadd scalar ftest e(widstat)
	qui estadd local marfe "Yes"
	qui estadd local timefe "Yes"
	qui estadd local disfe "Yes"
	qui estadd local thresfe "Yes"

	*iv - flagged ever 
	eststo ivever_`t': ivreghdfe `t'  (flagnorm = ///
			 flag_thresever) , ///
		ffirst absorb(mar year district##c.year thres) cluster(mar) 
		
	qui estadd ysumm
	qui sum `t' if e(sample)
	qui estadd scalar yobs `r(N)'
	qui sum `t'_f  
	qui estadd scalar ymeanbef `r(mean)'
	qui sum flag`t'_f	
	qui estadd scalar ymeanflag `r(mean)'
	qui estadd scalar ysdbef `r(sd)'
	qui estadd scalar ftest e(widstat)
	qui estadd local marfe "Yes"
	qui estadd local timefe "Yes"
	qui estadd local disfe "Yes"
	qui estadd local thresfe "Yes"

	*iv - q2
	eststo ivq2_`t': ivreghdfe `t'  (flagnorm = ///
			 i.flag`t'_thres_q2) , ///
		ffirst absorb(mar year district##c.year thres) cluster(mar) 
		
	qui estadd ysumm
	qui sum `t' if e(sample)
	qui estadd scalar yobs `r(N)'
	qui sum `t'_f  
	qui estadd scalar ymeanbef `r(mean)'
	qui sum flag`t'_f	
	qui estadd scalar ymeanflag `r(mean)'
	qui estadd scalar ysdbef `r(sd)'
	qui estadd scalar ftest e(widstat)

	rename thres thres`t'_f
	rename flagnorm flag`t'_fnorm 
	rename flag_thresnorm flag`t'_thres_fnorm 
	rename flag_thresever flag`t'_thresever
	qui estadd local marfe "Yes"
	qui estadd local timefe "Yes"
	qui estadd local disfe "Yes"
	qui estadd local thresfe "Yes"


}

* Panel A: school 
estout ivlin_tpres ivever_tpres ivq2_tpres ivlin_satt ivever_satt ivq2_satt ivlin_fac ivever_fac ivq2_fac ///
	using "$analysis/tables/causal/99_mean_alternative_iv_outcomes.tex", ///
	style(tex) /// style of exporting
	starl(* 0.10 ** 0.05 *** 0.01) /// significance stars
	cells(b(star fmt(%6.3f)) se(par fmt(%6.3f))) /// format of cells (coefficient and se)
	mlabels(none) /// no label for models
	collabels(none) /// no label for columns
	label ///
	varlabels(flagnorm "\# Times flagged\$_{t}$ (z-score)") ///
	prehead(\begin{tabular}{lccccccccc} \toprule ///
	"\multicolumn{10}{l}{\textbf{Panel A: School outcomes}} \\" ///
	" & \multicolumn{9}{c}{\underline{Dependent variables (range: 0-100)}} \\" /// dependent variable title	
	" & \multicolumn{3}{c}{Teacher presence\$_{t+1}$} & \multicolumn{3}{c}{Student attendance\$_{t+1}$} & \multicolumn{3}{c}{Functional facilities\$_{t+1}$} \\" ///
	" & Linear & Ever flag & Median & Linear & Ever flag & Median & Linear & Ever flag & Median \\" ///
	" & (1) & (2) & (3) & (4) & (5) & (6) & (7) & (8) & (9) \\" ///
	"\cline{2-10} \addlinespace[0.5em]") ///
	///posthead(\midrule) ///
    prefoot(\midrule) ///
	stats(N N_clust ymeanbef ymeanflag ysdbef ftest, fmt(%11.2gc %11.2gc a2 a2 a2 a2) ///
	labels("N. of obs." "Number markaz" "Mean Dep. Var." "Mean \# Times flagged" "SD \# Times flagged" "First stage F-stat")) /// stats to keep
	replace // replace if it exist

* Panel B: scores
estout ivlin_math ivever_math ivq2_math ivlin_eng ivever_eng ivq2_eng ivlin_urdu ivever_urdu ivq2_urdu ///
	using "$analysis/tables/causal/TableB4.tex", ///
	style(tex) /// style of exporting
	starl(* 0.10 ** 0.05 *** 0.01) /// significance stars
	cells(b(star fmt(%6.3f)) se(par fmt(%6.3f))) /// format of cells (coefficient and se)
	mlabels(none) /// no label for models
	collabels(none) /// no label for columns
	label ///
	varlabels(flagnorm "\# Times flagged\$_{t}$ (z-score)") ///
	prehead("\midrule \multicolumn{7}{l}{\textbf{Panel B: Student scores}} \\" ///
	" & \multicolumn{9}{c}{\underline{Dependent variables (range: 0-100)}} \\" /// dependent variable title	
	" & \multicolumn{3}{c}{Math\$_{t+1}$} & \multicolumn{3}{c}{English\$_{t+1}$} & \multicolumn{3}{c}{Urdu\$_{t+1}$} \\" /// 
	" & Linear & Ever flag & Median & Linear & Ever flag & Median & Linear & Ever flag & Median \\" ///
	" & (1) & (2) & (3) & (4) & (5) & (6) & (7) & (8) & (9) \\" ///
	"\cline{2-10} \addlinespace[0.5em]") ///
	///posthead(\midrule) ///
    prefoot(\midrule) ///
	postfoot(\bottomrule \end{tabular}) ///
	stats(N N_clust ymeanbef ymeanflag ysdbef ftest marfe timefe disfe thresfe, fmt(%11.2gc %11.2gc a2 a2 a2 a2 a2 a2 a2) ///
	labels("N. of obs." "Number markaz" "Mean Dep. Var." "Mean \# Times flagged" "SD \# Times flagged" "First stage F-stat" ///
		   "\midrule Markaz FE" "Time FE" "District time trends" "\# Times in threshold\$_t$ FE")) /// stats to keep
	topfile("$analysis/tables/causal/99_mean_alternative_iv_outcomes.tex") /// this joins the two panels into a single table
	replace // replace if it exist
}
 
*---------------------------------------------------------------------------------------------------
* 7. regressions: relaxing linearity assumption

***** Figure B4
if(1){

*mean	
local vars tpres satt fac 
foreach t of local vars{
	
	eststo iv_mar_`t': ivreghdfe `t' ///
		( ///
			 i.flag`t'_q3 = /// endogenous
			 i.flag`t'_thres_q3 /// instruments
		) , ffirst absorb(mar year district##c.year thres`t'_f) cluster(mar) 
	
	
	coefplot (iv_mar_`t', lcol(navy) mcol(navy) ciopts(lcol(navy) recast(rcap))), lw(vvthin) /// connected graph
		baselevels /// include baselevel
		omitted /// include ommited period (-1)
		level(95) /// 95% confidence intervals
		ciopts(recast(rcap)) /// type of confidence intervals
		keep( ///
			1.flag`t'_q3 2.flag`t'_q3 3.flag`t'_q3 ///
		) ///
		vertical /// vertical oriented graph 
		mcol(%30) /// transparency of points
		yline(0, lcol("black") lpattern(dash)) /// y line for 0
		yscale(r(-2 4)) /// y scale
		ylabel(-2(1)4, nogrid) /// y label
		xlabel(, nogrid) ///
		graphregion(color(white)) /// white background
		xtitle("# Times flagged", size(vlarge)) /// xtitle
		ytitle("Coefficient", size(vlarge)) /// ytitle
		title("", size(vsmall) col(black)) /// no title
		coeflabel( /// label of coefficients
			1.flag`t'_q3 = "1" 2.flag`t'_q3 = "2" 3.flag`t'_q3 = "3+", labsize(vlarge) ///
	)
				
	* save graph
	graph export "$analysis/figures/causal/FigureB4_`t'.pdf", replace		

}

*mean	
local vars math eng urdu 
foreach t of local vars{
	
	eststo iv_mar_`t': ivreghdfe `t' ///
		( ///
			 i.flag`t'_q2 = /// endogenous
			 i.flag`t'_thres_q2 /// instruments
		) , ffirst absorb(mar year district##c.year thres`t'_f) cluster(mar) 
	
	coefplot (iv_mar_`t', lcol(navy) mcol(navy) ciopts(lcol(navy) recast(rcap))), lw(vvthin) /// connected graph
		baselevels /// include baselevel
		omitted /// include ommited period (-1)
		level(95) /// 95% confidence intervals
		ciopts(recast(rcap)) /// type of confidence intervals
		keep( ///
			1.flag`t'_q2 2.flag`t'_q2 ///
		) ///
		vertical /// vertical oriented graph 
		mcol(%30) /// transparency of points
		yline(0, lcol("black") lpattern(dash)) /// y line for 0
		yscale(r(-4 6)) /// y scale
		ylabel(-4(2)6, nogrid) /// y label
		xlabel(, nogrid) ///
		graphregion(color(white)) /// white background
		xtitle("# Times flagged", size(vlarge)) /// xtitle
		ytitle("Coefficient", size(vlarge)) /// ytitle
		title("", size(vsmall) col(black)) /// no title
		coeflabel( /// label of coefficients
		1.flag`t'_q2 = "1" 2.flag`t'_q2 = "2+", labsize(vlarge) ///
	) 
				
	* save graph
	graph export "$analysis/figures/causal/FigureB4_`t'.pdf", replace		

}

}

*---------------------------------------------------------------------------------------------------
* 8. regressions: school performance

use "$analysis/processed/cc_mar_emis_year_data.dta", clear

***** Table B6
if(1){
	
local vars tpres satt fac math eng urdu
foreach t of local vars{

if("`t'" == "fac"){ // mean of fac no variation above, thus use tpres
bys mar emis (year): egen temp = mean(tpres)
sum temp, d
gen worst = (tpres < r(p50))
}
else{
bys mar emis (year): egen temp = mean(`t')
sum temp, d
gen worst = (`t' < r(p50))	
}

* worst performing
if(1){
* regression on bigger
rename flag`t'_fnorm flagnorm
rename flag`t'_thres_fnorm flag_thresnorm
rename thres`t'_f thres
	
label var flagnorm "\# Times flagged\$_{t}$ (z-score)"
	
*ols
eststo olsworst_`t': reghdfe `t' flagnorm if worst == 1 , /// 
	absorb(mar year district##c.year thres) vce(cluster mar) 
	qui estadd ysumm
	qui sum `t' if e(sample)
	qui estadd scalar yobs `r(N)'
	qui sum `t'_f  
	qui estadd scalar ymeanbef `r(mean)'
	qui sum flag`t'_f	
	qui estadd scalar ymeanflag `r(mean)'
	qui estadd scalar ysdbef `r(sd)'
	qui estadd local marfe "Yes"
	qui estadd local timefe "Yes"
	qui estadd local disfe "Yes"
	qui estadd local thresfe "Yes"


*iv
eststo ivworst_`t': ivreghdfe `t'  (flagnorm = ///
		 i.flagmonth`t'1_f i.flagmonth`t'2_f i.flagmonth`t'3_f i.flagmonth`t'4_f ///
		 i.flagmonth`t'10_f i.flagmonth`t'11_f i.flagmonth`t'12_f) if worst == 1 , ///
	ffirst absorb(mar year district##c.year thres) cluster(mar) 
		
	qui estadd ysumm
	qui sum `t' if e(sample)
	qui estadd scalar yobs `r(N)'
	qui sum `t'_f  
	qui estadd scalar ymeanbef `r(mean)'
	qui sum flag`t'_f	
	qui estadd scalar ymeanflag `r(mean)'
	qui estadd scalar ysdbef `r(sd)'
	qui estadd scalar ftest e(widstat)
	qui estadd local marfe "Yes"
	qui estadd local timefe "Yes"
	qui estadd local disfe "Yes"
	qui estadd local thresfe "Yes"

	
rename thres thres`t'_f
rename flagnorm flag`t'_fnorm 
rename flag_thresnorm flag`t'_thres_fnorm 

}

* best performing
if(1){

rename flag`t'_fnorm flagnorm
rename flag`t'_thres_fnorm flag_thresnorm
rename thres`t'_f thres
	
label var flagnorm "Times flagged (Z-Score)"
	
*ols
eststo ols_`t': reghdfe `t' flagnorm if worst == 0 , /// 
	absorb(mar year district##c.year thres) vce(cluster mar) 
	qui estadd ysumm
	qui sum `t' if e(sample)
	qui estadd scalar yobs `r(N)'
	qui sum `t'_f  
	qui estadd scalar ymeanbef `r(mean)'
	qui sum flag`t'_f	
	qui estadd scalar ymeanflag `r(mean)'
	qui estadd scalar ysdbef `r(sd)'
	qui estadd local marfe "Yes"
	qui estadd local timefe "Yes"
	qui estadd local disfe "Yes"
	qui estadd local thresfe "Yes"

*iv
eststo iv_`t': ivreghdfe `t'  (flagnorm = ///
		 i.flagmonth`t'1_f i.flagmonth`t'2_f i.flagmonth`t'3_f i.flagmonth`t'4_f ///
		 i.flagmonth`t'10_f i.flagmonth`t'11_f i.flagmonth`t'12_f) if worst == 0 , ///
	ffirst absorb(mar year district##c.year thres) cluster(mar) 
		
	qui estadd ysumm
	qui sum `t' if e(sample)
	qui estadd scalar yobs `r(N)'
	qui sum `t'_f  
	qui estadd scalar ymeanbef `r(mean)'
	qui sum flag`t'_f	
	qui estadd scalar ymeanflag `r(mean)'
	qui estadd scalar ysdbef `r(sd)'
	qui estadd scalar ftest e(widstat)
	qui estadd local marfe "Yes"
	qui estadd local timefe "Yes"
	qui estadd local disfe "Yes"
	qui estadd local thresfe "Yes"

	
rename thres thres`t'_f
rename flagnorm flag`t'_fnorm 
rename flag_thresnorm flag`t'_thres_fnorm 

}

drop temp worst

}

* Panel A: best performing

estout ols_tpres iv_tpres ols_satt iv_satt ols_fac iv_fac ols_math iv_math ols_eng iv_eng ols_urdu iv_urdu ///
	using "$analysis/tables/causal/99_mean_performance_school_best.tex", ///
	style(tex) /// style of exporting
	starl(* 0.10 ** 0.05 *** 0.01) /// significance stars
	cells(b(star fmt(%6.3f)) se(par fmt(%6.3f))) /// format of cells (coefficient and se)
	mlabels(none) /// no label for models
	collabels(none) /// no label for columns
	label ///
	varlabels(flagnorm "\# Times flagged\$_{t}$ (z-score)") ///	
	prehead(\begin{tabular}{lcccccccccccc} \toprule ///
	"\multicolumn{13}{l}{\textbf{Panel A: Best performance schools}} \\" ///
	" & \multicolumn{12}{c}{\underline{Dependent variables (range: 0-100)}} \\" /// dependent variable title
	" & \multicolumn{2}{c}{Teacher} & \multicolumn{2}{c}{Student} & \multicolumn{2}{c}{Functional} & \multicolumn{2}{c}{Math\$_{t+1}$} & \multicolumn{2}{c}{English\$_{t+1}$} & \multicolumn{2}{c}{Urdu\$_{t+1}$} \\" ///
	" & \multicolumn{2}{c}{presence\$_{t+1}$} & \multicolumn{2}{c}{attendance\$_{t+1}$} & \multicolumn{2}{c}{facilities\$_{t+1}$} & \multicolumn{2}{c}{} & \multicolumn{2}{c}{} & \multicolumn{2}{c}{} \\" ///
	" & OLS & 2SLS & OLS & 2SLS & OLS & 2SLS & OLS & 2SLS & OLS & 2SLS & OLS & 2SLS \\" ///
	" & (1) & (2) & (3) & (4) & (5) & (6) & (7) & (8) & (9) & (10) & (11) & (12) \\" ///
	"\cline{2-13} \addlinespace[0.5em]") ///
	///posthead(\midrule) ///
    prefoot(\midrule) ///
	drop(_cons) ///
	stats(N N_clust ymeanbef ymeanflag ysdbef ftest, fmt(%11.2gc %11.2gc a2 a2 a2) ///
	labels("N. of obs." "Number markaz" "Mean Dep. Var." "Mean \# Times flagged" "SD \# Times flagged" "First stage F-stat")) /// stats to keep
	replace // replace if it exist
	
* Panel B: worst performing
estout olsworst_tpres ivworst_tpres olsworst_satt ivworst_satt olsworst_fac ivworst_fac ///
	   olsworst_math ivworst_math olsworst_eng ivworst_eng olsworst_urdu ivworst_urdu ///
	using "$analysis/tables/causal/TableB6.tex", ///
	style(tex) /// style of exporting
	starl(* 0.10 ** 0.05 *** 0.01) /// significance stars
	cells(b(star fmt(%6.3f)) se(par fmt(%6.3f))) /// format of cells (coefficient and se)
	mlabels(none) /// no label for models
	collabels(none) /// no label for columns
	label ///
	varlabels(flagnorm "\# Times flagged\$_{t}$ (z-score)") ///	
	prehead("\midrule \multicolumn{13}{l}{\textbf{Panel B: Worst performing schools}} \\" ///
	" & \multicolumn{12}{c}{\underline{Dependent variables (range: 0-100)}} \\" /// dependent variable title
	" & \multicolumn{2}{c}{Teacher} & \multicolumn{2}{c}{Student} & \multicolumn{2}{c}{Functional} & \multicolumn{2}{c}{Math\$_{t+1}$} & \multicolumn{2}{c}{English\$_{t+1}$} & \multicolumn{2}{c}{Urdu\$_{t+1}$} \\" ///
	" & \multicolumn{2}{c}{presence\$_{t+1}$} & \multicolumn{2}{c}{attendance\$_{t+1}$} & \multicolumn{2}{c}{facilities\$_{t+1}$} & \multicolumn{2}{c}{} & \multicolumn{2}{c}{} & \multicolumn{2}{c}{} \\" ///
	" & OLS & 2SLS & OLS & 2SLS & OLS & 2SLS & OLS & 2SLS & OLS & 2SLS & OLS & 2SLS \\" ///
	" & (1) & (2) & (3) & (4) & (5) & (6) & (7) & (8) & (9) & (10) & (11) & (12) \\" ///
	"\cline{2-13} \addlinespace[0.5em]") ///
	///posthead(\midrule) ///
    prefoot(\midrule) ///
	postfoot(\bottomrule \end{tabular}) ///
	drop(_cons) ///
	stats(N N_clust ymeanbef ymeanflag ysdbef ftest marfe timefe disfe thresfe, fmt(%11.2gc %11.2gc a2 a2 a2 a2 a2 a2 a2) ///
	labels("N. of obs." "Number markaz" "Mean Dep. Var." "Mean \# Times flagged" "SD \# Times flagged" "First stage F-stat" ///
		   "\midrule Markaz FE" "Time FE" "District time trends" "\# Times in threshold\$_t$ FE")) /// stats to keep
	topfile("$analysis/tables/causal/99_mean_performance_school_best.tex") /// this joins the two panels into a single table
	replace // replace if it exist

}
 
*---------------------------------------------------------------------------------------------------
* 9. regressions: heterogeneity by district performance

use "$analysis/processed/cc_mar_emis_year_data.dta", clear

* create bad or good district

/* district meetings go until 2015, but because the ranking is relatively stable, we can assign good 
or bad performance for all the period */

bys district (mar emis year): egen ever_bottom = max(district_bottom)
bys district (mar emis year): egen ever_top = max(district_top)

gen district_perf = 1 if ever_bottom > 0 & ever_bottom != .
replace district_perf = 2 if ever_top > 0 & ever_top != .  
replace district_perf = 0 if district_perf == .

***** Table B7
local treatments tpres satt fac
foreach t of local treatments{
	
	rename flag`t'_fnorm flagnorm
	rename flag`t'_thres_fnorm flag_thresnorm
	rename thres`t'_f thres
		
	*ols
	eststo olsmar_`t': reghdfe `t' c.flagnorm##i.district_perf , /// 
		absorb(mar year district##c.year thres) vce(cluster mar) 
	qui estadd ysumm
	qui sum `t' if e(sample)
	qui estadd scalar yobs `r(N)'
	qui sum `t'_f  
	qui estadd scalar ymeanbef `r(mean)'
	qui sum flag`t'_f	
	qui estadd scalar ymeanflag `r(mean)'
	qui estadd scalar ysdbef `r(sd)'
	qui estadd local marfe "Yes"
	qui estadd local timefe "Yes"
	qui estadd local disfe "Yes"
	qui estadd local thresfe "Yes"
	gen sam = (e(sample) == 1) // lines below need to condition on original estimating sample

	rename flagnorm flag`t'_fnorm 

	*iv - for heterogeneous effects, need to predict first stage 
	reghdfe flag`t'_fnorm i.flagmonth`t'1_f i.flagmonth`t'2_f i.flagmonth`t'3_f i.flagmonth`t'4_f ///
					 i.flagmonth`t'10_f i.flagmonth`t'11_f i.flagmonth`t'12_f if sam == 1, ///
		absorb(mar year district##c.year thres) cluster(mar) 
	
	predict flagnorm
	bys mar emis year: egen temp = mean(flagnorm) 
	drop flagnorm
	rename temp flagnorm
	sum flagnorm if sam == 1
	sum `t' if sam == 1 
	
	eststo ivmar_`t': reghdfe `t' c.flagnorm##i.district_perf if sam == 1, ///
		absorb(mar year district##c.year thres) cluster(mar)
			
	qui estadd ysumm
	qui sum `t' if e(sample)
	qui estadd scalar yobs `r(N)'
	qui sum `t'_f  
	qui estadd scalar ymeanbef `r(mean)'
	qui sum flag`t'_f	
	qui estadd scalar ymeanflag `r(mean)'
	qui estadd scalar ysdbef `r(sd)'
	qui estadd scalar ftest e(widstat)
	qui estadd local marfe "Yes"
	qui estadd local timefe "Yes"
	qui estadd local disfe "Yes"
	qui estadd local thresfe "Yes"
	
	rename thres thres`t'_f
	rename flag_thresnorm flag`t'_thres_fnorm 
	
	drop flagnorm sam

}

if(1){
	
estout olsmar_tpres ivmar_tpres olsmar_satt ivmar_satt olsmar_fac ivmar_fac using "$analysis/tables/causal/TableB7.tex", ///
	style(tex) /// style of exporting
	starl(* 0.10 ** 0.05 *** 0.01) /// significance stars
	cells(b(star fmt(%6.3f)) se(par fmt(%6.3f))) /// format of cells (coefficient and se)
	mlabels(none) /// no label for models
	collabels(none) /// no label for columns
	label ///
	varlabels(flagnorm "\# Times flagged\$_{t}$ (z-score)" ///
		1.district_perf#c.flagnorm "Bottom district\$_{t}$ \$\times$ \# Times flagged\$_{t}$ (z-score)" ///
		2.district_perf#c.flagnorm "Top district\$_{t}$ \$\times$ \# Times flagged\$_{t}$ (z-score)") ///
	prehead(\begin{tabular}{lcccccc} \toprule ///
	" & \multicolumn{6}{c}{\underline{Dependent variables (range: 0-100)}} \\" /// dependent variable title
	" & \multicolumn{2}{c}{Teacher presence\$_{t+1}$} & \multicolumn{2}{c}{Student attendance\$_{t+1}$} & \multicolumn{2}{c}{Functional facilities\$_{t+1}$} \\" ///
	" & OLS & 2SLS & OLS & 2SLS & OLS & 2SLS \\" ///
	" & (1) & (2) & (3) & (4) & (5) & (6) \\" ///
	"\cline{2-7} \addlinespace[0.5em]") ///
	///posthead(\midrule) ///
    prefoot(\midrule) ///
	postfoot(\bottomrule \end{tabular}) ///
	keep(flagnorm 1.district_perf#c.flagnorm 2.district_perf#c.flagnorm) ///
	stats(N N_clust ymeanbef ymeanflag ysdbef marfe timefe disfe thresfe, fmt(%11.2gc %11.2gc a2 a2 a2 a2 a2 a2) ///
	labels("N. of obs." "Number markaz" "Mean Dep. Var." "Mean \# Times flagged" "SD \# Times flagged" ///
		   "\midrule Markaz FE" "Time FE" "District time trends" "\# Times in threshold\$_t$ FE")) /// stats to keep
	replace // replace if it exist
}

*---------------------------------------------------------------------------------------------------
* 10. regressions: heterogeneity by political alignment

use "$analysis/processed/cc_mar_emis_year_data.dta", clear

* constant alignment

/* because maraakiz change the composition of schools, some times they might be aligned or not. While
this happens only in a very small fraction of maraakiz, we will assign as aligned if ever aligned */

* set seed for replication
bys mar (emis year): egen numalign = nvals(align)
*gen align_old = align
bys mar (emis year): egen ever = max(align)
replace align = ever if numalign > 1
drop numalign ever

local treatments tpres satt fac 
foreach t of local treatments{
	
	rename flag`t'_fnorm flagnorm
	rename flag`t'_thres_fnorm flag_thresnorm
	rename thres`t'_f thres
		
	*ols
	eststo olsmar_`t': reghdfe `t' c.flagnorm##ib(0).align , /// 
		absorb(mar year district##c.year thres) vce(cluster mar) 
	qui estadd ysumm
	qui sum `t' if e(sample)
	qui estadd scalar yobs `r(N)'
	qui sum `t'_f  
	qui estadd scalar ymeanbef `r(mean)'
	qui sum flag`t'_f	
	qui estadd scalar ymeanflag `r(mean)'
	qui estadd scalar ysdbef `r(sd)'
	qui estadd local marfe "Yes"
	qui estadd local timefe "Yes"
	qui estadd local disfe "Yes"
	qui estadd local thresfe "Yes"
	gen sam = (e(sample) == 1) // lines below need to condition on original estimating sample
	rename flagnorm flag`t'_fnorm 

	*iv - for heterogeneous effects, need to predict first stage 

	reghdfe flag`t'_fnorm i.flagmonth`t'1_f i.flagmonth`t'2_f i.flagmonth`t'3_f i.flagmonth`t'4_f ///
					 i.flagmonth`t'10_f i.flagmonth`t'11_f i.flagmonth`t'12_f if sam == 1, ///
		absorb(mar year district##c.year thres) cluster(mar) 
		
	predict flagnorm
	bys mar emis year align: egen temp = mean(flagnorm) 
	drop flagnorm
	rename temp flagnorm
	sum flagnorm if sam == 1
	sum `t' if sam == 1 
	
	eststo ivmar_`t': reghdfe `t' c.flagnorm##ib(0).align, ///
		absorb(mar year district##c.year thres) cluster(mar)
			
	qui estadd ysumm
	qui sum `t' if e(sample)
	qui estadd scalar yobs `r(N)'
	qui sum `t'_f  
	qui estadd scalar ymeanbef `r(mean)'
	qui sum flag`t'_f	
	qui estadd scalar ymeanflag `r(mean)'
	qui estadd scalar ysdbef `r(sd)'
	qui estadd scalar ftest e(widstat)
	qui estadd local marfe "Yes"
	qui estadd local timefe "Yes"
	qui estadd local disfe "Yes"
	qui estadd local thresfe "Yes"
	
	rename thres thres`t'_f
	rename flag_thresnorm flag`t'_thres_fnorm 
	
	drop flagnorm sam

}

***** Table B8
if(1){
	
*Panel A: school
estout olsmar_tpres ivmar_tpres olsmar_satt ivmar_satt olsmar_fac ivmar_fac using "$analysis/tables/causal/TableB8.tex", ///
	style(tex) /// style of exporting
	starl(* 0.10 ** 0.05 *** 0.01) /// significance stars
	cells(b(star fmt(%6.3f)) se(par fmt(%6.3f))) /// format of cells (coefficient and se)
	mlabels(none) /// no label for models
	collabels(none) /// no label for columns
	label ///
	varlabels(flagnorm "\# Times flagged\$_{t}$ (z-score)" ///
		1.align#c.flagnorm "Not fully aligned \$\times$ \# Times flagged\$_{t}$ (z-score)" ///
		2.align#c.flagnorm "Fully aligned \$\times$ \# Times flagged\$_{t}$ (z-score)") ///
	prehead(\begin{tabular}{lcccccc} \toprule ///
	" & \multicolumn{6}{c}{\underline{Dependent variables (range: 0-100)}} \\" /// dependent variable title
	" & \multicolumn{2}{c}{Teacher presence\$_{t+1}$} & \multicolumn{2}{c}{Student attendance\$_{t+1}$} & \multicolumn{2}{c}{Functional facilities\$_{t+1}$} \\" ///
	" & OLS & 2SLS & OLS & 2SLS & OLS & 2SLS \\" ///
	" & (1) & (2) & (3) & (4) & (5) & (6) \\" ///
	"\cline{2-7} \addlinespace[0.5em]") ///
	///posthead(\midrule) ///
    prefoot(\midrule) ///
	postfoot(\bottomrule \end{tabular}) ///
	keep(flagnorm 1.align#c.flagnorm 2.align#c.flagnorm) ///
	stats(N N_clust ymeanbef ymeanflag ysdbef marfe timefe disfe thresfe, fmt(%11.2gc %11.2gc a2 a2 a2 a2 a2 a2) ///
	labels("N. of obs." "Number markaz" "Mean Dep. Var." "Mean \# Times flagged" "SD \# Times flagged" ///
		   "\midrule Markaz FE" "Time FE" "District time trends" "\# Times in threshold\$_t$ FE")) /// stats to keep
	replace // replace if it exist

}

*---------------------------------------------------------------------------------------------------
* 11. regressions: effect on budget

use "$analysis/processed/cc_mar_emis_year_data.dta", clear

*adjust financial variables
replace nongovfunds = nongovfunds*-1 if nongovfunds < 0
egen totalfunds = rowtotal(govfunds nongovfunds), m
local fin exp govfunds nongovfunds totalfunds
foreach f of local fin{
	
	gen l`f' = log(`f' + 1)
	replace l`f' = 0 if l`f' == .
}

local treatments tpres satt fac 
foreach t of local treatments{
local fin totalfunds exp govfunds nongovfunds
foreach f of local fin{
	
	rename flag`t'_fnorm flagnorm
	rename flag`t'_thres_fnorm flag_thresnorm
	rename thres`t'_f thres
		
	*ols
	eststo ols`t'_`f': reghdfe l`f' flagnorm if `t' != . , /// to held sample constant
		absorb(mar year district##c.year thres) vce(cluster mar) 
	qui estadd ysumm
	qui sum l`f' if e(sample)
	qui estadd scalar yobs `r(N)'
	qui sum `f'  
	qui estadd scalar ymeanbef `r(mean)'
	qui sum flag`t'_f	
	qui estadd scalar ymeanflag `r(mean)'
	qui estadd scalar ysdbef `r(sd)'
	qui estadd local marfe "Yes"
	qui estadd local timefe "Yes"
	qui estadd local disfe "Yes"
	qui estadd local thresfe "Yes"

	*iv
	eststo iv`t'_`f': ivreghdfe l`f' (flagnorm = ///
			 i.flagmonth`t'1_f i.flagmonth`t'2_f i.flagmonth`t'3_f i.flagmonth`t'4_f ///
			 i.flagmonth`t'10_f i.flagmonth`t'11_f i.flagmonth`t'12_f) if `t' != . , ///
		ffirst absorb(mar year district##c.year thres) cluster(mar) 
		
	qui estadd ysumm
	qui sum l`f' if e(sample)
	qui estadd scalar yobs `r(N)'
	qui sum `f' 
	qui estadd scalar ymeanbef `r(mean)'
	qui sum flag`t'_f	
	qui estadd scalar ymeanflag `r(mean)'
	qui estadd scalar ysdbef `r(sd)'
	qui estadd scalar ftest e(widstat)
	qui estadd local marfe "Yes"
	qui estadd local timefe "Yes"
	qui estadd local disfe "Yes"
	qui estadd local thresfe "Yes"
	
	rename thres thres`t'_f
	rename flagnorm flag`t'_fnorm 
	rename flag_thresnorm flag`t'_thres_fnorm 

}

}

local treatments math eng urdu 
foreach t of local treatments{
local fin totalfunds exp govfunds nongovfunds
foreach f of local fin{
	
	rename flag`t'_fnorm flagnorm
	rename flag`t'_thres_fnorm flag_thresnorm
	rename thres`t'_f thres
		
	*ols
	eststo ols`t'_`f': reghdfe l`f' flagnorm if `t' != . , /// 
		absorb(mar year district##c.year thres) vce(cluster mar) 
	qui estadd ysumm
	qui sum l`f' if e(sample)
	qui estadd scalar yobs `r(N)'
	qui sum `f'  
	qui estadd scalar ymeanbef `r(mean)'
	qui sum flag`t'_f	
	qui estadd scalar ymeanflag `r(mean)'
	qui estadd scalar ysdbef `r(sd)'
	qui estadd local marfe "Yes"
	qui estadd local timefe "Yes"
	qui estadd local disfe "Yes"
	qui estadd local thresfe "Yes"

	*iv
	eststo iv`t'_`f': ivreghdfe l`f' (flagnorm = ///
			 i.flagmonth`t'1_f i.flagmonth`t'2_f i.flagmonth`t'3_f i.flagmonth`t'4_f ///
			 i.flagmonth`t'10_f i.flagmonth`t'11_f i.flagmonth`t'12_f) if `t' != . , ///
		ffirst absorb(mar year district##c.year thres) cluster(mar) 
		
	qui estadd ysumm
	qui sum l`f' if e(sample)
	qui estadd scalar yobs `r(N)'
	qui sum `f' 
	qui estadd scalar ymeanbef `r(mean)'
	qui sum flag`t'_f	
	qui estadd scalar ymeanflag `r(mean)'
	qui estadd scalar ysdbef `r(sd)'
	qui estadd scalar ftest e(widstat)
	qui estadd local marfe "Yes"
	qui estadd local timefe "Yes"
	qui estadd local disfe "Yes"
	qui estadd local thresfe "Yes"
	
	rename thres thres`t'_f
	rename flagnorm flag`t'_fnorm 
	rename flag_thresnorm flag`t'_thres_fnorm 

}

}

***** Table 5
if(1){
	
* outcomes
estout olstpres_totalfunds ivtpres_totalfunds  olssatt_totalfunds ivsatt_totalfunds olsfac_totalfunds ivfac_totalfunds ///
	   olstpres_exp ivtpres_exp olssatt_exp ivsatt_exp olsfac_exp ivfac_exp ///
	   using "$analysis/tables/causal/99_budget_outcomes_dis.tex", ///
	style(tex) /// style of exporting
	starl(* 0.10 ** 0.05 *** 0.01) /// significance stars
	cells(b(star fmt(%6.3f)) se(par fmt(%6.3f))) /// format of cells (coefficient and se)
	mlabels(none) /// no label for models
	collabels(none) /// no label for columns
	label ///
	varlabels(flagnorm "\# Times flagged\$_{t}$ (z-score)") ///
	prehead(\begin{tabular}{lcccccccccccc} \toprule ///
	"\multicolumn{7}{l}{\textbf{Panel A: School outcomes flagging}} \\" ///
	"Flagging variable &  \multicolumn{2}{c}{Teacher} & \multicolumn{2}{c}{Student} & \multicolumn{2}{c}{Functional} &  \multicolumn{2}{c}{Teacher} & \multicolumn{2}{c}{Student} & \multicolumn{2}{c}{Functional} \\" ///
	" &  \multicolumn{2}{c}{presence} & \multicolumn{2}{c}{attendance} & \multicolumn{2}{c}{facilities} &  \multicolumn{2}{c}{presence} & \multicolumn{2}{c}{attendance} & \multicolumn{2}{c}{facilities} \\" ///
	"\cmidrule(lr){2-7} \cmidrule(lr){8-13} \addlinespace[0.5em]" ///
	" & \multicolumn{12}{c}{\underline{Dependent variables (logs)}} \\" /// dependent variable title	
	" & \multicolumn{6}{c}{Total Funds\$_{t+1}$} & \multicolumn{6}{c}{Expenditure\$_{t+1}$} \\" ///
	" & OLS & 2SLS & OLS & 2SLS & OLS & 2SLS & OLS & 2SLS & OLS & 2SLS & OLS & 2SLS \\" ///
	" & (1) & (2) & (3) & (4) & (5) & (6) & (7) & (8) & (9) & (10) & (11) & (12) \\" ///
	"\cmidrule(lr){2-7} \cmidrule(lr){8-13} \addlinespace[0.5em]") ///
	///posthead(\midrule) ///
    prefoot(\midrule) ///
	drop(_cons) ///
	stats(N N_clust ymeanbef  ymeanflag ysdbef ftest, fmt(%11.2gc %11.2gc %10.0fc a2 a2 a2) ///
	labels("N. of obs." "Number markaz" "Mean Dep. Var. (unlogged)" "Mean \# Times flagged" "SD \# Times flagged" "First stage F-stat")) /// stats to keep
	replace // replace if it exist

* scores
estout olsmath_totalfunds ivmath_totalfunds olseng_totalfunds iveng_totalfunds ///
       olsurdu_totalfunds  ivurdu_totalfunds olsmath_exp ivmath_exp olseng_exp iveng_exp ///
       olsurdu_exp ivurdu_exp ///
	   using "$analysis/tables/causal/Table5.tex", ///
	style(tex) /// style of exporting
	starl(* 0.10 ** 0.05 *** 0.01) /// significance stars
	cells(b(star fmt(%6.3f)) se(par fmt(%6.3f))) /// format of cells (coefficient and se)
	mlabels(none) /// no label for models
	collabels(none) /// no label for columns
	label ///
	varlabels(flagnorm "\# Times flagged\$_{t}$ (z-score)") ///
	prehead("\midrule \multicolumn{7}{l}{\textbf{Panel B: Student scores flagging}} \\" ///
	"Flagging variable &  \multicolumn{2}{c}{Math} & \multicolumn{2}{c}{English} & \multicolumn{2}{c}{Urdu} & \multicolumn{2}{c}{Math} & \multicolumn{2}{c}{English} & \multicolumn{2}{c}{Urdu} \\" ///
	"\cmidrule(lr){2-7} \cmidrule(lr){8-13} \addlinespace[0.5em]" ///
	" & \multicolumn{12}{c}{\underline{Dependent variables (logs)}} \\" /// dependent variable title	
	" & \multicolumn{6}{c}{Total Funds\$_{t+1}$} & \multicolumn{6}{c}{Expenditure\$_{t+1}$} \\" ///
	" & OLS & 2SLS & OLS & 2SLS & OLS & 2SLS & OLS & 2SLS & OLS & 2SLS & OLS & 2SLS \\" ///
	" & (1) & (2) & (3) & (4) & (5) & (6) & (7) & (8) & (9) & (10) & (11) & (12) \\" ///
	"\cmidrule(lr){2-7} \cmidrule(lr){8-13} \addlinespace[0.5em]") ///
	///posthead(\midrule) ///
    prefoot(\midrule) ///
	postfoot(\bottomrule \end{tabular}) ///
	drop(_cons) ///
	stats(N N_clust ymeanbef ymeanflag ysdbef ftest marfe timefe disfe thresfe, fmt(%11.2gc %11.2gc %10.0fc a2 a2 a2 a2 a2 a2 a2) ///
	labels("N. of obs." "Number markaz" "Mean Dep. Var. (unlogged)" "Mean \# Times flagged" "SD \# Times flagged" "First stage F-stat" ///
		   "\midrule Markaz FE" "Time FE" "District time trends" "\# Times in threshold\$_t$ FE")) /// stats to keep
	topfile("$analysis/tables/causal/99_budget_outcomes_dis.tex") /// this joins the two panels into a single table
	replace // replace if it exist
	
}

***** Table C2
if(1){
	
* outcomes
estout olstpres_govfunds ivtpres_govfunds olstpres_nongovfunds ivtpres_nongovfunds ///
       olssatt_govfunds ivsatt_govfunds olssatt_nongovfunds ivsatt_nongovfunds ///
	   olsfac_govfunds ivfac_govfunds olsfac_nongovfunds ivfac_nongovfunds ///
	   using "$analysis/tables/causal/99_budget_outcomes_disag.tex", ///
	style(tex) /// style of exporting
	starl(* 0.10 ** 0.05 *** 0.01) /// significance stars
	cells(b(star fmt(%6.3f)) se(par fmt(%6.3f))) /// format of cells (coefficient and se)
	mlabels(none) /// no label for models
	collabels(none) /// no label for columns
	label ///
	varlabels(flagnorm "\# Times flagged\$_{t}$ (z-score)") ///
	prehead(\begin{tabular}{lcccccccccccc} \toprule ///
	"\multicolumn{13}{l}{\textbf{Panel A: School outcomes flagging}} \\" ///
	"Flagging variable &  \multicolumn{4}{c}{Teacher presence} & \multicolumn{4}{c}{Student attendance} & \multicolumn{4}{c}{Functional facilities} \\" ///
	" & \multicolumn{12}{c}{\underline{Dependent variables (logs)}} \\" /// dependent variable title	
	" & \multicolumn{2}{c}{Government} & \multicolumn{2}{c}{Non Government} & \multicolumn{2}{c}{Government} & \multicolumn{2}{c}{Non Government} & \multicolumn{2}{c}{Government} & \multicolumn{2}{c}{Non Government} \\" ///
	" & \multicolumn{2}{c}{Funds\$_{t+1}$} & \multicolumn{2}{c}{Funds\$_{t+1}$} & \multicolumn{2}{c}{Funds\$_{t+1}$} & \multicolumn{2}{c}{Funds\$_{t+1}$} & \multicolumn{2}{c}{Funds\$_{t+1}$} & \multicolumn{2}{c}{Funds\$_{t+1}$} \\" ///
	" & OLS & 2SLS & OLS & 2SLS & OLS & 2SLS & OLS & 2SLS & OLS & 2SLS & OLS & 2SLS \\" ///
	" & (1) & (2) & (3) & (4) & (5) & (6) & (7) & (8) & (9) & (10) & (11) & (12) \\" ///
	"\cline{2-13} \addlinespace[0.5em]") ///
	///posthead(\midrule) ///
    prefoot(\midrule) ///
	drop(_cons) ///
	stats(N N_clust ymeanbef ymeanflag ysdbef ftest, fmt(%11.2gc %11.2gc %10.0fc a2 a2 a2) ///
	labels("N. of obs." "Number markaz" "Mean Dep. Var. (unlogged)" "Mean \# Times flagged" "SD \# Times flagged" "First stage F-stat")) /// stats to keep
	replace // replace if it exist

* scores
estout olsmath_govfunds ivmath_govfunds olsmath_nongovfunds ivmath_nongovfunds ///
       olseng_govfunds iveng_govfunds olseng_nongovfunds iveng_nongovfunds ///
	   olsurdu_govfunds ivurdu_govfunds olsurdu_nongovfunds ivurdu_nongovfunds ///
	   using "$analysis/tables/causal/TableC2.tex", ///
	style(tex) /// style of exporting
	starl(* 0.10 ** 0.05 *** 0.01) /// significance stars
	cells(b(star fmt(%6.3f)) se(par fmt(%6.3f))) /// format of cells (coefficient and se)
	mlabels(none) /// no label for models
	collabels(none) /// no label for columns
	label ///
	varlabels(flagnorm "\# Times flagged\$_{t}$ (z-score)") ///
	prehead("\midrule \multicolumn{13}{l}{\textbf{Panel B: Student scores flagging}} \\" ///
	"Flagging variable &  \multicolumn{4}{c}{Math} & \multicolumn{4}{c}{English} & \multicolumn{4}{c}{Urdu} \\" ///
	" & \multicolumn{12}{c}{\underline{Dependent variables (range: 0-100)}} \\" /// dependent variable title
	" & \multicolumn{2}{c}{Government} & \multicolumn{2}{c}{Non Government} & \multicolumn{2}{c}{Government} & \multicolumn{2}{c}{Non Government} & \multicolumn{2}{c}{Government} & \multicolumn{2}{c}{Non Government} \\" ///
	" & \multicolumn{2}{c}{Funds\$_{t+1}$} & \multicolumn{2}{c}{Funds\$_{t+1}$} & \multicolumn{2}{c}{Funds\$_{t+1}$} & \multicolumn{2}{c}{Funds\$_{t+1}$} & \multicolumn{2}{c}{Funds\$_{t+1}$} & \multicolumn{2}{c}{Funds\$_{t+1}$} \\" ///
	" & (1) & (2) & (3) & (4) & (5) & (6) & (7) & (8) & (9) & (10) & (11) & (12) \\" ///
	"\cline{2-13} \addlinespace[0.5em]") ///
	///posthead(\midrule) ///
    prefoot(\midrule) ///
	postfoot(\bottomrule \end{tabular}) ///
	drop(_cons) ///
	stats(N N_clust ymeanbef ymeanflag ysdbef ftest marfe timefe disfe thresfe, fmt(%11.2gc %11.2gc %10.0fc a2 a2 a2 a2 a2 a2 a2) ///
	labels("N. of obs." "Number markaz" "Mean Dep. Var. (unlogged)" "Mean \# Times flagged" "SD \# Times flagged" "First stage F-stat" ///
		   "\midrule Markaz FE" "Time FE" "District time trends" "\# Times in threshold\$_t$ FE")) /// stats to keep
	topfile("$analysis/tables/causal/99_budget_outcomes_disag.tex") /// this joins the two panels into a single table
	replace // replace if it exist
	
}

* robust instrument for budget
local treatments tpres satt fac math eng urdu
foreach t of local treatments{
local fin exp totalfunds
foreach f of local fin{
	
	rename flag`t'_fnorm flagnorm
	rename flag`t'_thres_fnorm flag_thresnorm
	rename thres`t'_f thres
	rename flag`t'_thresever flag_thresever
		
	*iv
	eststo iv`t'_`f': ivreghdfe l`f' (flagnorm = ///
			 i.flagmonth`t'1_f i.flagmonth`t'2_f i.flagmonth`t'3_f i.flagmonth`t'4_f ///
			 i.flagmonth`t'10_f i.flagmonth`t'11_f i.flagmonth`t'12_f) if `t' != ., ///
		ffirst absorb(mar year district##c.year thres) cluster(mar) 
		
	*iv - linear 
	eststo ivlin`t'_`f': ivreghdfe l`f'  (flagnorm = ///
			 flag_thresnorm) if `t' != ., ///
		ffirst absorb(mar year district##c.year thres) cluster(mar) 
		
	*iv - flagged ever 
	eststo ivever`t'_`f': ivreghdfe l`f'  (flagnorm = ///
			 flag_thresever) if `t' != ., ///
		ffirst absorb(mar year district##c.year thres) cluster(mar) 
		
	*iv - q2
	eststo ivq2`t'_`f': ivreghdfe l`f'  (flagnorm = ///
			 i.flag`t'_thres_q2) if `t' != ., ///
		ffirst absorb(mar year district##c.year thres) cluster(mar) 

	
	rename thres thres`t'_f
	rename flagnorm flag`t'_fnorm 
	rename flag_thresnorm flag`t'_thres_fnorm 
	rename flag_thresever flag`t'_thresever

}

}

***** Figure C2
local treatments tpres satt fac math eng urdu
foreach t of local treatments{

coefplot (iv`t'_totalfunds, mcol(navy)) (ivlin`t'_totalfunds, mcol(blue)) (ivever`t'_totalfunds, mcol(midblue)) (ivq2`t'_totalfunds, mcol(red)), ///
		  bylabel(Total funds (log)) || ///
		 (iv`t'_exp, mcol(navy) ) (ivlin`t'_exp, mcol(blue)) (ivever`t'_exp, mcol(midblue)) (ivq2`t'_exp, mcol(red)), ///
		 bylabel(Total expenditure (log)) || , ///
		 msize(large) ciopts(lcol(gray)) vertical yline(0, lpattern(dash) lcol(black)) ytitle("Coefficient", size(vlarge)) ///
		 coeflabel(flagnorm = "# Times flagged", labsize(vlarge)) ///
		 legend(order(2 "Main" 4 "Linear" 6 "Flag ever" 8 "Flag median") col(4) size(vlarge)) ///
		 byopts( legend(pos(6)) )
		 
* save graph
graph export "$analysis/figures/causal/FigureC2_`t'.pdf", replace		

}

*---------------------------------------------------------------------------------------------------
* 12. regressions: effect on effort

use "$analysis/processed/cc_mar_emis_year_data.dta", clear

* effort 
local treatments tpres satt fac math eng urdu
foreach t of local treatments{
local fin share_change share_visited
foreach f of local fin{
	
	rename flag`t'_fnorm flagnorm
	rename flag`t'_thres_fnorm flag_thresnorm
	rename thres`t'_f thres
		
	*ols
	eststo ols`t'_`f': reghdfe `f' flagnorm if `t' != . , /// 
		absorb(mar year district##c.year thres) vce(cluster mar) 
	qui estadd ysumm
	qui sum `f' if e(sample)
	qui estadd scalar yobs `r(N)'
	qui sum `f'  
	qui estadd scalar ymeanbef `r(mean)'
	qui sum flag`t'_f	
	qui estadd scalar ymeanflag `r(mean)'
	qui estadd scalar ysdbef `r(sd)'
	qui estadd local marfe "Yes"
	qui estadd local timefe "Yes"
	qui estadd local disfe "Yes"
	qui estadd local thresfe "Yes"

	*iv
	eststo iv`t'_`f': ivreghdfe `f' (flagnorm = ///
			 i.flagmonth`t'1_f i.flagmonth`t'2_f i.flagmonth`t'3_f i.flagmonth`t'4_f ///
			 i.flagmonth`t'10_f i.flagmonth`t'11_f i.flagmonth`t'12_f) if `t' != ., ///
		ffirst absorb(mar year district##c.year thres) cluster(mar) 
		
	qui estadd ysumm
	qui sum `f' if e(sample)
	qui estadd scalar yobs `r(N)'
	qui sum `f'  
	qui estadd scalar ymeanbef `r(mean)'
	qui sum flag`t'_f	
	qui estadd scalar ymeanflag `r(mean)'
	qui estadd scalar ysdbef `r(sd)'
	qui estadd scalar ftest e(widstat)
	qui estadd local marfe "Yes"
	qui estadd local timefe "Yes"
	qui estadd local disfe "Yes"
	qui estadd local thresfe "Yes"
	
	rename thres thres`t'_f
	rename flagnorm flag`t'_fnorm 
	rename flag_thresnorm flag`t'_thres_fnorm 

}

}

***** Table C1
if(1){
	
* outcomes
estout olstpres_share_visited ivtpres_share_visited olssatt_share_visited  ivsatt_share_visited ///
	olsfac_share_visited ivfac_share_visited olsmath_share_visited ivmath_share_visited ///
	olseng_share_visited iveng_share_visited olsurdu_share_visited ivurdu_share_visited ///
	   using "$analysis/tables/causal/99_effort_outcomes_dis.tex", ///
	style(tex) /// style of exporting
	starl(* 0.10 ** 0.05 *** 0.01) /// significance stars
	cells(b(star fmt(%6.3f)) se(par fmt(%6.3f))) /// format of cells (coefficient and se)
	mlabels(none) /// no label for models
	collabels(none) /// no label for columns
	label ///
	varlabels(flagnorm "\# Times flagged\$_{t}$ (z-score)") ///
	prehead(\begin{tabular}{lcccccccccccc} \toprule ///
	"\multicolumn{13}{l}{\textbf{Panel A: Bureaucratic oversight}} \\" ///
	"Flagging variable &  \multicolumn{2}{c}{Teacher} & \multicolumn{2}{c}{Student} & \multicolumn{2}{c}{Functional} & \multicolumn{2}{c}{Math} & \multicolumn{2}{c}{English} & \multicolumn{2}{c}{Urdu} \\" ///
	"&  \multicolumn{2}{c}{presence} & \multicolumn{2}{c}{attendance} & \multicolumn{2}{c}{facilities} & \multicolumn{2}{c}{} & \multicolumn{2}{c}{} & \multicolumn{2}{c}{} \\" ///
	" & \multicolumn{12}{c}{\underline{Dependent variable (range: 0-100)} Visited schools\$_{t+1}$} \\" /// dependent variable title
	" & OLS & 2SLS & OLS & 2SLS & OLS & 2SLS & OLS & 2SLS & OLS & 2SLS & OLS & 2SLS \\" ///
	" & (1) & (2) & (3) & (4) & (5) & (6) & (7) & (8) & (9) & (10) & (11) & (12) \\" ///
	"\cline{2-13} \addlinespace[0.5em]") ///
	///posthead(\midrule) ///
    prefoot(\midrule) ///
	drop(_cons) ///
	stats(N N_clust ymeanbef  ymeanflag ysdbef ftest, fmt(%11.2gc %11.2gc a2 a2 a2) ///
	labels("N. of obs." "Number markaz" "Mean Dep. Var." "Mean \# Times flagged" "SD \# Times flagged" "First stage F-stat")) /// stats to keep
	replace // replace if it exist

* scores
estout olstpres_share_change ivtpres_share_change olssatt_share_change  ivsatt_share_change ///
	    olsfac_share_change ivfac_share_change olsmath_share_change ivmath_share_change ///
		olseng_share_change iveng_share_change olsurdu_share_change ivurdu_share_change ///
	   using "$analysis/tables/causal/TableC1.tex", ///
	style(tex) /// style of exporting
	starl(* 0.10 ** 0.05 *** 0.01) /// significance stars
	cells(b(star fmt(%6.3f)) se(par fmt(%6.3f))) /// format of cells (coefficient and se)
	mlabels(none) /// no label for models
	collabels(none) /// no label for columns
	label ///
	varlabels(flagnorm "\# Times flagged\$_{t}$ (z-score)") ///
	prehead("\midrule \multicolumn{7}{l}{\textbf{Panel B: Transfers and postings}} \\" ///
	"Flagging variable &  \multicolumn{2}{c}{Teacher} & \multicolumn{2}{c}{Student} & \multicolumn{2}{c}{Functional} & \multicolumn{2}{c}{Math} & \multicolumn{2}{c}{English} & \multicolumn{2}{c}{Urdu} \\" ///
	"&  \multicolumn{2}{c}{presence} & \multicolumn{2}{c}{attendance} & \multicolumn{2}{c}{facilities} & \multicolumn{2}{c}{} & \multicolumn{2}{c}{} & \multicolumn{2}{c}{} \\" ///
	" & \multicolumn{12}{c}{\underline{Dependent variable (range: 0-100)} Change head teacher\$_{t+1}$} \\" /// dependent variable title
	" & OLS & 2SLS & OLS & 2SLS & OLS & 2SLS & OLS & 2SLS & OLS & 2SLS & OLS & 2SLS \\" ///
	" & (1) & (2) & (3) & (4) & (5) & (6) & (7) & (8) & (9) & (10) & (11) & (12) \\" ///
	"\cline{2-13} \addlinespace[0.5em]") ///
	///posthead(\midrule) ///
    prefoot(\midrule) ///
	postfoot(\bottomrule \end{tabular}) ///
	drop(_cons) ///
	stats(N N_clust ymeanbef ymeanflag ysdbef ftest marfe timefe disfe thresfe, fmt(%11.2gc %11.2gc a2 a2 a2 a2 a2 a2 a2) ///
	labels("N. of obs." "Number markaz" "Mean Dep. Var." "Mean \# Times flagged" "SD \# Times flagged" "First stage F-stat" ///
		   "\midrule Markaz FE" "Time FE" "District time trends" "\# Times in threshold\$_t$ FE")) /// stats to keep
	topfile("$analysis/tables/causal/99_effort_outcomes_dis.tex") /// this joins the two panels into a single table
	replace // replace if it exist
	
}

* robust instrument
local treatments tpres satt fac math eng urdu
foreach t of local treatments{
local fin share_change share_visited
foreach f of local fin{
	
	rename flag`t'_fnorm flagnorm
	rename flag`t'_thres_fnorm flag_thresnorm
	rename thres`t'_f thres
	rename flag`t'_thresever flag_thresever
		
	*iv
	eststo iv`t'_`f': ivreghdfe `f' (flagnorm = ///
			 i.flagmonth`t'1_f i.flagmonth`t'2_f i.flagmonth`t'3_f i.flagmonth`t'4_f ///
			 i.flagmonth`t'10_f i.flagmonth`t'11_f i.flagmonth`t'12_f) if `t' != ., ///
		ffirst absorb(mar year district##c.year thres) cluster(mar) 
		
	*iv - linear 
	eststo ivlin`t'_`f': ivreghdfe `f'  (flagnorm = ///
			 flag_thresnorm) if `t' != ., ///
		ffirst absorb(mar year district##c.year thres) cluster(mar) 
		
	*iv - flagged ever 
	eststo ivever`t'_`f': ivreghdfe `f'  (flagnorm = ///
			 flag_thresever) if `t' != ., ///
		ffirst absorb(mar year district##c.year thres) cluster(mar) 
		
	*iv - q2
	eststo ivq2`t'_`f': ivreghdfe `f'  (flagnorm = ///
			 i.flag`t'_thres_q2) if `t' != ., ///
		ffirst absorb(mar year district##c.year thres) cluster(mar) 

	
	rename thres thres`t'_f
	rename flagnorm flag`t'_fnorm 
	rename flag_thresnorm flag`t'_thres_fnorm 
	rename flag_thresever flag`t'_thresever

}

}

***** Figure C1
local treatments tpres satt fac math eng urdu
foreach t of local treatments{

coefplot (iv`t'_share_change, mcol(navy)) (ivlin`t'_share_change, mcol(blue)) (ivever`t'_share_change, mcol(midblue)) (ivq2`t'_share_change, mcol(red)), ///
		  bylabel(Change head teacher) || ///
		 (iv`t'_share_visited, mcol(navy) ) (ivlin`t'_share_visited, mcol(blue)) (ivever`t'_share_visited, mcol(midblue)) (ivq2`t'_share_visited, mcol(red)), ///
		 bylabel(Visited schools) || , ///
		 msize(large) ciopts(lcol(gray)) vertical yline(0, lpattern(dash) lcol(black)) ytitle("Coefficient", size(vlarge)) ///
		 coeflabel(flagnorm = "# Times flagged", labsize(vlarge)) ///
		 legend(order(2 "Main" 4 "Linear" 6 "Flag ever" 8 "Flag median") col(4) size(vlarge)) ///
		 byopts( legend(pos(6)) )
		 
* save graph
graph export "$analysis/figures/causal/FigureC1_`t'.pdf", replace		

}


