/*--------------------------------------------------------------------------------------------------
Set up

Initial characteristics for replication the analysis

	Outline:

	1. standardize settings
	2. path
	3. packages
	4. run analysis
--------------------------------------------------------------------------------------------------*/
*
*
*
*
*
*---------------------------------------------------------------------------------------------------
**# 1. standardize settings #

* initial setting
set more off
clear all
version 16.1
set varabbrev on

* set seed for replication
set seed 30042024
set sortseed 30042024

*---------------------------------------------------------------------------------------------------
**# 2. path #

global user "`c(username)'"

global projectfolder "C:/WBG/rep-checks/RR_PAK_2023_61"

* globals path for analysis
global analysis "$projectfolder/analysis" // main folder
global data "$analysis/data" // raw data folder
global code "$analysis/code" // code folder

*---------------------------------------------------------------------------------------------------
**# 3. packages #

sysdir set PLUS "$analysis/adofiles" // packages folder
mata: mata mlib index

/* packages used are all in the adofiles folder, so do not change to 1*/
if(0){ //change to 1 to RUN. Last update: november 14 / 2023

	*reproducibility world bank
	ssc install repkit, replace
	
	* miscelaneous
	ssc install egenmore // additional functions for variable calculations
	ssc install outreg2 // storing output for table exporting
	ssc install geodist // calculate gps distances
	ssc install geonear // nearest neighbor calculation
	ssc install group_id // grouping based on shared id
	ssc install jarowinkler // implementation of jarowrinkler: for fuzzy matching
	ssc install palettes // colors in graphs
	net install colrspace, replace from(https://raw.githubusercontent.com/benjann/colrspace/master/) // color management in mata
	ssc install sencode // encode string variable	
	ssc install binscatter // binscatter graph
	ssc install blindschemes
	
	* network analysis in stata
	net from http://nwcommands.org
	net install "nwcommands-ado"
	
	*rd analysis
	net install rdrobust, from(https://raw.githubusercontent.com/rdpackages/rdrobust/master/stata) replace
	
	* regression
	ssc install bcuse
	net install ftools, from("https://raw.githubusercontent.com/sergiocorreia/ftools/master/src/")
	ssc install moremata
	net install reghdfe, from("https://raw.githubusercontent.com/sergiocorreia/reghdfe/master/src/")
	net install ivreghdfe, from(https://raw.githubusercontent.com/sergiocorreia/ivreghdfe/master/src/)
	ssc install ivreg2 // IV regression
	ssc install ranktest
	ssc install rddensity // density test
	net install lpdensity, from(https://raw.githubusercontent.com/nppackages/lpdensity/master/stata) replace
	ssc install did_multiplegt // dif-in-dif for heterogeneous effects (deChaisemartin)
	ssc install did_multiplegt_dyn
	ssc install gtools // required for did_multiplegt_dyn
	ssc install eventstudyweights // implement dif-in-dif with staggered adoption (Sun & Abraham)
	net install github, from("https://haghish.github.io/github/") // suplement for eventstudyweights
	github install lsun20/eventstudyinteract // suplement for eventstudyweights

	* figures
	ssc install addplot // add plot to coefplot
	net install panelview, all replace from("https://yiqingxu.org/packages/panelview_stata") // panelview
	
	/* similar problem to panelview */
	ssc install grstyle // graph style
	ssc install tabplot // summary graphs by categories
	ssc install beamplot // dotplots and binscatter
	ssc install coefplot // plot of coefficients
	net install grc1leg, from(http://www.stata.com/users/vwiggins/) // management of legends in graph
	
	* tables 
	ssc install estout // format of tables
	ssc install labutil // table labels management
	
}

*---------------------------------------------------------------------------------------------------
**# 4. run analysis #

* do files
* -- set up scheme for graphs:
set scheme plotplain

// data cleaning
do "$code/0_clean_data.do"

// data stacking
do "$code/1_stack_data.do"

* always run this: some set up outside of windows might have problems reading some mata functions related to plots
capture mata: mata drop m_calckw()
capture mata: mata drop m_omega()
capture mata: mata drop ms_vcvorthog()
capture mata: mata drop s_vkernel()
mata: mata mlib index

// descriptive analysis
do "$code/2_descriptive.do" 

/*
NOTE ON REGRESSIONS ############################################################

we are using the command REGHDFE: https://scorreia.com/help/reghdfe.html

- our base fixed effects include MARKAZ and TIME fixed effects and a linear trend for DISTRICTS (slopes)
- the author of the package states that slopes in the form district#c.time can cause some NUMERICAL INSTABILITY --> which can in turn affect the replication of the results

According to the package help files, there are two alternatives for this 

1. increase the tolerance as tol(1e-14) (default is 1e-8), so it converges under more strict values
2. use district##c.time, where i.district would be included in the fixed effects
	* in this scenario because we always use markaz FE, then district FE is redundant. The author of the package states that this just helps the convergence (precision of decimal points) 
	  but does not include i.district in any way for estimating the relevant coefficients
	  
We tested the replication of the results using (a) our base fixed effects, (b) increasing tolerance, (c) including the slopes as district##c.time

(a) replicates everything except a couple of tables where the third decimal might change slighly (+/- 0.005) --> this due to numerical instability of slope term
(b) replicates everything --> runs slower due to stronger conditions for convergence
(c) replicates everything --> runs faster due to inclusion of intercept -- redundant by design but still used by the algorithm

- comparing replications between (b) and (c) replicate almost perfectly with slight variations in some coefficients: +/- 0.001 at worst
- comparing replications (a) vs (b), and (a) vs (c) have variations in some coefficients: +/- 0.01 at worst, this due to numerical instability of (a) and (b), (c) having more precise results
- the method DOES NOT AFFECT IN ANY WAY the conclusions of the paper and can be attributable to how stata in different settings (mac vs windows vs linux 
  for instance) approximates the decimal points after the third or four decimal), using (b) or (c) ensures replicability across settings due to best stability

FINAL METHOD: we use option (c) include slopes as district##c.time, as according to the author it improves the speed of convergence, so the code on average runs faster

*/

// analysis - iv
do "$code/3_iv_regressions.do"

// analysis - stacked
do "$code/4_stacked_regressions.do"
